import { Token } from "./token";
/**
 * The base class for all user-facing Liquid errors.
 */
export declare class LiquidError extends Error {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown when a template syntax error is found.
 */
export declare class LiquidSyntaxError extends LiquidError {
    message: string;
    originalMessage: string;
    token: Token;
    constructor(message: string, token: Token, templateName?: string);
    withTemplateName(templateName?: string): LiquidSyntaxError;
}
/**
 * An error thrown when a tag or filter are given an argument of an unacceptable type.
 */
export declare class LiquidTypeError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown when there's a problem with a filter's left value.
 */
export declare class LiquidFilterValueError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown when there's a problem with one or more filter arguments.
 */
export declare class LiquidFilterArgumentError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown when a template contains an unregistered tag.
 */
export declare class NoSuchTagError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown when a template uses an unregistered filter.
 */
export declare class NoSuchFilterError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown when a render context is copied or extended too many times.
 */
export declare class ContextDepthError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown when a render context's local namespace limit is reached.
 */
export declare class LocalNamespaceLimitError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown when the loop iteration limit is reached.
 */
export declare class LoopIterationLimitError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown when the output stream limit is reached.
 */
export declare class OutputStreamLimitError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown by the {@link StrictUndefined} class.
 */
export declare class LiquidUndefinedError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown when a template loader can not locate a template.
 */
export declare class NoSuchTemplateError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown when a `break` tag appears outside an `if` tag.
 */
export declare class OrphanedBreakTagError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown when a `continue` tag appears outside an `if` tag.
 */
export declare class OrphanedContinueTagError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown when tag is used in a render context where such tags are
 * disabled.
 */
export declare class DisabledTagError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown when template inheritance tags are used incorrectly.
 */
export declare class TemplateInheritanceError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * An error thrown due to a misconfigured environment.
 */
export declare class LiquidEnvironmentError extends LiquidError {
    message: string;
    constructor(message: string, token: Token, templateName?: string);
}
/**
 * The base class for all internal Liquid errors.
 */
export declare abstract class InternalLiquidError extends Error {
    message: string;
    constructor(message: string);
    abstract withToken(token: Token, templateName?: string): LiquidError;
}
/**
 * An error thrown when someone tries to set a property on an {@link ObjectChain}.
 */
export declare class ReadOnlyObjectChainError extends InternalLiquidError {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
/**
 * An error thrown when a render context can not resolve a variable name and path.
 */
export declare class InternalKeyError extends InternalLiquidError {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
/**
 * An error thrown by a Liquid {@link Drop} dispatch method if a name does not exist.
 */
export declare class LiquidKeyError extends InternalKeyError {
    message: string;
    constructor(message: string);
}
/**
 * An error thrown by the {@link StrictUndefined} type.
 */
export declare class InternalUndefinedError extends InternalLiquidError {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
/**
 * An error thrown when a render context is copied or extended too many times.
 */
export declare class MaxContextDepthError extends InternalLiquidError {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
/**
 * An error thrown when a render context's local namespace exceeds its limit.
 */
export declare class MaxLocalNamespaceLimitError extends InternalLiquidError {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
/**
 * An error thrown when the loop iteration limit is reached.
 */
export declare class MaxLoopIterationLimitError extends InternalLiquidError {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
/**
 * An error thrown when the output stream limit is reached.
 */
export declare class InternalOutputStreamLimitError extends InternalLiquidError {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
/**
 * An error thrown when a template loader can not locate a template.
 */
export declare class TemplateNotFoundError extends InternalLiquidError {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
/**
 * An error thrown by an {@link ExpressionTokenStream} if too many tokens are
 * pushed back onto the stream.
 */
export declare class PushedTooFarError extends InternalLiquidError {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
/**
 * An error thrown when a template uses an unregistered filter.
 */
export declare class FilterNotFoundError extends InternalLiquidError {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
/**
 * An error thrown when there's a problem with a filter's left value.
 */
export declare class FilterValueError extends InternalLiquidError {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
/**
 * An error thrown when there's a problem with one or more filter arguments.
 */
export declare class FilterArgumentError extends InternalLiquidError {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
/**
 * An error thrown when a tag or filter are given an argument of an unacceptable type.
 */
export declare class InternalTypeError extends InternalLiquidError {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
export declare class InternalSyntaxError extends InternalLiquidError {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
export declare abstract class LiquidInterrupt extends Error {
    message: string;
    constructor(message: string);
}
/**
 * An error thrown to indicate a Liquid for loop should be broken.
 */
export declare class BreakIteration extends LiquidInterrupt {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
/**
 * An error thrown to indicate a Liquid for loop should continue to the next iteration.
 */
export declare class ContinueIteration extends LiquidInterrupt {
    message: string;
    constructor(message: string);
    withToken(token: Token, templateName?: string): LiquidError;
}
export declare class StopRender extends LiquidInterrupt {
    message: string;
    constructor(message: string);
}
/**
 * An error thrown during static template analysis. Indicates a `Node` or `Expression`
 * could not be visited.
 */
export declare class TemplateTraversalError extends Error {
    message: string;
    constructor(message: string);
}
