/*
 * liquidscript version 1.8.2
 * https://github.com/jg-rp/liquidscript
 * 
 * MIT License
 * 
 * Copyright (c) 2022 James Prior
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 * 
 */
import Decimal from 'decimal.js';
import { DateTime } from 'luxon';
import fsCallback from 'fs';
import fs from 'fs/promises';
import path from 'path';

// We're manually setting the prototype for each error subclass. See
// https://github.com/Microsoft/TypeScript-wiki/blob/main/Breaking-Changes.md#extending-built-ins-like-error-array-and-map-may-no-longer-work

/**
 * The base class for all user-facing Liquid errors.
 */
class LiquidError extends Error {
  constructor(message, token, templateName) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, LiquidError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, LiquidError);
    }
    this.name = "LiquidError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown when a template syntax error is found.
 */
class LiquidSyntaxError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, LiquidSyntaxError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, LiquidSyntaxError);
    }
    this.name = "LiquidSyntaxError";
    this.originalMessage = message;
    this.message = _message(message, token, templateName);
    this.token = token;
  }
  withTemplateName(templateName) {
    return new LiquidSyntaxError(this.originalMessage, this.token, templateName);
  }
}

/**
 * An error thrown when a tag or filter are given an argument of an unacceptable type.
 */
class LiquidTypeError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, LiquidTypeError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, LiquidTypeError);
    }
    this.name = "LiquidTypeError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown when there's a problem with a filter's left value.
 */
class LiquidFilterValueError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token, templateName);
    this.message = message;
    Object.setPrototypeOf(this, LiquidFilterValueError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, LiquidFilterValueError);
    }
    this.name = "LiquidFilterValueError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown when there's a problem with one or more filter arguments.
 */
class LiquidFilterArgumentError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token, templateName);
    this.message = message;
    Object.setPrototypeOf(this, LiquidFilterArgumentError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, LiquidFilterArgumentError);
    }
    this.name = "LiquidFilterArgumentError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown when a template contains an unregistered tag.
 */
class NoSuchTagError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, NoSuchTagError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, NoSuchTagError);
    }
    this.name = "NoSuchTagError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown when a template uses an unregistered filter.
 */
class NoSuchFilterError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, NoSuchFilterError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, NoSuchFilterError);
    }
    this.name = "NoSuchFilterError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown when a render context is copied or extended too many times.
 */
class ContextDepthError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, ContextDepthError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, ContextDepthError);
    }
    this.name = "ContextDepthError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown when a render context's local namespace limit is reached.
 */
class LocalNamespaceLimitError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, LocalNamespaceLimitError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, LocalNamespaceLimitError);
    }
    this.name = "LocalNamespaceLimitError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown when the loop iteration limit is reached.
 */
class LoopIterationLimitError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, LoopIterationLimitError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, LoopIterationLimitError);
    }
    this.name = "LoopIterationLimitError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown when the output stream limit is reached.
 */
class OutputStreamLimitError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, OutputStreamLimitError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, OutputStreamLimitError);
    }
    this.name = "OutputStreamLimitError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown by the {@link StrictUndefined} class.
 */
class LiquidUndefinedError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, LiquidUndefinedError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, LiquidUndefinedError);
    }
    this.name = "LiquidUndefinedError";
    this.message = _message(`'${message}' is undefined`, token, templateName);
  }
}

/**
 * An error thrown when a template loader can not locate a template.
 */
class NoSuchTemplateError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, NoSuchTemplateError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, NoSuchTemplateError);
    }
    this.name = "NoSuchTemplateError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown when a `break` tag appears outside an `if` tag.
 */
class OrphanedBreakTagError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, OrphanedBreakTagError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, OrphanedBreakTagError);
    }
    this.name = "OrphanedBreakTagError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown when a `continue` tag appears outside an `if` tag.
 */
class OrphanedContinueTagError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, OrphanedContinueTagError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, OrphanedContinueTagError);
    }
    this.name = "OrphanedContinueTagError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown when tag is used in a render context where such tags are
 * disabled.
 */
class DisabledTagError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, DisabledTagError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, DisabledTagError);
    }
    this.name = "DisabledTagError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown when template inheritance tags are used incorrectly.
 */
class TemplateInheritanceError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, TemplateInheritanceError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, TemplateInheritanceError);
    }
    this.name = "TemplateInheritanceError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * An error thrown due to a misconfigured environment.
 */
class LiquidEnvironmentError extends LiquidError {
  constructor(message, token, templateName) {
    super(message, token);
    this.message = message;
    Object.setPrototypeOf(this, LiquidEnvironmentError.prototype);
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, LiquidEnvironmentError);
    }
    this.name = "LiquidEnvironmentError";
    this.message = _message(message, token, templateName);
  }
}

/**
 * The base class for all internal Liquid errors.
 */
class InternalLiquidError extends Error {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, InternalLiquidError.prototype);
  }
}

/**
 * An error thrown when someone tries to set a property on an {@link ObjectChain}.
 */
class ReadOnlyObjectChainError extends InternalLiquidError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, ReadOnlyObjectChainError.prototype);
  }
  withToken(token, templateName) {
    return new LiquidError(this.message, token, templateName);
  }
}

/**
 * An error thrown when a render context can not resolve a variable name and path.
 */
class InternalKeyError extends InternalLiquidError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, InternalKeyError.prototype);
  }
  withToken(token, templateName) {
    return new LiquidUndefinedError(this.message, token, templateName);
  }
}

/**
 * An error thrown by a Liquid {@link Drop} dispatch method if a name does not exist.
 */
class LiquidKeyError extends InternalKeyError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, LiquidKeyError.prototype);
  }
}

/**
 * An error thrown by the {@link StrictUndefined} type.
 */
class InternalUndefinedError extends InternalLiquidError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, InternalUndefinedError.prototype);
  }
  withToken(token, templateName) {
    return new LiquidUndefinedError(this.message, token, templateName);
  }
}

/**
 * An error thrown when a render context is copied or extended too many times.
 */
class MaxContextDepthError extends InternalLiquidError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, MaxContextDepthError.prototype);
  }
  withToken(token, templateName) {
    return new ContextDepthError(this.message, token, templateName);
  }
}

/**
 * An error thrown when a render context's local namespace exceeds its limit.
 */
class MaxLocalNamespaceLimitError extends InternalLiquidError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, MaxLocalNamespaceLimitError.prototype);
  }
  withToken(token, templateName) {
    return new LocalNamespaceLimitError(this.message, token, templateName);
  }
}

/**
 * An error thrown when the loop iteration limit is reached.
 */
class MaxLoopIterationLimitError extends InternalLiquidError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, MaxLoopIterationLimitError.prototype);
  }
  withToken(token, templateName) {
    return new LoopIterationLimitError(this.message, token, templateName);
  }
}

/**
 * An error thrown when the output stream limit is reached.
 */
class InternalOutputStreamLimitError extends InternalLiquidError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, InternalOutputStreamLimitError.prototype);
  }
  withToken(token, templateName) {
    return new OutputStreamLimitError(this.message, token, templateName);
  }
}

/**
 * An error thrown when a template loader can not locate a template.
 */
class TemplateNotFoundError extends InternalLiquidError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, TemplateNotFoundError.prototype);
  }
  withToken(token, templateName) {
    return new NoSuchTemplateError(this.message, token, templateName);
  }
}

/**
 * An error thrown by an {@link ExpressionTokenStream} if too many tokens are
 * pushed back onto the stream.
 */
class PushedTooFarError extends InternalLiquidError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, PushedTooFarError.prototype);
  }
  withToken(token, templateName) {
    return new LiquidError(this.message, token, templateName);
  }
}

/**
 * An error thrown when a template uses an unregistered filter.
 */
class FilterNotFoundError extends InternalLiquidError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, FilterNotFoundError.prototype);
  }
  withToken(token, templateName) {
    return new NoSuchFilterError(this.message, token, templateName);
  }
}

/**
 * An error thrown when there's a problem with a filter's left value.
 */
class FilterValueError extends InternalLiquidError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, FilterValueError.prototype);
  }
  withToken(token, templateName) {
    return new LiquidFilterValueError(this.message, token, templateName);
  }
}

/**
 * An error thrown when there's a problem with one or more filter arguments.
 */
class FilterArgumentError extends InternalLiquidError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, FilterArgumentError.prototype);
  }
  withToken(token, templateName) {
    return new LiquidFilterArgumentError(this.message, token, templateName);
  }
}

/**
 * An error thrown when a tag or filter are given an argument of an unacceptable type.
 */
class InternalTypeError extends InternalLiquidError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, InternalTypeError.prototype);
  }
  withToken(token, templateName) {
    return new LiquidTypeError(this.message, token, templateName);
  }
}
class InternalSyntaxError extends InternalLiquidError {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, InternalSyntaxError.prototype);
  }
  withToken(token, templateName) {
    return new LiquidSyntaxError(this.message, token, templateName);
  }
}
class LiquidInterrupt extends Error {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, LiquidInterrupt.prototype);
  }
}

/**
 * An error thrown to indicate a Liquid for loop should be broken.
 */
class BreakIteration extends LiquidInterrupt {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, BreakIteration.prototype);
  }
  withToken(token, templateName) {
    return new OrphanedBreakTagError(this.message, token, templateName);
  }
}

/**
 * An error thrown to indicate a Liquid for loop should continue to the next iteration.
 */
class ContinueIteration extends LiquidInterrupt {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, ContinueIteration.prototype);
  }
  withToken(token, templateName) {
    return new OrphanedContinueTagError(this.message, token, templateName);
  }
}
class StopRender extends LiquidInterrupt {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, StopRender.prototype);
  }
}
function _message(message, token, templateName) {
  return `${message} (${templateName || "<string>"}:${token.lineNumber()})`;
}

/**
 * An error thrown during static template analysis. Indicates a `Node` or `Expression`
 * could not be visited.
 */
class TemplateTraversalError extends Error {
  constructor(message) {
    super(message);
    this.message = message;
    Object.setPrototypeOf(this, TemplateTraversalError.prototype);
  }
}

const Missing = Symbol.for("liquid.context.missing");
const chainPush = Symbol.for("liquid.context.chain_push");
const chainPop = Symbol.for("liquid.context.chain_pop");
const chainSize = Symbol.for("liquid.context.chain_size");
const ChainObjects = Symbol.for("liquid.context.chain_objects");
class ChainObject {
  constructor() {
    for (var _len = arguments.length, objects = new Array(_len), _key = 0; _key < _len; _key++) {
      objects[_key] = arguments[_key];
    }
    this._objects = objects.length ? objects.reverse() : [];
  }
  [chainPush](obj) {
    this[ChainObjects].push(obj);
  }
  [chainPop]() {
    return this[ChainObjects].pop();
  }
  [chainSize]() {
    return this[ChainObjects].length;
  }
  get [ChainObjects]() {
    return this._objects;
  }
}
const chainObjectHandler = {
  get(target, prop) {
    if (prop === chainPush || prop === chainPop || prop === chainSize || prop === ChainObjects) {
      return Reflect.get(target, prop);
    }
    for (let i = target[ChainObjects].length - 1; i >= 0; i--) {
      if (target[ChainObjects][i] instanceof ChainObject && prop in target[ChainObjects][i]) {
        return Reflect.get(target[ChainObjects][i], prop);
      }
      if (Object.prototype.hasOwnProperty.call(target[ChainObjects][i], prop)) return Reflect.get(target[ChainObjects][i], prop);
    }
    return Missing;
  },
  has(target, prop) {
    for (let i = target[ChainObjects].length - 1; i >= 0; i--) {
      if (target[ChainObjects][i] instanceof ChainObject) {
        return prop in target[ChainObjects][i];
      }
      if (Object.prototype.hasOwnProperty.call(target[ChainObjects][i], prop)) return true;
    }
    return false;
  },
  set() {
    throw new ReadOnlyObjectChainError("chains objects are read only");
  }
};

/**
 *
 * @param objects -
 * @returns
 */
function chainObjects() {
  for (var _len2 = arguments.length, objects = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
    objects[_key2] = arguments[_key2];
  }
  return new Proxy(new ChainObject(...objects), chainObjectHandler);
}

/**
 * A symbol that specifies a function valued property that is called to
 * convert an object to its corresponding Liquid value.
 */
const toLiquid = Symbol.for("liquid.drop.liquid");
/**
 * A type predicate for the `Liquidable` interface.
 * @param value - A value that may or may not implement the `Liquidable` interface.
 * @returns `true` if the argument value implements the `Liquidable`
 * interface, `false` otherwise.
 */
function isLiquidable(value) {
  return isObject$1(value) && toLiquid in value && typeof Reflect.get(value, toLiquid) === "function";
}

/**
 * A symbol that specifies a function valued property that is called to
 * convert an object to its corresponding Liquid value.
 */
const toLiquidSync = Symbol.for("liquid.drop.liquidSync");
/**
 * A type predicate for the `LiquidableSync` interface.
 * @param value - A value that may or may not implement the `LiquidableSync`
 * interface.
 * @returns `true` if the argument value implements the `LiquidableSync`
 * interface, `false` otherwise.
 */
function isLiquidableSync(value) {
  return isObject$1(value) && toLiquidSync in value && typeof Reflect.get(value, toLiquid) === "function";
}

/**
 * A symbol that specifies a function valued property that is called to
 * convert an object to its corresponding Liquid primitive value.
 */
const toLiquidPrimitive = Symbol.for("liquid.drop.primitive");
/**
 * A type predicate for the `LiquidPrimitive` interface.
 * @param value - A value that may or may not implement the `LiquidPrimitive` interface.
 * @returns `true` if the argument value implements the `LiquidPrimitive`
 * interface, `false` otherwise.
 */
function isLiquidPrimitive(value) {
  return isObject$1(value) && toLiquidPrimitive in value && typeof Reflect.get(value, toLiquidPrimitive) === "function";
}

/**
 * A symbol that specifies a function valued property that is called to
 * convert an object to its Liquid specific string representation.
 */
const toLiquidString = Symbol.for("liquid.drop.string");
/**
 * A type predicate for the `LiquidStringable` interface.
 * @param value - A value that may or may not implement the `LiquidStringable` interface.
 * @returns `true` if the argument value implements the `LiquidStringable`
 * interface, `false` otherwise.
 */
function isLiquidStringable(value) {
  return isObject$1(value) && toLiquidString in value && typeof Reflect.get(value, toLiquidString) === "function";
}

/**
 * A symbol that specifies a function valued property that is called to
 * convert an object to an HTML-safe string representation.
 */
const toLiquidHtml = Symbol.for("liquid.drop.html");
/**
 * A type predicate for the `LiquidHTMLable` interface.
 * @param value - A value that may or may not implement the `LiquidHTMLable` interface.
 * @returns `true` if the argument value implements the `LiquidHTMLable`
 * interface, `false` otherwise.
 */
function isLiquidHTMLable(value) {
  return isObject$1(value) && toLiquidHtml in value && typeof Reflect.get(value, toLiquidHtml) === "function";
}

/**
 * A symbol that specifies a function valued property that is called to
 * test a method name against a set of whitelisted methods that Liquid
 * can call.
 */
const isLiquidCallable = Symbol.for("liquid.drop.callable");
/**
 * A type predicate for the `LiquidCallable` interface.
 * @param value - A value that may or may not implement the `LiquidCallable` interface.
 * @returns `true` if the argument value implements the `LiquidCallable` interface,
 * `false` otherwise.
 */
function hasLiquidCallable(value) {
  return isObject$1(value) && isLiquidCallable in value;
}

/**
 * A symbol that specifies a function valued property that is called in
 * the event that a property is missing from an object.
 */
const liquidDispatch = Symbol.for("liquid.drop.dispatch");
/**
 * A type predicate for the `LiquidDispatchable` interface.
 * @param value - A value that may or may not implement the `LiquidDispatchable` interface.
 * @returns `true` if the argument value implements the `LiquidDispatchable` interface,
 * `false` otherwise.
 */
function isLiquidDispatchable(value) {
  return isObject$1(value) && liquidDispatch in value;
}
const liquidDispatchSync = Symbol.for("liquid.drop.dispatchSync");
function isLiquidDispatchableSync(value) {
  return isObject$1(value) && liquidDispatchSync in value;
}
function isObject$1(value) {
  const _type = typeof value;
  return value !== null && _type === "object" || _type === "function" ? true : false;
}

Decimal.set({
  precision: 16
});

// eslint-disable-next-line @typescript-eslint/ban-types

class LiquidNumber {
  constructor(val) {
    this.n = new Decimal(val);
  }
  valueOf() {
    return this.n.toNumber();
  }
  abs() {
    const result = this.n.abs();
    return isFloat(this) ? new Float(result) : new Integer(result);
  }
  ceil() {
    return new Integer(this.n.ceil());
  }
  div(n) {
    const _n = parseNumberT(n);
    return isInteger(this) && isInteger(_n) ? new Integer(this.n.dividedToIntegerBy(_n.n)) : new Float(this.n.dividedBy(_n.n));
  }
  eq(n) {
    return this.n.eq(parseNumberT(n).n);
  }
  floor() {
    return new Integer(this.n.floor());
  }
  gt(n) {
    return this.n.gt(parseNumberT(n).n);
  }
  gte(n) {
    return this.n.gte(parseNumberT(n).n);
  }
  lt(n) {
    return this.n.lt(parseNumberT(n).n);
  }
  lte(n) {
    return this.n.lte(parseNumberT(n).n);
  }
  max(n) {
    const _n = parseNumberT(n);
    return _n.gt(this) ? _n : this;
  }
  min(n) {
    const _n = parseNumberT(n);
    return _n.lt(this) ? _n : this;
  }
  minus(n) {
    const _n = parseNumberT(n);
    const result = this.n.minus(_n.n);
    return isFloat(this) || isFloat(_n) ? new Float(result) : new Integer(result);
  }
  mod(n) {
    const _n = parseNumberT(n);
    const result = this.n.mod(_n.n);
    return isFloat(this) || isFloat(_n) ? new Float(result) : new Integer(result);
  }
  plus(n) {
    const _n = parseNumberT(n);
    const result = this.n.plus(_n.n);
    return isFloat(this) || isFloat(_n) ? new Float(result) : new Integer(result);
  }
  round(decimalPlaces) {
    return decimalPlaces === undefined || this.n.eq(0) ? new Integer(this.n.toDecimalPlaces(0, Decimal.ROUND_HALF_CEIL)) : new Float(this.n.toDecimalPlaces(decimalPlaces, Decimal.ROUND_HALF_CEIL));
  }
  times(n) {
    const _n = parseNumberT(n);
    const result = this.n.times(_n.n);
    return isFloat(this) || isFloat(_n) ? new Float(result) : new Integer(result);
  }
  trunc() {
    return new Integer(this.n.trunc());
  }
  isFinite() {
    return this.n.isFinite();
  }
}
class Float extends LiquidNumber {
  float = true;
  toString() {
    const s = this.n.toString();
    return s.toString().indexOf(".") === -1 ? `${s}.0` : s;
  }
}
class Integer extends LiquidNumber {
  float = false;
  toString() {
    return this.n.toString();
  }
}
/**
 * A type predicate for Liquid's number wrapper types.
 */
function isNumberT(val) {
  return val instanceof Integer || val instanceof Float;
}

/**
 * A type predicate for Liquid's `Integer` type.
 */
function isInteger(val) {
  return val instanceof Integer && !isNaN(val.valueOf());
}

/**
 * A type predicate for Liquid's `Float` type.
 */
function isFloat(val) {
  return val instanceof Float;
}
function isPrimitiveNumber$1(value) {
  return typeof value === "number";
}
function isString$1(value) {
  return typeof value === "string";
}
const ZERO = new Integer(0);
const NAN = new Integer(NaN);
function _stringToNumberT(s) {
  return s.indexOf(".") === -1 ? new Integer(Number(s)) : new Float(Number(s));
}

/**
 * A type predicate for valid inputs to the `parseNumberT` function.
 *
 * @param val - Any value.
 * @returns `true` if the input value can be passed to `parseNumberT`.
 */
function isN(val) {
  return isNumberT(val) || isString$1(val) || isFinite(val);
}

/**
 * Parse a string, primitive number or Number object to a Liquid
 * integer or float.
 *
 * @param n - A number or string representation of a number.
 * @returns A wrapped number representing a Liquid integer or float.
 */
function parseNumberT(n) {
  if (n instanceof LiquidNumber) return n;
  if (n instanceof Number) return Number.isInteger(n) ? new Integer(n.valueOf()) : new Float(n.valueOf());
  if (isPrimitiveNumber$1(n)) return Number.isInteger(n) ? new Integer(n) : new Float(n);
  if (isString$1(n)) return _stringToNumberT(n);
  return n;
}

/**
 * The base class for objects wrapping undefined variables found in
 * Liquid templates.
 */
class Undefined {
  /**
   * Create a new `Undefined` object.
   *
   * @param name - The name of the undefined variable.
   * @param object - The target object which does not have a property
   * with the given name.
   * @param hint - Optionally override the default "undefined" message.
   */
  constructor(name, object, hint) {
    this.name = name;
    this.object = object;
    this.hint = hint;
  }
  toString() {
    return `Undefined(${this.name})`;
  }

  /**
   * Prompt the undefined type to throw an error.
   */
  poke() {
    this.toString();
  }
}

/**
 * An {@link Undefined} type that throws an error whenever it appears
 * in a Liquid expression.
 */
class StrictUndefined extends Undefined {
  static from(name) {
    return new StrictUndefined(name);
  }
  toString() {
    throw new InternalUndefinedError(this.name);
  }
  poke() {
    throw new InternalUndefinedError(this.name);
  }
  valueOf() {
    throw new InternalUndefinedError(this.name);
  }
  [Symbol.iterator]() {
    throw new InternalUndefinedError(this.name);
  }
  [toLiquidPrimitive]() {
    throw new InternalUndefinedError(this.name);
  }
  async [liquidDispatch]() {
    throw new InternalUndefinedError(this.name);
  }
  [liquidDispatchSync]() {
    throw new InternalUndefinedError(this.name);
  }
  get first() {
    throw new InternalUndefinedError(this.name);
  }
  get last() {
    throw new InternalUndefinedError(this.name);
  }
  get size() {
    throw new InternalUndefinedError(this.name);
  }
}

/**
 * An {@link Undefined} type that evaluates to an empty string or `0`,
 * and can be indexed and iterated over without error.
 */
class LaxUndefined extends Undefined {
  static from(name) {
    return new LaxUndefined(name);
  }
  toString() {
    return "";
  }
  poke() {
    return;
  }
  valueOf() {
    return "";
  }
  async [liquidDispatch]() {
    return this;
  }
  [liquidDispatchSync]() {
    return this;
  }
  [Symbol.iterator]() {
    return [].values();
  }
  [Symbol.toPrimitive](hint) {
    if (hint === "number") {
      return 0;
    }
    if (hint === "string") {
      return "";
    }
    return null;
  }
  get first() {
    return this;
  }
  get last() {
    return this;
  }
  get size() {
    return this;
  }
}

/**
 * An {@link Undefined} type that will evaluate to `false` in a boolean
 * expression and throw an error when iterated, output or when accessing
 * its properties.
 */
class FalsyStrictUndefined extends Undefined {
  static from(name) {
    return new FalsyStrictUndefined(name);
  }
  toString() {
    throw new InternalUndefinedError(this.name);
  }
  poke() {
    throw new InternalUndefinedError(this.name);
  }
  valueOf() {
    throw new InternalUndefinedError(this.name);
  }
  [Symbol.iterator]() {
    throw new InternalUndefinedError(this.name);
  }
  async [liquidDispatch]() {
    throw new InternalUndefinedError(this.name);
  }
  [liquidDispatchSync]() {
    throw new InternalUndefinedError(this.name);
  }
  get first() {
    throw new InternalUndefinedError(this.name);
  }
  get last() {
    throw new InternalUndefinedError(this.name);
  }
  get size() {
    throw new InternalUndefinedError(this.name);
  }
}

/**
 * A type predicate for the primitive boolean.
 * @param value - Any value
 * @returns `true` if the value is a primitive boolean.
 */
function isBoolean(value) {
  return typeof value == "boolean";
}

/**
 * A type predicate for the primitive string.
 * @param value - Any value
 * @returns `true` if the value is a primitive string.
 */
function isString(value) {
  return typeof value === "string";
}

/**
 * A type predicate for the primitive Symbol.
 * @param value - Any value
 * @returns `true` if the value is a symbol.
 */
function isSymbol(value) {
  return typeof value === "symbol";
}

/**
 * A type predicate for the Array object.
 * @param value - Any value
 * @returns `true` if the value is an array.
 */
function isArray(value) {
  return Array.isArray(value);
}

/**
 * A type predicate for Object.
 * @param value - Any value
 * @returns `true` if the value is an object.
 */
function isObject(value) {
  const _type = typeof value;
  return value !== null && _type === "object" || _type === "function" ? true : false;
}

/**
 * A type predicate for Function.
 * @param value - Any value
 * @returns `true` if the value is a function.
 */
function isFunction(value) {
  return typeof value === "function";
}

/**
 * A type predicate for an object property key.
 * @param value - Any value
 * @returns `true` if the value is a string, number or symbol.
 */
function isPropertyKey(value) {
  const _type = typeof value;
  return _type === "string" || _type === "number" || _type === "symbol" ? true : false;
}

/**
 * A type predicate for a primitive number or the wrapped, Liquid number type.
 * @param value - Any value
 * @returns `true` if the value is a number or `NumberT`.
 */
function isNumber(value) {
  return typeof value === "number" || isNumberT(value);
}

/**
 * A type predicate for the number primitive.
 * @param value - Any value
 * @returns `true` if the value is a primitive number.
 */
function isPrimitiveNumber(value) {
  return typeof value === "number";
}

/**
 * A type predicate for a primitive number that is an integer.
 * @param value - Any value
 * @returns `true` if the value is a primitive number and is an integer.
 */
function isPrimitiveInteger(value) {
  return typeof value === "number" && Number.isInteger(value);
}
function isComparable(value) {
  return isNumber(value) || isString(value);
}

/**
 * Stringify a value following Liquid semantics.
 * @param value - Any value
 * @returns A Liquid string representation of the value.
 */
function liquidStringify(value) {
  if (value === null || value === undefined) return "";
  if (value instanceof Undefined) return value.toString();
  if (isLiquidStringable(value)) return value[toLiquidString]();
  if (isArray(value)) return value.join("");
  const s = String(value);
  return s === "[object Object]" ? "{}" : s;
}

/**
 * A type predicate for the Iterable interface.
 * @param value - Any value
 * @returns `true` if the value is iterable.
 */
function isIterable(value) {
  return isObject(value) ? Symbol.iterator in value : false;
}

/**
 * A type predicate for `undefined` or Liquid's undefined wrapper.
 * @param value - Any value
 * @returns `true` if the value is `undefined` or a subclass of `Undefined`.
 */
function isUndefined(value) {
  return value === undefined || value instanceof Undefined;
}
// XXX: iterables?

/**
 * A type predicate for objects that a considered array-like in Liquid.
 * @param value - Any value
 * @returns `true` if the value is considered array-like, `false` otherwise.
 */
function isLiquidArrayLike(value) {
  return isArray(value);
}

/**
 * A plain object with string indexes (not an array).
 */

/**
 * A type predicate for the `ContextScope` type.
 * @param value - Any value
 * @returns `true` if the value is a non-array object.
 */
function isContextScope(value) {
  return isObject(value) && !isArray(value);
}

var types = /*#__PURE__*/Object.freeze({
  __proto__: null,
  isArray: isArray,
  isBoolean: isBoolean,
  isComparable: isComparable,
  isContextScope: isContextScope,
  isFunction: isFunction,
  isIterable: isIterable,
  isLiquidArrayLike: isLiquidArrayLike,
  isNumber: isNumber,
  isObject: isObject,
  isPrimitiveInteger: isPrimitiveInteger,
  isPrimitiveNumber: isPrimitiveNumber,
  isPropertyKey: isPropertyKey,
  isString: isString,
  isSymbol: isSymbol,
  isUndefined: isUndefined,
  liquidStringify: liquidStringify
});

const EXTENDS_REGISTER$1 = Symbol.for("liquid.tags.extends");
/**
 * A RenderContext manages template scopes, internal registers and
 * access to the bound environment during the rendering of a template.
 *
 * A new RenderContext is created automatically every time `render()`
 * is called on a `Template`, so you probably don't want to instantiate
 * it directly.
 */
class RenderContext {
  /**
   * A distinct scope for counters set using the `increment` and
   * `decrement` tags.
   */
  counters = {};

  /**
   * A stack of `ForLoopDrop` objects. Used to populate the `parentloop`
   * property of a `ForLoopDrop`.
   */
  forLoops = [];

  /**
   * A register is a Map used by tags and/or filters to store arbitrary
   * values that are not available to template authors. Use `getRegister()`
   * to obtain a named register.
   */
  registers = new Map();

  /**
   * A namespace for variables set using the `assign` or `capture` tags.
   */
  locals = {};

  /**
   * A non-specific indication of how much the local namespace has been used.
   */

  /**
   * A loop iteration count carried over from a parent context, if this one has
   * been copied. This helps us adhere to loop iteration limits in templates
   * rendered with the `render` tag.
   */

  /**
   * A chain of scopes. When resolving names, each scope in the chain is
   * searched in order. If a new scope if pushed on to a RenderContext,
   * it is pushed to the front if this chain.
   */

  /**
   * A set of tag names that are disallowed in this render context. For
   * example, the `include` tag is not allowed in templates rendered
   * with the `render` tag.
   */

  /** The name of the template being rendered. Will be `<string>` for
   * templates parsed using `Environment.fromString()` without being
   * given a name.
   */

  /**
   * The `Template` being rendered by this render context.
   */

  /**
   * The number of times this render context has been copied or
   * extended. This helps us guard against recursive use of `include`
   * or `render` tags.
   */

  /**
   * An object containing arbitrary properties passed down from a
   * template loader. The properties of this object are not intended
   * to be accessible by template authors.
   */

  /**
   *
   * @param environment - The environment from which this context was created.
   * @param globals - Global template variables, passed down from the
   * Environment, Template, Loader and arguments to `.render()`.
   * @param options - Extra render context options.
   */
  constructor(environment) {
    let globals = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    let {
      disabledTags,
      templateName,
      copyDepth,
      loaderContext,
      localsScoreCarry,
      loopIterationCarry,
      template
    } = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    this.environment = environment;
    this.globals = globals;
    this.disabledTags = disabledTags ?? new Set();
    this.templateName = templateName ?? "<string>";
    this.template = template;
    this.copyDepth = copyDepth ?? 0;
    this.localsScore = localsScoreCarry ?? 0;
    this.loaderContext = loaderContext ?? {};
    this.loopIterationCarry = loopIterationCarry ?? 1;
    // Scopes are searched in this order.
    this.scope = chainObjects(this.locals, this.globals, BuiltIn, this.counters);
  }

  /**
   * Assign or re-assign a template local variable, probably from either the
   * `assign` or `capture` tags.
   * @param key - The name of the template local variable.
   * @param value - The value of the template local variable.
   */
  assign(key, value) {
    if (this.environment.localNamespaceLimit > -1) {
      this.localsScore += this.assignScore(key, value);
      if (this.localsScore > this.environment.localNamespaceLimit) {
        throw new MaxLocalNamespaceLimitError("local namespace limit reached");
      }
    }
    this.locals[key] = value;
  }

  /**
   * Return a size or score for the key and/or value to contribute to the local
   * namespace score. Override this to control how the local namespace score is
   * calculated.
   */
  assignScore(key, value) {
    return _assignScore(value);
  }

  /**
   * Resolve a template variable by searching the scope chain. Unlike `get`,
   * `resolve` performs a single, top level search of the scope chain. It
   * does not expect a dotted or bracketed identifier.
   * @param name - The name of the template variable to resolve.
   * @returns The value stored against the given name, or an instance of
   * the `Undefined` class defined on the attached environment.
   */
  async resolve(name) {
    const value = this.scope[name];
    if (value === Missing) return this.environment.undefinedFactory(name);
    return isLiquidable(value) ? value[toLiquid](this) : value;
  }
  resolveSync(name) {
    const value = this.scope[name];
    if (value === Missing) return this.environment.undefinedFactory(name);
    return isLiquidableSync(value) ? value[toLiquidSync](this) : value;
  }

  /**
   * Search the current scope for a template variable and, if found, follow
   * the given path. This is a bit like resolving a JSONPath expression.
   * @param name - The name of the template variable to resolve.
   * @param path - An optional array of path elements to follow.
   * @param missing - A default value used if the name and path fail to find
   * a value.
   * @returns The value at `path`, starting from the given name, or `missing`
   * otherwise. If `missing` is not given, an instance of the `Undefined`
   * class defined on the attached environment will be used.
   */
  async get(name, path) {
    let missing = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : Missing;
    let obj = await this.resolve(name);
    if (!path || !path.length) return obj;
    for (const item of path) {
      try {
        obj = await getItem$1(obj, item);
        if (isLiquidable(obj)) obj = await obj[toLiquid](this);
      } catch (error) {
        if (error instanceof InternalKeyError) {
          if (missing !== Missing) return missing;
          return this.environment.undefinedFactory(`${item}`);
        }
        throw error;
      }
    }
    return obj;
  }

  /**
   * A synchronous version of `RenderContext.get()`.
   * @see {@link get}
   */
  getSync(name, path) {
    let missing = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : Missing;
    let obj = this.resolveSync(name);
    if (!path || !path.length) return obj;
    for (const item of path) {
      try {
        obj = getItemSync(obj, item);
        if (isLiquidableSync(obj)) obj = obj[toLiquidSync](this);
      } catch (error) {
        if (error instanceof InternalKeyError) {
          if (missing !== Missing) return missing;
          return this.environment.undefinedFactory(`${item}`);
        }
        throw error;
      }
    }
    return obj;
  }

  /**
   * A convenience method for loading a template from the attached environment.
   * @param name - The name or identifier of the template to load.
   * @param loaderContext - Additional, arbitrary data that a loader can use
   * to scope or otherwise narrow its search space.
   * @returns A `Template`, ready to be rendered.
   * @throws `NoSuchTemplateError` if a template with the given name can not
   * be found.
   */
  async getTemplate(name, loaderContext) {
    return this.environment.getTemplate(name, undefined, this, this.makeLoaderContext(loaderContext));
  }

  /**
   * A synchronous version of `RenderContext.getTemplate()`.
   * @see {@link getTemplate}
   */
  getTemplateSync(name) {
    let loaderContext = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    return this.environment.getTemplateSync(name, undefined, this, this.makeLoaderContext(loaderContext));
  }

  /**
   * Merge a loader context object with the loader context already stored
   * in this render context.
   */
  makeLoaderContext(loaderContext) {
    return {
      ...this.loaderContext,
      ...loaderContext
    };
  }

  /**
   * Fetch a render context register, creating one if it does not exist.
   *
   * A register is a place for tags and/or filters to store arbitrary data,
   * without leaking said data into the template scope.
   * @param key - An identifier for the register.
   * @returns A register.
   */
  getRegister(key) {
    let reg = this.registers.get(key);
    if (reg === undefined) {
      reg = new Map();
      this.registers.set(key, reg);
    }
    return reg;
  }
  raiseForLoopLimit() {
    let length = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 1;
    if (this.environment.loopIterationLimit > -1 && this.forLoops.map(loop => loop.length).reduce((a, b) => a * b, length * this.loopIterationCarry) > this.environment.loopIterationLimit) {
      throw new MaxLoopIterationLimitError("loop iteration limit reached");
    }
  }

  /**
   * Create a new context by copying and extending this one with the given scope.
   * @param scope - A scope with which to extend the current context.
   * @param disabledTags - The names of any tags that should be disallowed in
   * the new context.
   * @param carryLoopIterations - If true, carry the loop iteration counter.
   * @param blockScope - If true, include context locals in the copy.
   * @param template - Optionally attach a new template to the returned copy.
   * @returns An extended copy of this context.
   */
  copy(scope, disabledTags) {
    let carryLoopIterations = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
    let blockScope = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
    let template = arguments.length > 4 ? arguments[4] : undefined;
    if (this.copyDepth + 1 > this.environment.maxContextDepth) throw new MaxContextDepthError("maximum context depth reached, possible recursive render");
    const loopIterationCarry = carryLoopIterations ? this.forLoops.map(loop => loop.length).reduce((a, b) => a * b, this.loopIterationCarry) : 1;
    let ctx;
    if (blockScope) {
      ctx = new RenderContext(this.environment, chainObjects(scope, this.scope),
      // include locals
      {
        templateName: this.templateName,
        disabledTags: new Set(disabledTags),
        copyDepth: this.copyDepth + 1,
        localsScoreCarry: this.localsScore,
        loopIterationCarry
      });
      // XXX: bit of a hack
      ctx.registers.set(EXTENDS_REGISTER$1, this.getRegister(EXTENDS_REGISTER$1));
    } else {
      ctx = new RenderContext(this.environment, chainObjects(scope, this.globals), {
        templateName: this.templateName,
        disabledTags: new Set(disabledTags),
        copyDepth: this.copyDepth + 1,
        localsScoreCarry: this.localsScore,
        loopIterationCarry
      });
    }
    ctx.template = template || this.template;
    return ctx;
  }

  /**
   * Extend the current scope for the duration of the given callback function.
   *
   * @param scope - Variables with which to extend the
   * @param callback - A function to call with the extended scope.
   * @returns The callback functions return value.
   */
  async extend(scope, callback, template) {
    if (this.scope[chainSize]() > this.environment.maxContextDepth) throw new MaxContextDepthError("maximum context depth reached");
    const _template = this.template;
    if (template !== undefined) this.template = template;
    this.scope[chainPush](scope);
    try {
      return await callback();
    } finally {
      if (template !== undefined) this.template = _template;
      this.scope[chainPop]();
    }
  }

  /**
   * A synchronous version of {@link extend}.
   */
  extendSync(scope, callback, template) {
    if (this.scope[chainSize]() > this.environment.maxContextDepth) throw new MaxContextDepthError("maximum context depth reached");
    const _template = this.template;
    if (template !== undefined) this.template = template;
    this.scope[chainPush](scope);
    try {
      return callback();
    } finally {
      if (template !== undefined) this.template = _template;
      this.scope[chainPop]();
    }
  }
}

/**
 * Get a property of an object while adhering to Liquid semantics.
 * @param obj - An object that may or may not implement some of the Drop
 * protocol.
 * @param item - The item to get from the object.
 * @returns An unknown value.
 * @throws InternalKeyError if the item does not exist on the object or
 * is not allowed in Liquid.
 */
// eslint-disable-next-line sonarjs/cognitive-complexity
function getItemSync(obj, item) {
  if (obj === null) throw new InternalKeyError(`can't get property of null`);
  if (item === null) throw new InternalKeyError(`can't read null property`);

  // `toLiquidPrimitive` is part of the Drop protocol. If defined, an
  // object can be used as an array index, or compared to to a boolean,
  // for example.
  if (isLiquidPrimitive(item)) item = item[toLiquidPrimitive]();
  if (!isPropertyKey(item)) throw new InternalKeyError(`${item} is not a valid property key`);

  // Special, built-in properties.
  if (item === "size") return getSize(obj);
  if (item === "first") return getFirst(obj);
  if (item === "last") return getLast(obj);

  // Access arrays using positive or negative integers, or enumerable
  // properties set on array sub classes.
  if (isArray(obj)) {
    // Integers are OK
    if (isNumber(item) && item < 0) {
      return obj[item + obj.length];
    }

    // .length is not OK
    if (Object.propertyIsEnumerable.call(obj, item)) {
      return Reflect.get(obj, item);
    }
    throw new InternalKeyError(`can't read non-enumerable property '${String(item)}' of Array`);
  }
  if (typeof obj === "object") {
    if (item === "__proto__" || item === "constructor") {
      throw new InternalKeyError(`can't access property '${item}'`);
    }
    if (item in obj) {
      const result = obj[item];
      // Functions will only be called if they are explicitly whitelisted.
      if (isFunction(result)) {
        // `liquidCallable` is part of the Drop protocol. If defined it
        // should return `true` if the given function name is allowed
        // to be called.
        if (hasLiquidCallable(obj) && obj[isLiquidCallable](item)) return Reflect.apply(result, obj, []);

        // Pretend the function does not exist.
        throw new InternalKeyError(`function '${String(item)}' is not liquid callable`);
      }
      return result;
    } else if (isLiquidDispatchableSync(obj)) {
      return obj[liquidDispatchSync](item);
    }
  }
  throw new InternalKeyError(`${obj}[${String(item)}]`);
}

// TODO: Refactor to avoid duplicated code. The only difference between
// getItem and getItemSync is the calls to liquidDispatch and liquidDispatchSync.

/**
 * An asynchronous version of `getItemSync()`.
 */
// eslint-disable-next-line sonarjs/cognitive-complexity
async function getItem$1(obj, item) {
  if (obj === null) throw new InternalKeyError(`can't get property of null`);
  if (item === null) throw new InternalKeyError(`can't read null property`);

  // `toLiquidPrimitive` is part of the Drop protocol. If defined, an
  // object can be used as an array index, or compared to to a boolean,
  // for example.
  if (isLiquidPrimitive(item)) item = item[toLiquidPrimitive]();
  if (!isPropertyKey(item)) throw new InternalKeyError(`${item} is not a valid property key`);

  // Special, built-in properties.
  if (item === "size") return getSize(obj);
  if (item === "first") return getFirst(obj);
  if (item === "last") return getLast(obj);

  // Access arrays using positive or negative integers, or enumerable
  // properties set on array sub classes.
  if (isArray(obj)) {
    // Integers are OK
    if (isNumber(item) && item < 0) {
      return obj[item + obj.length];
    }

    // .length is not OK
    if (Object.propertyIsEnumerable.call(obj, item)) {
      return Reflect.get(obj, item);
    }
    throw new InternalKeyError(`can't read non-enumerable property '${String(item)}' of Array`);
  }
  if (typeof obj === "object") {
    if (item === "__proto__" || item === "constructor") {
      throw new InternalKeyError(`can't access property '${item}'`);
    }
    if (item in obj) {
      const result = obj[item];
      // Functions will only be called if they are explicitly whitelisted.
      if (isFunction(result)) {
        // `liquidCallable` is part of the Drop protocol. If defined it
        // should return `true` if the given function name is allowed
        // to be called.
        if (hasLiquidCallable(obj) && obj[isLiquidCallable](item)) return Reflect.apply(result, obj, []);

        // Pretend the function does not exist.
        throw new InternalKeyError(`function '${String(item)}' is not liquid callable`);
      }
      return result;
    } else if (isLiquidDispatchable(obj)) {
      return obj[liquidDispatch](item);
    } else if (isLiquidDispatchableSync(obj)) {
      return obj[liquidDispatchSync](item);
    }
  }
  throw new InternalKeyError(`${obj}[${String(item)}]`);
}
function getSize(obj) {
  if (isNumberT(obj) || isPrimitiveNumber(obj)) {
    // XXX: This is not necessarily the case for wrapped decimal numbers
    return 8;
  } else if (isArray(obj) || isString(obj)) {
    return obj.length;
  } else if (isObject(obj)) {
    if ("size" in obj) {
      const size = Reflect.get(obj, "size");
      if (isPrimitiveNumber(size) || isInteger(size)) {
        return size;
      }
    } else {
      return Object.keys(obj).length;
    }
  }
  throw new InternalKeyError(`${obj}[size]`);
}

// TODO: First/Last of Map?

function getFirst(obj) {
  // First of a string is not supported.
  if (isString(obj)) return null;
  if (isObject(obj) && "first" in obj) return Reflect.get(obj, "first");
  // Iterable objects are OK.
  if (isObject(obj) && isIterable(obj)) return obj[Symbol.iterator]().next().value;
  // XXX: Object.entries does not guarantee insertion order.
  if (isObject(obj)) {
    const val = Object.entries(obj).entries().next().value;
    return val === undefined ? null : val[1];
  }
  return null;
}
function getLast(obj) {
  // Last of a string is not supported.
  if (isString(obj)) return null;
  if (isObject(obj) && "last" in obj) return Reflect.get(obj, "last");
  if (isArray(obj)) return obj[obj.length - 1];
  return null;
}

/**
 * An object implementing the special, built-in `now` and `today` objects.
 */
const BuiltIn = {
  now: () => new Date(),
  today: () => new Date()
};

// eslint-disable-next-line sonarjs/cognitive-complexity
function _assignScore(obj) {
  // TODO: drop protocol override?
  if (isString(obj)) return obj.length * 2;
  if (isArray(obj)) {
    return obj.reduce((a, b) => a + _assignScore(b), 0);
  }
  if (obj instanceof Set) {
    let sum = 0;
    for (const val of obj.keys()) {
      sum += _assignScore(val);
    }
    return sum;
  }
  if (obj instanceof Map) {
    let sum = 0;
    for (const val of obj.entries()) {
      sum += _assignScore(val);
    }
    return sum;
  }
  if (isIterable(obj)) {
    let sum = 0;
    for (const val of obj) {
      sum += _assignScore(val);
    }
    return sum;
  }
  if (isObject(obj)) {
    const seen = new Set();
    const stack = [obj];
    let sum = 0;
    while (stack.length) {
      const val = stack.pop();
      if (typeof val === "object") {
        if (!seen.has(val)) {
          seen.add(val);
          for (const [k, v] of Object.entries(obj)) {
            sum += _assignScore(k);
            stack.push(v);
          }
        }
      } else {
        sum += _assignScore(val);
      }
    }
    return sum;
  }
  return 1;
}

// Adapted from https://github.com/mathiasbynens/he/blob/master/src/he.js
// Licence https://github.com/mathiasbynens/he/blob/master/LICENSE-MIT.txt

const reEscape = /["&'<>`]/g;

// This map has been updated to mimic the reference implementation's mapping
// of characters to escape codes.
const escapeMap = {
  '"': "&#34;",
  "&": "&amp;",
  "'": "&#39;",
  "<": "&lt;",
  // See https://mathiasbynens.be/notes/ambiguous-ampersands: in HTML, the
  // following is not strictly necessary unless it’s part of a tag or an
  // unquoted attribute value. We’re only escaping it to support those
  // situations, and for XML support.
  ">": "&gt;",
  // In Internet Explorer ≤ 8, the backtick character can be used
  // to break out of (un)quoted attribute values or HTML comments.
  // See http://html5sec.org/#102, http://html5sec.org/#108, and
  // http://html5sec.org/#133.
  "`": "&#96;"
};
const reUnescape = /&(#34|amp|#39|lt|gt|#96);/gi;
const unescapeMap = {
  "&#34;": '"',
  "&amp;": "&",
  "&#39;": "'",
  "&lt;": "<",
  "&gt;": ">",
  "&#96;": "`"
};

/**
 *
 * @param s -
 * @returns
 */
function escape$1(s) {
  return s.replace(reEscape, c => escapeMap[c]);
}

/**
 *
 * @param s -
 * @returns
 */
function unescape(s) {
  return s.replace(reUnescape, m => unescapeMap[m]);
}

/**
 * A string wrapper that is safe to output as HTML, either because it
 * has already been escaped or is considered safe without escaping.
 */
class Markup {
  #s;

  /**
   * `Markup` constructor.
   * @param s - Escaped or safe markup text.
   */
  constructor(s) {
    this.#s = s;
  }

  /**
   * A `Markup` factory function.
   *
   * @param s - Escaped or safe markup text.
   * @returns The input string inside a `Markup` wrapper.
   */
  static from(s) {
    return s instanceof Markup ? s : new Markup(s);
  }

  /**
   * A `Markup` factory function that will escape the input value if it is
   * not already `Markup`.
   *
   * @param value - Any value. If it's already `Markup`, it will be returned
   * unchanged. Otherwise it will be converted to a string and escaped.
   * @returns A string representation of the input value after HTML-escaping.
   */
  static escape(value) {
    if (value instanceof Markup) return value;
    return new Markup(escape$1(liquidStringify(value)));
  }
  get [Symbol.toStringTag]() {
    return "Markup";
  }
  [Symbol.toPrimitive](hint) {
    return hint === "number" ? null : this.#s;
  }
  [toLiquidHtml]() {
    return this.#s;
  }
  [toLiquidString]() {
    return this.#s;
  }
  toString() {
    return `Markup(${this.#s})`;
  }
}

/**
 * Construct a new `Range` object, a lazy sequence of integer.
 */

function range() {
  let start = 0;
  let stop;
  for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }
  if (args.length === 2) {
    [start, stop] = args;
  } else {
    [stop] = args;
  }
  return new Range(start, stop);
}
class Range {
  constructor(start, stop) {
    this.start = Math.trunc(start);
    this.stop = Math.trunc(stop);
    this.length = this.stop - this.start + 1;
  }
  *[Symbol.iterator]() {
    // Ranges are inclusive of stop.
    for (let i = this.start; i <= this.stop; i++) yield i;
  }
  equals(other) {
    return other instanceof Range && this.start === other.start && this.stop === other.stop;
  }
  toString() {
    return `${this.start}..${this.stop}`;
  }
}

class Nil {
  async evaluate() {
    return null;
  }
  evaluateSync() {
    return null;
  }
  equals(other) {
    return other === null || other === undefined || other instanceof Nil ? true : false;
  }
  toString() {
    return "";
  }
  children() {
    return [];
  }
}
const NIL = new Nil();
class Empty {
  async evaluate() {
    return this;
  }
  evaluateSync() {
    return this;
  }
  equals(other) {
    if (other instanceof Empty) return true;
    if (other === null) return false;
    if (isString(other) || isArray(other)) return !other.length;
    if (other instanceof Map || other instanceof Set) return other.size === 0;
    if (isObject(other)) {
      for (const i in other) return false;
      return true;
    }
    return false;
  }
  toString() {
    return "empty";
  }
  children() {
    return [];
  }
}
const EMPTY = new Empty();
class Blank {
  async evaluate() {
    return this;
  }
  evaluateSync() {
    return this;
  }
  equals(other) {
    if (other instanceof Empty) return false;
    if (other instanceof Blank) return false;
    if (other === null) return true;
    if (isString(other)) return !other.trim().length;
    if (isArray(other)) return !other.length;
    if (isObject(other)) {
      for (const i in other) return false;
      return true;
    }
    return false;
  }
  toString() {
    return "blank";
  }
  children() {
    return [];
  }
}
const BLANK = new Blank();
class Continue {
  async evaluate() {
    return this;
  }
  evaluateSync() {
    return this;
  }
  equals(other) {
    return other instanceof Continue;
  }
  toString() {
    return "continue";
  }
  children() {
    return [];
  }
}
const CONTINUE = new Continue();
class Literal {
  constructor(value) {
    this.value = value;
  }

  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  async evaluate(context) {
    return this.value;
  }

  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  evaluateSync(context) {
    return this.value;
  }
  equals(other) {
    return this.value === other;
  }
  toString() {
    return `${this.value}`;
  }
  children() {
    return [];
  }
}
class BooleanLiteral extends Literal {
  equals(other) {
    return other instanceof BooleanLiteral && this.value === other.value;
  }
}
const TRUE = new BooleanLiteral(true);
const FALSE = new BooleanLiteral(false);
class StringLiteral extends Literal {
  async evaluate(context) {
    return this.evaluateSync(context);
  }
  evaluateSync(context) {
    return context.environment.autoEscape ? Markup.from(this.value) : this.value;
  }
  equals(other) {
    return other instanceof StringLiteral && this.value === other.value;
  }
}
class IntegerLiteral extends Literal {
  equals(other) {
    return other instanceof IntegerLiteral && this.value === other.value;
  }
  toString() {
    return this.value.toString();
  }
}
class FloatLiteral extends Literal {
  equals(other) {
    return other instanceof FloatLiteral && this.value === other.value;
  }
  toString() {
    return this.value.toString();
  }
}
class RangeLiteral {
  constructor(start, stop) {
    this.start = start;
    this.stop = stop;
  }
  async evaluate(context) {
    let start = Number(this.start instanceof Literal ? this.start.evaluateSync(context) : await this.start.evaluate(context));
    let stop = Number(this.stop instanceof Literal ? this.stop.evaluateSync(context) : await this.stop.evaluate(context));
    if (isNaN(start.valueOf())) start = 0;
    if (isNaN(stop.valueOf())) stop = 0;
    if (start > stop) return range(-1);
    return range(start.valueOf(), stop.valueOf());
  }
  evaluateSync(context) {
    let start = Number(this.start.evaluateSync(context));
    let stop = Number(this.stop.evaluateSync(context));
    if (isNaN(start.valueOf())) start = 0;
    if (isNaN(stop.valueOf())) stop = 0;
    if (start > stop) return range(-1);
    return range(start.valueOf(), stop.valueOf());
  }
  equals(other) {
    return other instanceof RangeLiteral && this.start === other.start && this.stop === other.stop;
  }
  toString() {
    return `(${this.start}..${this.stop})`;
  }
  children() {
    return [this.start, this.stop];
  }
}
class IdentifierPathElement extends Literal {
  equals(other) {
    return other instanceof IdentifierPathElement && this.value === other.value;
  }
}
class Identifier {
  constructor(root, path) {
    this.root = root;
    this.path = path;
  }
  equals(other) {
    return other instanceof Identifier && this.root === other.root && this.path === other.path;
  }
  toString() {
    const buf = [];
    if (this.root !== null) {
      buf.push(this.root);
    }
    let part;
    for (const e of this.path) {
      if (e instanceof Identifier) {
        buf.push(`[${e}]`);
      } else {
        part = String(e);
        if (part.includes(".")) {
          buf.push(`["${part}"]`);
        } else {
          buf.push(part);
        }
      }
    }
    return buf.join(".").replace(".[", "[");
  }
  async evaluate(context) {
    const path = [];
    let prop;
    for (const e of this.path) {
      prop = e instanceof Literal ? e.evaluateSync(context) : await e.evaluate(context);
      if (isInteger(prop)) {
        path.push(prop.valueOf());
      } else if (isString(prop) || isLiquidPrimitive(prop) || isPrimitiveInteger(prop)) {
        path.push(prop);
      } else {
        throw new InternalKeyError(`can't access property with '${prop}'`);
      }
    }
    if (this.root === null) {
      return await context.get(path[0].toString(), path.slice(1));
    }
    return await context.get(this.root, path);
  }
  evaluateSync(context) {
    const path = [];
    let prop;
    for (const e of this.path) {
      prop = e.evaluateSync(context);
      if (isInteger(prop)) {
        path.push(prop.valueOf());
      } else if (isString(prop) || isLiquidPrimitive(prop) || isPrimitiveInteger(prop)) {
        path.push(prop);
      } else {
        throw new InternalKeyError(`can't access property with '${prop}'`);
      }
    }
    if (this.root === null) {
      return context.getSync(path[0].toString(), path.slice(1));
    }
    return context.getSync(this.root, path);
  }
  children() {
    return this.path.filter(isExpression);
  }
}
class ExpressionFilter {
  constructor(name) {
    let args = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
    let kwargs = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : new Map();
    this.name = name;
    this.args = args;
    this.kwargs = kwargs;
  }
  toString() {
    const buf = [this.name];
    const argsString = this.args.map(String).join(", ");
    if (argsString.length) buf.push(`: ${argsString}`);
    const kwargsString = Array.from(this.kwargs).map(_ref => {
      let [k, v] = _ref;
      return `${k}: ${v}`;
    }).join(", ");
    if (kwargsString.length) buf.push(`, ${kwargsString}`);
    return buf.join("");
  }
  async evalArgs(context) {
    return Promise.all(this.args.map(async arg => arg instanceof Literal ? arg.evaluateSync(context) : await arg.evaluate(context)));
  }
  async evalKeywordArgs(context) {
    const kwargs = {};
    for (const [key, value] of this.kwargs.entries()) {
      kwargs[key] = value instanceof Literal ? value.evaluateSync(context) : await value.evaluate(context);
    }
    return kwargs;
  }
  evalArgsSync(context) {
    return this.args.map(arg => arg.evaluateSync(context));
  }
  evalKeywordArgsSync(context) {
    const kwargs = {};
    for (const [key, value] of this.kwargs.entries()) {
      kwargs[key] = value.evaluateSync(context);
    }
    return kwargs;
  }
}
class FilteredExpression {
  constructor(expression) {
    let filters = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
    this.expression = expression;
    this.filters = filters;
  }
  equals(other) {
    return other instanceof FilteredExpression && this.expression.equals(other.expression) && this.filters === other.filters;
  }
  toString() {
    const filterStr = this.filters.map(String).join("|");
    if (filterStr.length) return `${this.expression} | ${filterStr}`;
    return this.expression.toString();
  }
  async applyFilters(left, filters, context) {
    let result = left;
    for (const filter of filters) {
      const _filter = context.environment.filters[filter.name];
      if (_filter === undefined) {
        if (context.environment.strictFilters) throw new FilterNotFoundError(`unknown filter ${filter.name}`);
        continue;
      }
      try {
        result = _filter.apply({
          context,
          options: await filter.evalKeywordArgs(context)
        }, [result, ...(await filter.evalArgs(context))]);
      } catch (error) {
        if (error instanceof FilterValueError) continue;
        if (error instanceof FilterArgumentError) {
          error.message = `${filter.name}: ${error.message}`;
        }
        throw error;
      }
    }
    return result;
  }
  applyFiltersSync(left, filters, context) {
    let result = left;
    for (const filter of filters) {
      const _filter = context.environment.filters[filter.name];
      if (_filter === undefined) {
        if (context.environment.strictFilters) throw new FilterNotFoundError(`unknown filter ${filter.name}`);
        continue;
      }
      try {
        result = _filter.apply({
          context,
          options: filter.evalKeywordArgsSync(context)
        }, [result, ...filter.evalArgsSync(context)]);
      } catch (error) {
        if (error instanceof FilterValueError) continue;
        if (error instanceof FilterArgumentError) {
          error.message = `${filter.name}: ${error.message}`;
        }
        throw error;
      }
    }
    return result;
  }
  async evaluate(context) {
    const left = this.expression instanceof Literal ? this.expression.evaluateSync(context) : await this.expression.evaluate(context);
    return await this.applyFilters(left, this.filters, context);
  }
  evaluateSync(context) {
    const left = this.expression.evaluateSync(context);
    return this.applyFiltersSync(left, this.filters, context);
  }
  children() {
    const _children = [this.expression];
    for (const filter of this.filters) {
      for (const arg of filter.args) {
        _children.push(arg);
      }
      for (const arg of filter.kwargs.values()) {
        _children.push(arg);
      }
    }
    return _children;
  }
}
class ConditionalExpression extends FilteredExpression {
  constructor(expression) {
    let filters = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
    let condition = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : NIL;
    let alternative = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : NIL;
    super(expression, filters);
    this.expression = expression;
    this.filters = filters;
    this.condition = condition;
    this.alternative = alternative;
  }
  equals(other) {
    return other instanceof ConditionalExpression && this.expression.equals(other.expression) && this.condition.equals(other.condition) && this.alternative.equals(other.alternative) && this.filters === other.filters;
  }
  toString() {
    const buf = [this.expression.toString()];
    if (!this.condition.equals(NIL)) {
      buf.push("if", this.condition.toString());
    }
    if (!this.alternative.equals(NIL)) {
      buf.push("else", this.condition.toString());
    }
    if (this.filters.length > 0) {
      buf.push("|");
      buf.push(this.filters.map(String).join(" | "));
    }
    return buf.join(" | ");
  }
  async evaluate(context) {
    let left;
    if (this.condition.equals(NIL)) {
      left = await this.expression.evaluate(context);
    } else {
      if (isLiquidTruthy(await this.condition.evaluate(context))) {
        left = await this.expression.evaluate(context);
      } else if (this.alternative.equals(NIL)) {
        left = context.environment.undefinedFactory("");
      } else {
        left = await this.alternative.evaluate(context);
      }
    }
    return await this.applyFilters(left, this.filters, context);
  }
  evaluateSync(context) {
    let left;
    if (this.condition.equals(NIL)) {
      left = this.expression.evaluateSync(context);
    } else {
      if (isLiquidTruthy(this.condition.evaluateSync(context))) {
        left = this.expression.evaluateSync(context);
      } else if (this.alternative.equals(NIL)) {
        left = context.environment.undefinedFactory("");
      } else {
        left = this.alternative.evaluateSync(context);
      }
    }
    return this.applyFiltersSync(left, this.filters, context);
  }
  children() {
    const _children = [this.expression];
    if (!this.condition.equals(NIL)) {
      _children.push(this.condition);
    }
    if (!this.alternative.equals(NIL)) {
      _children.push(this.alternative);
    }
    for (const filter of this.filters) {
      for (const arg of filter.args) {
        _children.push(arg);
      }
      for (const arg of filter.kwargs.values()) {
        _children.push(arg);
      }
    }
    return _children;
  }
}
class PrefixExpression {
  constructor(operator, right) {
    this.operator = operator;
    this.right = right;
  }
  equals(other) {
    return other instanceof PrefixExpression && this.operator === other.operator && this.right === other.right;
  }
  toString() {
    return `${this.operator}${this.right}`;
  }
  async evaluate(context) {
    if (this.operator === "not") {
      const right = await this.right.evaluate(context);
      return !isLiquidTruthy(right);
    }
    throw new InternalTypeError(`unknown prefix operator '${this.operator}'`);
  }
  evaluateSync(context) {
    if (this.operator === "not") {
      const right = this.right.evaluateSync(context);
      return !isLiquidTruthy(right);
    }
    throw new InternalTypeError(`unknown prefix operator '${this.operator}'`);
  }
  children() {
    return [this.right];
  }
}
class InfixExpression {
  constructor(left, operator, right) {
    this.left = left;
    this.operator = operator;
    this.right = right;
  }
  equals(other) {
    return other instanceof InfixExpression && this.left.equals(other.left) && this.operator === other.operator && this.right.equals(other.right);
  }
  toString() {
    return `(${this.left} ${this.operator} ${this.right})`;
  }
  async evaluate(context) {
    return compare$1(this.left instanceof Literal ? this.left.evaluateSync(context) : await this.left.evaluate(context), this.operator, this.right instanceof Literal ? this.right.evaluateSync(context) : await this.right.evaluate(context));
  }
  evaluateSync(context) {
    return compare$1(this.left.evaluateSync(context), this.operator, this.right.evaluateSync(context));
  }
  children() {
    return [this.left, this.right];
  }
}
class BooleanExpression {
  constructor(expression) {
    this.expression = expression;
  }
  equals(other) {
    return other instanceof BooleanExpression && this.expression.equals(other.expression);
  }
  toString() {
    return `(${this.expression})`;
  }
  async evaluate(context) {
    return isLiquidTruthy(await this.expression.evaluate(context));
  }
  evaluateSync(context) {
    return isLiquidTruthy(this.expression.evaluateSync(context));
  }
  children() {
    return [this.expression];
  }
}
const For = Symbol.for("liquid.tags.for");
class LoopExpression {
  constructor(name, iterable, limit, offset, cols) {
    let reversed = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : false;
    this.name = name;
    this.iterable = iterable;
    this.limit = limit;
    this.offset = offset;
    this.cols = cols;
    this.reversed = reversed;
  }
  equals(other) {
    return other instanceof LoopExpression && this.name === other.name && this.iterable === other.iterable && this.limit === other.limit && this.offset === other.offset && this.cols === other.cols && this.reversed === other.reversed;
  }
  toString() {
    const buf = [`${this.name} in ${this.iterable}`];
    if (this.limit !== undefined) buf.push(`limit:${this.limit}`);
    if (this.offset !== undefined) buf.push(`offset:${this.offset}`);
    if (this.cols !== undefined) buf.push(`cols:${this.cols}`);
    if (this.reversed) buf.push("reversed");
    return buf.join(" ");
  }
  toIter(obj) {
    if (isArray(obj)) return [obj.values(), obj.length];
    if (obj instanceof Range) return [obj, obj.length];
    if (obj instanceof Set) return [obj.values(), obj.size];
    if (obj instanceof Map) return [obj.entries(), obj.size];
    if (isString(obj)) return [[obj], obj.length];
    if (isObject(obj)) {
      const it = isIterable(obj) ? obj : Object.entries(obj);
      return [it, Object.keys(obj).length];
    }
    throw new InternalTypeError(`expected an iterable object, at ${this.iterable}, ` + `found ${typeof this.iterable}`);
  }
  *drop(it, n) {
    for (let i = 0; i < n; i++) it.next();
    let next = it.next();
    while (!next.done) {
      yield next.value;
      next = it.next();
    }
  }
  *take(it, n) {
    for (let i = 0; i < n; i++) yield it.next().value;
  }
  limitAndOffset(context, it, length, limit, offset) {
    const offsets = context.getRegister(For);
    const _name = `${this.name}-${this.iterable}`;
    let _it = it[Symbol.iterator]();
    let _length = length;
    if (offset === CONTINUE) {
      offset = offsets.get(_name);
    }
    if (isPrimitiveInteger(offset)) {
      _it = this.drop(_it, offset);
      _length -= offset;
    } else if (isInteger(offset)) {
      _it = this.drop(_it, offset.valueOf());
      _length -= offset.valueOf();
    } else if (offset !== undefined) {
      throw new InternalTypeError(`loop offset must be an integer, found '${offset}'`);
    }
    if (isPrimitiveInteger(limit)) {
      _length = Math.min(_length, limit);
      _it = this.take(_it, _length);
    } else if (isInteger(limit)) {
      _length = Math.min(_length, limit.valueOf());
      _it = this.take(_it, _length);
    } else if (limit !== undefined) {
      throw new InternalTypeError(`loop limit must be an integer, found '${limit}'`);
    }
    if (offset) {
      offsets.set(_name, _length + offset);
    } else {
      offsets.set(_name, _length);
    }
    return [_it, _length];
  }
  async evaluate(context) {
    const [it, length] = this.toIter(await this.iterable.evaluate(context));
    return this.limitAndOffset(context, this.reversed ? Array.from(it).reverse() : it, length, await this.limit?.evaluate(context), await this.offset?.evaluate(context));
  }
  evaluateSync(context) {
    const [it, length] = this.toIter(this.iterable.evaluateSync(context));
    return this.limitAndOffset(context, this.reversed ? Array.from(it).reverse() : it, length, this.limit?.evaluateSync(context), this.offset?.evaluateSync(context));
  }
  children() {
    const _children = [this.iterable];
    if (this.limit) _children.push(this.limit);
    if (this.offset) _children.push(this.offset);
    if (this.cols) _children.push(this.cols);
    return _children;
  }
}

/**
 * A type predicate for the `Expression` interface.
 */
function isExpression(obj) {
  return !!obj && typeof obj === "object" && "equals" in obj && "evaluate" in obj;
}

// eslint-disable-next-line sonarjs/cognitive-complexity
function compare$1(left, op, right) {
  if (op === "and") {
    return isLiquidTruthy(left) && isLiquidTruthy(right);
  } else if (op === "or") {
    return isLiquidTruthy(left) || isLiquidTruthy(right);
  }
  if (isLiquidPrimitive(left)) left = left[toLiquidPrimitive]();
  if (isLiquidPrimitive(right)) right = right[toLiquidPrimitive]();
  switch (op) {
    case "==":
      return eq(left, right);
    case "!=":
    case "<>":
      return !eq(left, right);
    case "<":
      try {
        return lt(left, right);
      } catch {
        throw new InternalTypeError(`invalid operator '${left} ${op} ${right}'`);
      }
    case ">":
      try {
        return lt(right, left);
      } catch {
        throw new InternalTypeError(`invalid operator '${left} ${op} ${right}'`);
      }
    case ">=":
      try {
        return lt(right, left) || eq(left, right);
      } catch {
        throw new InternalTypeError(`invalid operator '${left} ${op} ${right}'`);
      }
    case "<=":
      try {
        return lt(left, right) || eq(left, right);
      } catch {
        throw new InternalTypeError(`invalid operator '${left} ${op} ${right}'`);
      }
    case "contains":
      if (isString(left)) {
        return left.indexOf(String(right)) !== -1;
      }
      if (isArray(left)) {
        if (isNumber(right)) {
          const n = parseNumberT(right);
          for (const item of left) {
            if (isNumber(item) && n.eq(item)) {
              return true;
            }
          }
          return false;
        }
        return left.indexOf(right) !== -1;
      }
      if (isUndefined(left)) {
        return false;
      }
      if (isObject(left) && isPropertyKey(right)) {
        return Object.propertyIsEnumerable.call(left, right);
      }
  }
  throw new InternalTypeError(`invalid comparison operator '${left} ${op} ${right}'`);
}

/**
 * Check a value for Liquid truthiness.
 * @param value - Any value
 * @returns `true` if the value is Liquid truthy, `false` otherwise.
 */
function isLiquidTruthy(value) {
  if (isLiquidPrimitive(value)) value = value[toLiquidPrimitive]();
  return !(value === false || FALSE.equals(value) || value === undefined || value === null || value instanceof Undefined);
}
function eq(left, right) {
  if (right instanceof Empty || right instanceof Blank || right instanceof Nil || right instanceof Range) [left, right] = [right, left];
  if ((isUndefined(left) || left instanceof Nil || left === null) && (isUndefined(right) || right instanceof Nil || right === null)) {
    return true;
  }
  if (isNumber(left) && isNumber(right)) {
    return parseNumberT(left).eq(right);
  }
  if (isArray(left) && isArray(right)) {
    const _right = right; // for odd typescript bug?
    return left.length === _right.length && left.every((v, i) => v === _right[i]);
  }
  return isExpression(left) || left instanceof Range ? left.equals(right) : left === right;
}
function lt(left, right) {
  if (isString(left) && isString(right)) {
    return left < right;
  }
  if (isBoolean(left) || isBoolean(right)) {
    return false;
  }
  if (isNumber(left) && isNumber(right)) {
    return parseNumberT(left) < right;
  }
  throw new InternalTypeError("");
}

/**
 * A utility function that checks throws an error if the given number of
 * arguments are not between the expected minimum and maximum.
 */
function checkArguments(n, max, min) {
  n -= 1;
  if (n > max) {
    if (max === 0) {
      throw new FilterArgumentError(`too many arguments, expected 0, but got ${n}`);
    }
    throw new FilterArgumentError(`too many arguments, expected at most ${max}, but got ${n}`);
  }
  if (min !== undefined && n < min) throw new FilterArgumentError(`missing argument, expected at least ${min}, but got ${n}`);
}

/**
 * Throw an error if the given filter context contains options.
 */
function throwIfOptions(context) {
  for (const _ in context.options) {
    throw new FilterArgumentError("unexpected filter options");
  }
}

/**
 * Return the absolute value of a number. Given a value that can't be cast to
 * an integer or float, `0` will be returned.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @returns - The absolute value of the input argument.
 */
function abs(left) {
  checkArguments(arguments.length, 0);
  return parseNumberOrZero(left).abs();
}

/**
 * Return the maximum of the filter's input value and its argument. If either
 * input value or argument are string representations of an integer or float,
 * they will be cast to an integer or float prior to comparison.
 *
 * If either input value or argument can not be cast to an integer or float,
 * `0` will be used instead.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @param arg - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @returns The maximum of the input value and the argument value.
 */
function atLeast(left, arg) {
  checkArguments(arguments.length, 1, 1);
  return parseNumberOrZero(left).max(parseNumberOrZero(arg));
}

/**
 * Return the minimum of the filter's input value and its argument. If either
 * input value or argument are string representations of an integer or float,
 * they will be cast to an integer or float prior to comparison.
 *
 * If either input value or argument can not be cast to an integer or float,
 * `0` will be used instead.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @param arg - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @returns The minimum of the input value and the argument value.
 */
function atMost(left, arg) {
  checkArguments(arguments.length, 1, 1);
  return parseNumberOrZero(left).min(parseNumberOrZero(arg));
}

/**
 * Round the input value up to the nearest whole number. The input value will
 * be converted to a number if it is not an integer or float.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @returns The input value rounded up to the nearest whole number.
 */
function ceil(left) {
  checkArguments(arguments.length, 0);
  return parseNumberOrZero(left).ceil();
}

/**
 * Divide the input value by the argument value, rounded down to the nearest
 * whole number if the divisor is an integer.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @param divisor - Any value. If it can't be converted to a number an
 * exception will be raised.
 * @returns The input value divided by the argument value.
 * @throws {@link FilterArgumentError}
 * Thrown if the divisor is zero or can't be converted to a number.
 */
function dividedBy(left, divisor) {
  checkArguments(arguments.length, 1, 1);
  const _divisor = parseNumberOrZero(divisor);
  if (_divisor.eq(0)) throw new FilterArgumentError("can't divide by zero");
  return parseNumberOrZero(left).div(_divisor);
}

/**
 * Round the input value down to the nearest whole number. The input value will
 * be converted to a number if it is not an integer or float.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @returns The input value rounded down to the nearest whole number.
 */
function floor(left) {
  checkArguments(arguments.length, 0);
  return parseNumberOrZero(left).floor();
}

/**
 * Subtract the argument value from the input value. If either the input or
 * argument are not a number, they will be convert to a number. If that
 * conversion fails, `0` is used instead.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @param right - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @returns The result of subtracting the argument value from the input value.
 */
function minus(left, right) {
  checkArguments(arguments.length, 1, 1);
  return parseNumberOrZero(left).minus(parseNumberOrZero(right));
}

/**
 * Return the remainder from the division of the input value by the argument
 * value.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @param right - Any value. If it can't be converted to a number an exception
 * will be raised.
 * @returns the remainder from the division of the input value by the argument
 * value.
 * @throws {@link FilterArgumentError}
 * Thrown if the argument is zero or can't be converted to a number.
 */
function modulo(left, right) {
  checkArguments(arguments.length, 1, 1);
  // undefined or invalid arguments get caught by "divide by zero" check.
  const _right = parseNumberOrZero(right);
  if (_right.eq(0)) throw new FilterArgumentError("can't divide by zero");
  return parseNumberOrZero(left).mod(_right);
}

/**
 * Add one number to another. If either the input or argument are not a number,
 * they will be to convert to a number. If that conversion fails, `0` is used
 * instead.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @param right - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @returns The result of adding the input value to the argument value.
 */
function plus(left, right) {
  checkArguments(arguments.length, 1, 1);
  return parseNumberOrZero(left).plus(parseNumberOrZero(right));
}

/**
 * Return the input number rounded to the given number of decimal places.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @param decimalPlaces - Any value. If it can't be converted to a number, zero
 * will be used instead. Defaults to `0`.
 * @returns The input number rounded to the given number of decimal places
 */
function round(left, decimalPlaces) {
  checkArguments(arguments.length, 1);
  if (decimalPlaces === undefined || isUndefined(decimalPlaces)) {
    return parseNumberOrZero(left).round();
  }
  const _decimalPlaces = Number(decimalPlaces);
  if (!isFinite(_decimalPlaces)) {
    return parseNumberOrZero(left).round();
  }
  if (_decimalPlaces < 0) {
    return ZERO;
  }
  if (_decimalPlaces === 0) {
    return parseNumberOrZero(left).round();
  }
  return parseNumberOrZero(left).round(Math.round(_decimalPlaces));
}

/**
 * Return the product of the input number and the argument number. If either
 * the input or argument are not a number, they will be convert to a number. If
 * that conversion fails, `0` is used instead.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @param right - Any value. If it can't be converted to a number, zero will be
 * used instead.
 * @returns The product of the input number and the argument number
 */
function times(left, right) {
  checkArguments(arguments.length, 1, 1);
  return parseNumberOrZero(left).times(parseNumberOrZero(right));
}

/**
 * A utility function that converts a value to a number. Returns `0` if the
 * input value can't be converted to a number.
 */
function parseNumberOrZero(value) {
  // XXX: See https://github.com/jg-rp/liquid/issues/49
  if (isN(value)) {
    const num = parseNumberT(value);
    return !isNumberT(num) || !num.isFinite() ? ZERO : num;
  }
  return ZERO;
}

/**
 * Concatenate items in an array-like object into a single string, separated by
 * a separator string.
 *
 * If the input value is not array-like, it will be coerced to one. If input
 * array items are not strings, they will be converted to strings before joining.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. If it's not iterable, a new array will be used with
 * the value as its first and only item.
 * @param separator - A string to be used to separate input items in the output
 * string. Defaults to a single space.
 * @returns Items in the input array, concatenated together and separated by
 * the given separator.
 */
function join(left, separator) {
  checkArguments(arguments.length, 1);
  if (this.context.environment.autoEscape) {
    const _separator = separator === undefined ? new Markup(" ") : separator;
    if (_separator instanceof Markup) return new Markup(inputArray(left).map(Markup.escape).join(_separator[toLiquidString]()));
  }
  if (separator === undefined) separator = " ";
  return inputArray(left).map(liquidStringify).join(liquidStringify(separator));
}

/**
 * Return the first item of the input sequence. The input could be array-like
 * or a mapping, but not a string.
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value.
 * @returns The first item in the input iterable, or `null` if the input value
 * is not iterable, or `undefined` if the iterable is empty.
 */
function first(left) {
  checkArguments(arguments.length, 0);
  // First of a string is not supported.
  if (isString(left)) return null;
  // Iterable objects are OK.
  if (isIterable(left)) return left[Symbol.iterator]().next().value;
  if (isObject(left)) {
    return Object.entries(left)[Symbol.iterator]().next().value;
  }
  return null;
}

/**
 * Return the last item of the input sequence. The input could be array-like,
 * but not a string.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value.
 * @returns The last item in the input iterable, or `null` if the input value
 * is not iterable.
 */
function last(left) {
  checkArguments(arguments.length, 0);
  if (isArray(left)) return left[left.length - 1];
  if (left instanceof Range) return left.stop;
  if (left instanceof Undefined) left.poke();
  return null;
}

/**
 * Remove `null` and `undefined` values from an array-like object. If given, the
 * argument should be the name of a property that exists on each object in the
 * array-like sequence.
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value.
 * @param prop - The name of a property to check for `null` or `undefined`
 * values. Each object in the input iterable should have this property.
 * @returns - A new array with `null` and `undefined` values removed.
 */
function compact(left, prop) {
  checkArguments(arguments.length, 1);
  if (prop === undefined) return inputArray(left).filter(v => v !== undefined && v !== null);
  return inputArray(left).filter(v => {
    const _v = getItemOrThrow(v, prop);
    return _v !== undefined && _v !== null;
  });
}

/**
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @param arg -
 * @returns
 */
function concat(left, arg) {
  checkArguments(arguments.length, 1, 1);
  if (!isArray(arg)) throw new FilterArgumentError(`expected an array, found ${typeof arg}`);
  if (left instanceof Undefined) return arg;
  return inputArray(left).concat(arg);
}

/**
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @param key -
 * @returns
 */
function map(left, key) {
  checkArguments(arguments.length, 1, 1);
  return Array.from(inputArray(left)).map(v => getItem(v, key));
}

/**
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @returns
 */
function reverse(left) {
  checkArguments(arguments.length, 0);
  return Array.from(inputArray(left)).reverse();
}

/**
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @param key -
 * @returns
 */
function sort(left, key) {
  checkArguments(arguments.length, 1);
  if (isUndefined(key)) {
    return Array.from(inputArray(left)).sort(compare);
  }
  return Array.from(inputArray(left)).sort((a, b) => compare(getItem(a, key), getItem(b, key)));
}

/**
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @param key -
 * @returns
 */
function sortNatural(left, key) {
  checkArguments(arguments.length, 1);
  if (isUndefined(key)) {
    return Array.from(inputArray(left)).sort(naturalCompare);
  }
  return Array.from(inputArray(left)).sort((a, b) => naturalCompare(getItem(a, key), getItem(b, key)));
}

/**
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @param prop -
 * @returns
 */
function uniq(left, prop) {
  checkArguments(arguments.length, 1);
  const _map = new Map();
  let key;
  if (prop === undefined) {
    for (const obj of inputArray(left)) {
      key = JSON.stringify(obj);
      if (!_map.has(key)) {
        _map.set(key, obj);
      }
    }
  } else {
    for (const obj of inputArray(left)) {
      key = JSON.stringify(getItem(obj, prop));
      if (!_map.has(key)) {
        _map.set(key, obj);
      }
    }
  }
  return Array.from(_map.values());
}

/**
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @param prop -
 * @param value -
 * @returns
 */
function where(left, prop, value) {
  checkArguments(arguments.length, 2, 1);
  if (value === null || NIL.equals(value) || isUndefined(value)) {
    return inputArray(left).filter(v => isLiquidTruthy(getItem(v, prop)));
  }
  return inputArray(left).filter(v => getItem(v, prop) === value);
}

/**
 * Return the sum of all numeric items in _left_.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @param prop -
 * @returns
 */
function sum(left, prop) {
  if (prop === null || NIL.equals(prop) || isUndefined(prop)) {
    return inputArray(left).map(parseNumberOrZero).reduce((a, b) => a.plus(b), ZERO);
  }
  return inputArray(left).map(e => parseNumberOrZero(getItem(e, prop))).reduce((a, b) => a.plus(b), ZERO);
}

/**
 * Coerce an unknown array filter input to an iterable.
 * @param value -
 * @returns
 */
function inputArray(value) {
  if (isArray(value)) {
    return value.flat(5);
  }
  // Not flattening iterables.
  if (isIterable(value)) {
    return Array.from(value);
  }
  return [value];
}

/**
 *
 * @param obj -
 * @param key -
 * @returns
 */
function getItem(obj, key) {
  if (!isObject(obj)) throw new FilterArgumentError(`can't read property ${obj}[${key}]`);
  if (obj instanceof Map) {
    return obj.get(key);
  }
  try {
    return getItemSync(obj, key);
  } catch (error) {
    if (error instanceof InternalKeyError) {
      return undefined;
    }
    throw error;
  }
}
function getItemOrThrow(obj, key) {
  if (obj instanceof Map && obj.has(key)) {
    return obj.get(key);
  }
  try {
    return getItemSync(obj, key);
  } catch (error) {
    if (error instanceof InternalKeyError) {
      throw new FilterArgumentError(`can't read property '${key}' of ${obj}`);
    }
    throw error;
  }
}
function compare(a, b) {
  if (a === undefined && b === undefined) return 0;
  if (a === undefined && b !== undefined) return 1;
  if (a !== undefined && b === undefined) return -1;
  if (typeof a !== typeof b) throw new InternalTypeError(`comparison with ${typeof a} and ${typeof b} failed`);
  if (isComparable(a) && isComparable(b)) return a < b ? -1 : a > b ? 1 : 0;
  throw new InternalTypeError(`comparison of '${a}' and '${b}' failed`);
}
function naturalCompare(a, b) {
  if (a === undefined && b === undefined) return 0;
  if (a === undefined && b !== undefined) return 1;
  if (a !== undefined && b === undefined) return -1;
  const _a = JSON.stringify(a).toLowerCase();
  const _b = JSON.stringify(b).toLowerCase();
  return _a < _b ? -1 : _a > _b ? 1 : 0;
}

class DefaultMap extends Map {
  constructor(defaultFactory, entries) {
    if (entries !== undefined) {
      super(entries);
    } else {
      super();
    }
    this.default = typeof defaultFactory === "function" ? defaultFactory : () => defaultFactory;
  }
  get(key) {
    if (this.has(key)) {
      return super.get(key);
    }
    this.set(key, this.default());
    return this.get(key);
  }
}

/**
 * Return the length of an array or string. If the input is an object or map,
 * returns the number of keys.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value.
 * @returns The size of an object or `0` if a size can not be determined.
 */
function size(left) {
  checkArguments(arguments.length, 0);
  if (isArray(left) || isString(left)) return left.length;
  if (left instanceof Map) return left.size;
  if (isUndefined(left)) return 0;
  if (isObject(left)) return Object.keys(left).length;
  return 0;
}

/**
 * Return a default value if the input is nil, false or empty.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value.
 * @param _default - Optional default value. Defaults to an empty string.
 * @returns The default value if the input is nil, false or empty.
 */
function default_(left) {
  let _default = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "";
  checkArguments(arguments.length, 1);
  const _left = isLiquidPrimitive(left) ? left[toLiquidPrimitive]() : left;
  if (isLiquidTruthy(this.options["allow_false"]) && _left === false) return left;
  if (!isLiquidTruthy(_left) || EMPTY.equals(_left)) return _default;
  return left;
}
const FORMAT_TOKENS = new DefaultMap("", [["%%", "%"], ["%a", "ccc"], ["%A", "cccc"], ["%b", "LLL"], ["%B", "LLLL"], ["%c", "DDD tt"], ["%d", "dd"], ["%H", "HH"], ["%I", "hh"], ["%j", "ooo"], ["%m", "LL"], ["%M", "mm"], ["%p", "a"], ["%s", "X"], ["%S", "ss"], ["%W", "WW"], ["%w", "c"], ["%x", "DDD"], ["%X", "tt"], ["%y", "yy"], ["%Y", "yyyy"], ["%Z", "ZZZZ"]]);
const RE_DATE_FORMAT = new RegExp(["%%", ...FORMAT_TOKENS.keys()].join("|"), "g");
function replaceDateFormat(format) {
  return format.replace(RE_DATE_FORMAT, match => FORMAT_TOKENS.get(match));
}

/**
 * Parse a string as DateTime by trying each of the common date formats
 * in turn. This does not do fuzzy or natural language parsing.
 */
function parseDateString(s) {
  let _date = DateTime.fromSQL(s);
  if (_date.isValid) return _date;
  _date = DateTime.fromISO(s);
  if (_date.isValid) return _date;
  _date = DateTime.fromHTTP(s);
  if (_date.isValid) return _date;
  if (s.match(/\d+/)) {
    _date = DateTime.fromSeconds(Number(s));
    if (_date.isValid) return _date;
  }
  return _date;
}

/**
 * Format a date according to the given format string. If the input is not a
 * date it will be converted to a string and parsed using one of the common
 * date representation standards.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - The date to be formatted.
 * @param format - A format string.
 * @returns A string representation of the input date according to the given
 * format string.
 */
function date(left, format) {
  checkArguments(arguments.length, 1, 1);
  if (isUndefined(left)) return "";
  if (isUndefined(format)) return liquidStringify(left);
  let _date;

  // Numbers could be a unix timestamp or an ISO date/time without separators.
  if (isPrimitiveNumber(left) || isNumberT(left)) left = left.toString();
  if (isString(left)) {
    if (left === "now" || left === "today") {
      _date = DateTime.now();
    } else {
      _date = parseDateString(left);
    }
  } else if (left instanceof Date) {
    _date = DateTime.fromJSDate(left);
  } else if (left instanceof DateTime) {
    _date = left;
  } else {
    throw new FilterArgumentError(`expected a date, found ${left}`);
  }
  return _date.toFormat(replaceDateFormat(liquidStringify(format)));
}

/**
 * Return a substring or subsequence of the input value.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. If its not an array or string, it will be
 * converted to a string.
 * @param offset - Start of the subsequence in number of items or characters.
 * @param length - The maximum number of items or characters in the resulting
 * sequence.
 * @returns A substring for subsequence.
 */
function slice(left, offset, length) {
  checkArguments(arguments.length, 2, 1);
  const _offset = _clamp_slice_arg(parseIntegerOrThrow(offset, "offset"));
  const _length = _clamp_slice_arg(isUndefined(length) ? 1 : parseIntegerOrThrow(length, "length"));

  // Arrays and strings only.
  const _left = isArray(left) ? left : liquidStringify(left);
  const start = _offset < 0 ? _left.length + _offset : _offset;
  return _left.slice(start, start + _length);
}
function parseIntegerOrThrow(value, name) {
  if (isN(value)) {
    const num = parseNumberT(value);
    if (isInteger(num)) return num.valueOf();
  }
  throw new FilterArgumentError(`expected an integer ${name}, found '${value}'`);
}

// This range is smaller than the reference implementation.
const MAX_SLICE_ARG = Number.MAX_SAFE_INTEGER;
const MIN_SLICE_ARG = Number.MIN_SAFE_INTEGER;
function _clamp_slice_arg(arg) {
  const rv = arg > MAX_SLICE_ARG ? MAX_SLICE_ARG : arg;
  return rv < MIN_SLICE_ARG ? MIN_SLICE_ARG : rv;
}

/**
 * Return the input value concatenated with the argument value.
 *
 * If either the input value or argument are not a string, they will be
 * coerced to a string before concatenation.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @param other - Any value. Will be coerced to a string if it's not one already.
 * @returns The input value concatenated with the argument value.
 */
function append(left, other) {
  checkArguments(arguments.length, 1, 1);
  if (left instanceof Markup) return new Markup(left[toLiquidString]() + Markup.escape(other)[toLiquidString]());
  if (other instanceof Markup) {
    return new Markup(Markup.escape(left)[toLiquidString]() + other[toLiquidString]());
  }
  return liquidStringify(left) + liquidStringify(other);
}

/**
 * Return the input string with the first character in upper case and the rest
 * lowercase.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @returns The input string with the first character in upper case and the rest
 * lowercase.
 */
function capitalize(left) {
  checkArguments(arguments.length, 0);
  if (left instanceof Markup) {
    const s = left[toLiquidString]();
    return new Markup(s.charAt(0).toLocaleUpperCase() + s.slice(1).toLocaleLowerCase());
  }
  const s = liquidStringify(left);
  return s.charAt(0).toLocaleUpperCase() + s.slice(1).toLocaleLowerCase();
}

/**
 * Return the input string with all characters in lowercase.
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @returns The input string with all characters in lowercase.
 */
function downcase(left) {
  checkArguments(arguments.length, 0);
  if (left instanceof Markup) return new Markup(left[toLiquidString]().toLocaleLowerCase());
  return liquidStringify(left).toLocaleLowerCase();
}

/**
 * Return the input string with `&`, `<`, `>`, `"`, `'`, and "\`" replaced with
 * HTML escape codes.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @returns The input string with `&`, `<`, `>`, `"`, `'`, and "\`" replaced
 * with HTML escape codes.
 */
function escape(left) {
  checkArguments(arguments.length, 0);
  if (this.context.environment.autoEscape) return Markup.escape(liquidStringify(left));
  return escape$1(liquidStringify(left));
}

/**
 * Return the input string with `&`, `<`, `>`, `"`, `'`, and "\`" replaced with
 * HTML escape codes while preserving existing escape sequences.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @returns The input string with `&`, `<`, `>`, `"`, `'`, and "\`" replaced
 * with HTML escape codes while preserving existing escape sequences.
 */
function escapeOnce(left) {
  checkArguments(arguments.length, 0);
  if (this.context.environment.autoEscape) return Markup.escape(unescape(liquidStringify(left)));
  return escape$1(unescape(liquidStringify(left)));
}

/**
 * Return the input string with all leading whitespace removed. If the input is
 * not a string, it will be converted to a string before stripping whitespace.

 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @returns The input string with all leading whitespace removed
 */
function lstrip(left) {
  checkArguments(arguments.length, 0);
  if (left instanceof Markup) return new Markup(left[toLiquidString]().trimStart());
  return liquidStringify(left).trimStart();
}

/**
 * Return the input string with `\n` and `\r\n` replaced with `<br />\n`.
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @returns The input string with `\n` and `\r\n` replaced with `<br />\n`.
 */
function newlineToBr(left) {
  checkArguments(arguments.length, 0);
  if (this.context.environment.autoEscape) return new Markup(Markup.escape(left)[toLiquidString]().replace(/\r?\n/g, "<br />\n"));
  return liquidStringify(left).replace(/\r?\n/g, "<br />\n");
}

/**
 * Return the argument value concatenated with the input value.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @param other - Any value. Will be coerced to a string if it's not one already.
 * @returns The argument value concatenated with the input value.
 */
function prepend(left, other) {
  checkArguments(arguments.length, 1, 1);
  if (left instanceof Markup) return new Markup(Markup.escape(other)[toLiquidString]() + left[toLiquidString]());
  if (other instanceof Markup) {
    return new Markup(other[toLiquidString]() + Markup.escape(left)[toLiquidString]());
  }
  return liquidStringify(other) + liquidStringify(left);
}

/**
 * Return the input value with all occurrences of the argument substring
 * removed.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @param subString - Any value. Will be coerced to a string if it's not one
 * already.
 * @returns The input value with all occurrences of the argument substring
 * removed.
 */
function remove(left, subString) {
  checkArguments(arguments.length, 1, 1);
  if (left instanceof Markup) return new Markup(left[toLiquidString]().replace(new RegExp(Markup.escape(subString)[toLiquidString](), "g"), ""));
  return liquidStringify(left).replace(new RegExp(liquidStringify(subString), "g"), "");
}

/**
 * Return the input value with the first occurrence of the argument string
 * removed.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @param subString - Any value. Will be coerced to a string if it's not one
 * already.
 * @returns The input value with the first occurrence of the argument string
 * removed.
 */
function removeFirst(left, subString) {
  checkArguments(arguments.length, 1, 1);
  if (left instanceof Markup) return new Markup(left[toLiquidString]().replace(Markup.escape(subString)[toLiquidString](), ""));
  return liquidStringify(left).replace(liquidStringify(subString), "");
}

/**
 * Return the input value with the last occurrence of the argument string
 * removed.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @param arg - Any value. Will be coerced to a string if it's not one already.
 * @returns The input value with the last occurrence of the argument string
 * removed.
 */
function removeLast(left, arg) {
  checkArguments(arguments.length, 1, 1);
  if (left instanceof Markup) {
    const _left = left[toLiquidString]();
    const _arg = Markup.escape(arg)[toLiquidString]();
    const startIndex = _left.lastIndexOf(_arg);
    // substring not found
    if (startIndex === -1) return left;
    return new Markup(_left.substring(0, startIndex) + _left.substring(startIndex + _arg.length + 1));
  }
  const _left = liquidStringify(left);
  const _arg = liquidStringify(arg);
  const startIndex = _left.lastIndexOf(_arg);
  // substring not found
  if (startIndex === -1) return _left;
  return _left.substring(0, startIndex) + _left.substring(startIndex + _arg.length + 1);
}

/**
 * Return the input string with all occurrences of the first argument replaced
 * with the second argument.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @param subString - Any value. Will be coerced to a string if it's not one
 * already.
 * @param newSubString - Any value. Will be coerced to a string if it's not one
 * already.
 * @returns The input string with all occurrences of the first argument
 * replaced with the second argument.
 */
function replace(left, subString, newSubString) {
  checkArguments(arguments.length, 2, 1);
  if (left instanceof Markup) return new Markup(left[toLiquidString]().replace(new RegExp(Markup.escape(subString)[toLiquidString](), "g"), Markup.escape(newSubString)[toLiquidString]()));
  return liquidStringify(left).replace(new RegExp(liquidStringify(subString), "g"), liquidStringify(newSubString));
}

/**
 * Return the input string with the first occurrence of the first argument
 * replaced with the second argument.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @param subString - Any value. Will be coerced to a string if it's not one
 * already.
 * @param newSubString - Any value. Will be coerced to a string if it's not one
 * already.
 * @returns The input string with the first occurrence of the first argument
 * replaced with the second argument.
 */
function replaceFirst(left, subString, newSubString) {
  checkArguments(arguments.length, 2, 1);
  if (left instanceof Markup) return new Markup(left[toLiquidString]().replace(Markup.escape(subString)[toLiquidString](), Markup.escape(newSubString)[toLiquidString]()));
  return liquidStringify(left).replace(liquidStringify(subString), liquidStringify(newSubString));
}

/**
 * Return the input string with the last occurrence of the first argument
 * replaced with the second argument.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @param subString - Any value. Will be coerced to a string if it's not one
 * already.
 * @param newSubString - Any value. Will be coerced to a string if it's not one
 * already.
 * @returns The input string with the last occurrence of the first argument
 * replaced with the second argument.
 */
function replaceLast(left, subString, newSubString) {
  checkArguments(arguments.length, 2, 2);
  if (left instanceof Markup) {
    const _left = left[toLiquidString]();
    const _sub = Markup.escape(subString)[toLiquidString]();
    const startIndex = _left.lastIndexOf(_sub);

    // substring not found
    if (startIndex === -1) return left;
    const _newSub = Markup.escape(newSubString);
    return new Markup(_left.substring(0, startIndex) + _newSub + _left.substring(startIndex + _sub.length));
  }
  const _left = liquidStringify(left);
  const _sub = liquidStringify(subString);
  const startIndex = _left.lastIndexOf(_sub);

  // substring not found
  if (startIndex === -1) return _left;
  const _newSub = liquidStringify(newSubString);
  return _left.substring(0, startIndex) + _newSub + _left.substring(startIndex + _sub.length);
}

/**
 * Return the input string with all characters in uppercase.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @returns The input string with all characters in uppercase.
 */
function upcase(left) {
  checkArguments(arguments.length, 0);
  if (left instanceof Markup) return new Markup(left[toLiquidString]().toLocaleUpperCase());
  return liquidStringify(left).toLocaleUpperCase();
}

/**
 * Return an array of strings that are the input string split on the filter's
 * argument string.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @param subString - Any value. Will be coerced to a string if it's not one
 * already.
 * @returns An array of strings that are the input string split on the filter's
 * argument string.
 */
function split(left, subString) {
  checkArguments(arguments.length, 1, 1);
  const val = liquidStringify(left);
  const sep = liquidStringify(subString);
  if (!val || val === sep) return [];
  return val.split(sep);
}

/**
 * Return the input string with all leading and trailing whitespace removed.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @returns The input string with all leading and trailing whitespace removed.
 */
function strip(left) {
  checkArguments(arguments.length, 0);
  if (left instanceof Markup) return new Markup(left[toLiquidString]().trim());
  return liquidStringify(left).trim();
}

/**
 * Return the input string with all trailing whitespace removed.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @returns The input string with all trailing whitespace removed.
 */
function rstrip(left) {
  checkArguments(arguments.length, 0);
  if (left instanceof Markup) return new Markup(left[toLiquidString]().trimEnd());
  return liquidStringify(left).trimEnd();
}

// We're aiming for consistency with the reference implementation here,
// rather than correctness.
const STRIP_HTML_BLOCKS = new RegExp("<script.*?</script>|<!--.*?-->|<style.*?</style>", "gs");
const STRIP_HTML_TAGS = new RegExp("<.*?>", "gs");

/**
 * Return the input string with all HTML tags removed.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @returns The input string with all HTML tags removed.
 */
function stripHtml(left) {
  checkArguments(arguments.length, 0);
  return liquidStringify(left).replace(STRIP_HTML_BLOCKS, "").replace(STRIP_HTML_TAGS, "");
}

/**
 * Return the input string with `\n` and `\r\n` removed.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @returns The input string with `\n` and `\r\n` removed.
 */
function stripNewlines(left) {
  checkArguments(arguments.length, 0);
  if (left instanceof Markup) return new Markup(left[toLiquidString]().replace(/\r?\n/g, ""));
  return liquidStringify(left).replace(/\r?\n/g, "");
}

/**
 * Return a truncated version of the input string. The first argument, length,
 * defaults to `50`. The second argument defaults to an ellipsis (`...`).
 *
 * If the length of the input string is less than the given length (first
 * argument), the input string will be truncated to `length` minus the length
 * of the second argument, with the second argument appended.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @param length - Any value. If it can't be converted to a number, zero will
 * be used instead. Defaults to `50`.
 * @param end - Any value. Will be coerced to a string if it's not one already.
 * Defaults to `...`.
 * @returns A truncated version of the input string.
 */
function truncate(left) {
  let length = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 50;
  let end = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : "...";
  checkArguments(arguments.length, 2);
  const _left = liquidStringify(left);
  const _length = Number(length);
  if (isUndefined(length) || !Number.isInteger(_length)) throw new FilterArgumentError(`expected an integer length, found ${length}`);
  if (_left.length <= _length) return _left;
  const _end = liquidStringify(end);
  const stop = _length - _end.length < 0 ? 0 : _length - _end.length;
  return `${_left.slice(0, stop)}${_end}`;
}
const MAX_TRUNC_WORDS = 2147483647;

/**
 * Return the input string truncated to the specified number of words, with
 * the second argument appended. The number of words (first argument) defaults
 * to `15`. The second argument defaults to an ellipsis (`...`).
 *
 * If the input string already has fewer than the given number of words, it is
 * returned unchanged.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @param wordCount - Any value. If it can't be converted to a number, zero
 * will be used instead. Defaults to `15`.
 * @param end - Any value. Will be coerced to a string if it's not one already.
 * Defaults to `...`.
 * @returns The input string truncated to the specified number of words.
 */
function truncateWords(left) {
  let wordCount = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 15;
  let end = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : "...";
  checkArguments(arguments.length, 2);
  const _left = liquidStringify(left);
  let _wordCount = Number(wordCount);
  if (isUndefined(wordCount) || !Number.isInteger(_wordCount)) throw new FilterArgumentError(`expected an integer length, found ${wordCount}`);
  if (_wordCount <= 0) _wordCount = 1;
  if (_wordCount >= MAX_TRUNC_WORDS) return _left;
  const _end = liquidStringify(end);
  const words = _left.trim().split(/\s+/g);
  if (words.length <= _wordCount) return _left;
  return words.slice(0, _wordCount).join(" ") + _end;
}
function fixedEncodeURIComponent(s) {
  return encodeURIComponent(s).replace(/[!'()*]/g, function (c) {
    return `%${c.charCodeAt(0).toString(16).toUpperCase()}`;
  });
}

/**
 * Return the input string with URL reserved characters percent-escaped. Also
 * replaces `' '` with `'+'`.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @returns The input string with URL reserved characters percent-escaped.
 */
function urlEncode(left) {
  checkArguments(arguments.length, 0);
  return fixedEncodeURIComponent(liquidStringify(left)).replace(/%20/g, "+");
}

/**
 * Return the input string with `%xx` escapes replaced with their single-
 * character equivalents. Also replaces `'+'` with `' '`.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. Will be coerced to a string if it's not one already.
 * @returns The input string with `%xx` escapes replaced with their single-
 * character equivalents.
 */
function urlDecode(left) {
  checkArguments(arguments.length, 0);
  return decodeURIComponent(liquidStringify(left).replace(/\+/g, " "));
}

function base64Encode(left) {
  checkArguments(arguments.length, 0);
  return Buffer.from(liquidStringify(left)).toString("base64");
}
function base64Decode(left) {
  checkArguments(arguments.length, 0);
  const _left = liquidStringify(left);
  // Check for valid characters, valid groups size and valid padding.
  if (!_left.match(/^([0-9a-zA-Z+/]{4})*(([0-9a-zA-Z+/]{2}==)|([0-9a-zA-Z+/]{3}=))?$/)) throw new FilterArgumentError("invalid base64");
  return Buffer.from(_left, "base64").toString();
}
function base64UrlSafeEncode(left) {
  checkArguments(arguments.length, 0);
  // don't use "base64url" encoding, we want to keep the padding
  return Buffer.from(liquidStringify(left)).toString("base64").replace("+", "-").replace("/", "_");
}
function base64UrlSafeDecode(left) {
  checkArguments(arguments.length, 0);
  const _left = liquidStringify(left);
  // Check for valid characters, valid groups size and valid padding.
  if (!_left.match(/^([0-9a-zA-Z\\-_]{4})*(([0-9a-zA-Z\\-_]{2}==)|([0-9a-zA-Z\\-_]{3}=))?$/)) throw new FilterArgumentError("invalid base64");
  // don't use "base64url" encoding, we want to keep the padding
  return Buffer.from(_left.replace("-", "+").replace("_", "/"), "base64").toString();
}

var index$d = /*#__PURE__*/Object.freeze({
  __proto__: null,
  abs: abs,
  append: append,
  atLeast: atLeast,
  atMost: atMost,
  base64Decode: base64Decode,
  base64Encode: base64Encode,
  base64UrlSafeDecode: base64UrlSafeDecode,
  base64UrlSafeEncode: base64UrlSafeEncode,
  capitalize: capitalize,
  ceil: ceil,
  compact: compact,
  concat: concat,
  date: date,
  default_: default_,
  dividedBy: dividedBy,
  downcase: downcase,
  escape: escape,
  escapeOnce: escapeOnce,
  first: first,
  floor: floor,
  join: join,
  last: last,
  lstrip: lstrip,
  map: map,
  minus: minus,
  modulo: modulo,
  newlineToBr: newlineToBr,
  parseNumberOrZero: parseNumberOrZero,
  plus: plus,
  prepend: prepend,
  remove: remove,
  removeFirst: removeFirst,
  removeLast: removeLast,
  replace: replace,
  replaceFirst: replaceFirst,
  replaceLast: replaceLast,
  reverse: reverse,
  round: round,
  rstrip: rstrip,
  size: size,
  slice: slice,
  sort: sort,
  sortNatural: sortNatural,
  split: split,
  strip: strip,
  stripHtml: stripHtml,
  stripNewlines: stripNewlines,
  sum: sum,
  times: times,
  truncate: truncate,
  truncateWords: truncateWords,
  uniq: uniq,
  upcase: upcase,
  urlDecode: urlDecode,
  urlEncode: urlEncode,
  where: where
});

const TOKEN_LITERAL = "literal";
const TOKEN_STATEMENT = "TOKEN_STATEMENT";
const TOKEN_TAG = "TOKEN_TAG";
const TOKEN_RAW = "TOKEN_RAW";
const TOKEN_EOF$1 = "TOKEN_EOF";
const TOKEN_EXPRESSION = "TOKEN_EXPRESSION";
class Token {
  constructor(kind, value, index, input) {
    this.kind = kind;
    this.value = value;
    this.index = index;
    this.input = input;
  }
  toString() {
    return `(kind=${this.kind}, value=${this.value})`;
  }
  lineNumber() {
    return this.input.slice(0, this.index).split("\n").length;
  }
}
const EOF$1 = new Token(TOKEN_EOF$1, "EOF", -1, "");
class TemplateTokenStream {
  constructor(tokens) {
    this.tokens = tokens;
    this._current = this._next();
    this._peek = this._next();
  }
  get current() {
    return this._current;
  }
  get peek() {
    return this._peek;
  }
  expect(kind) {
    if (this.current.kind !== kind) {
      if (kind === TOKEN_EXPRESSION) {
        throw new LiquidSyntaxError(`missing tag expression`, this.current);
      } else {
        throw new LiquidSyntaxError(`expected '${kind}', found ${this.current.kind}`, this.current);
      }
    }
  }
  expectTag(name) {
    if (this.current.kind !== TOKEN_TAG) {
      throw new LiquidSyntaxError(`expected tag '${name}', found '${this.current.kind}'`, this.current);
    }
    if (this.current.value !== name) {
      throw new LiquidSyntaxError(`expected '${name}', found '${this.current.value}'`, this.current);
    }
  }
  next() {
    const current = this.current;
    this._current = this._peek;
    this._peek = this._next();
    return current;
  }
  _next() {
    const it = this.tokens.next();
    if (it.done) return EOF$1;
    return it.value;
  }
}

var token = /*#__PURE__*/Object.freeze({
  __proto__: null,
  TOKEN_EOF: TOKEN_EOF$1,
  TOKEN_EXPRESSION: TOKEN_EXPRESSION,
  TOKEN_LITERAL: TOKEN_LITERAL,
  TOKEN_RAW: TOKEN_RAW,
  TOKEN_STATEMENT: TOKEN_STATEMENT,
  TOKEN_TAG: TOKEN_TAG,
  TemplateTokenStream: TemplateTokenStream,
  Token: Token
});

const TOKEN_SKIP = "TOKEN_SKIP";
const TOKEN_ILLEGAL = "TOKEN_ILLEGAL";
const TOKEN_TRUE = "true";
const TOKEN_FALSE = "false";
const TOKEN_IDENT = "TOKEN_IDENT";
const TOKEN_IDENT_INDEX = "TOKEN_IDENT_INDEX";
const TOKEN_IDENT_STRING = "TOKEN_IDENT_STRING";
const TOKEN_DOT = "TOKEN_DOT";
const TOKEN_LBRACKET = "TOKEN_LBRACKET";
const TOKEN_RBRACKET = "TOKEN_RBRACKET";
const TOKEN_INTEGER = "TOKEN_INTEGER";
const TOKEN_FLOAT = "TOKEN_FLOAT";
const TOKEN_LPAREN = "TOKEN_LPAREN";
const TOKEN_RPAREN = "TOKEN_RPAREN";
const TOKEN_RANGE = "TOKEN_RANGE";
const TOKEN_RANGE_LPAREN = "TOKEN_RANGE_LPAREN";
const TOKEN_STRING = "TOKEN_STRING";
const TOKEN_EOF = "TOKEN_EOF";
const TOKEN_NEWLINE = "TOKEN_NEWLINE";
const TOKEN_EMPTY = "empty";
const TOKEN_NIL = "nil";
const TOKEN_NULL = "null";
const TOKEN_BLANK = "blank";
const TOKEN_WITH = "with";
const TOKEN_FOR = "for";
const TOKEN_AS = "as";
const TOKEN_BY = "by";
const TOKEN_CONTAINS = "contains";
const TOKEN_IN = "in";
const TOKEN_LIMIT = "limit";
const TOKEN_OFFSET = "offset";
const TOKEN_REVERSED = "reversed";
const TOKEN_CONTINUE = "continue";
const TOKEN_COLS = "cols";
const TOKEN_DPIPE = "TOKEN_DPIPE";
const TOKEN_PIPE = "TOKEN_PIPE";
const TOKEN_COLON = "TOKEN_COLON";
const TOKEN_COMMA = "TOKEN_COMMA";

// Assignment as used by `assign` and `capture` tags.
const TOKEN_ASSIGN = "TOKEN_ASSIGN";

// Inline conditional tokens
const TOKEN_IF = "if";
const TOKEN_ELSE = "else";

// Logical operators
const TOKEN_AND = "and";
const TOKEN_OR = "or";
const TOKEN_NOT = "not";

// Comparison operators
const TOKEN_EQ = "TOKEN_EQ";
const TOKEN_NE = "TOKEN_NE";
const TOKEN_LG = "TOKEN_LG";
const TOKEN_LT = "TOKEN_LT";
const TOKEN_GT = "TOKEN_GT";
const TOKEN_LE = "TOKEN_LE";
const TOKEN_GE = "TOKEN_GE";
const TOKEN_OP = "TOKEN_OP";
const OPERATORS = new Map([["==", TOKEN_EQ], ["!=", TOKEN_NE], ["<>", TOKEN_LG], ["<", TOKEN_LT], [">", TOKEN_GT], ["<=", TOKEN_LE], [">=", TOKEN_GE], ["|", TOKEN_PIPE], [":", TOKEN_COLON], [",", TOKEN_COMMA], [".", TOKEN_DOT], ["(", TOKEN_LPAREN], [")", TOKEN_RPAREN], ["..", TOKEN_RANGE], ["[", TOKEN_LBRACKET], ["]", TOKEN_RBRACKET], ["=", TOKEN_ASSIGN]]);
const REVERSE_OPERATORS = new Map(Array.from(OPERATORS.entries()).map(_ref => {
  let [k, v] = _ref;
  return [v, k];
}));
const EOF = new Token(TOKEN_EOF, "EOF", -1, "");
class ExpressionTokenStream {
  _buf = undefined;
  constructor(tokens) {
    this.tokens = tokens;
    this._current = this._next();
    this._peek = this._next();
  }
  expectTag() {
    throw new Error("Method not implemented.");
  }
  get current() {
    return this._current;
  }
  get peek() {
    return this._peek;
  }
  next() {
    const current = this.current;
    this._current = this._peek;
    if (this._buf) {
      this._peek = this._buf;
      this._buf = undefined;
    } else {
      this._peek = this._next();
    }
    return current;
  }
  push(token) {
    if (this._buf !== undefined) throw new PushedTooFarError("can't push more than one token");
    this._buf = this._peek;
    this._peek = this._current;
    this._current = token;
  }
  expect(kind) {
    if (this.current.kind !== kind) throw new LiquidSyntaxError(`expected '${reverseOperatorLookup(kind)}', found '${reverseOperatorLookup(this.current.kind)}'`, this.current);
  }
  expectPeek(kind) {
    if (this.peek.kind !== kind) throw new LiquidSyntaxError(`expected '${reverseOperatorLookup(kind)}', found '${reverseOperatorLookup(this.peek.kind)}'`, this.peek);
  }
  _next() {
    const it = this.tokens.next();
    if (it.done) return EOF;
    return it.value;
  }
}

/**
 * Return the operator that matches the given token kind, or the
 * input kind if it's not an operator token.
 */
function reverseOperatorLookup(kind) {
  return REVERSE_OPERATORS.has(kind) ? REVERSE_OPERATORS.get(kind) : kind;
}

var MatchGroup$1 = /*#__PURE__*/function (MatchGroup) {
  MatchGroup["QUOTE"] = "quote";
  MatchGroup["QUOTED"] = "quoted";
  MatchGroup["IDENT_INDEX"] = "identIndex";
  MatchGroup["IDENT_QUOTE"] = "identQuote";
  MatchGroup["IDENT_QUOTED"] = "identQuoted";
  return MatchGroup;
}(MatchGroup$1 || {});
// Optional trailing question mark.
const IDENTIFIER_PATTERN = "[a-zA-Z_][\\w\\-]*\\??";

// Trailing question mark is not allowed in assignment names.
const ASSIGN_IDENTIFIER_PATTERN = "[0-9a-zA-Z_][\\w\\-]*";

// ["ident"] or ['ident']
const IDENT_STRING_PATTERN = `\\[\\s*(?<${MatchGroup$1.IDENT_QUOTE}>["'])` + `(?<${MatchGroup$1.IDENT_QUOTED}>.*?)` + `\\k<${MatchGroup$1.IDENT_QUOTE}>\\s*]`;

// [0] or [-1]
const IDENT_INDEX_PATTERN = `\\[\\s*(?<${MatchGroup$1.IDENT_INDEX}>\\-?\\d+)\\s*]`;

// 'something' or "something"
const STRING_PATTERN = `(?<${MatchGroup$1.QUOTE}>['"])` + `(?<${MatchGroup$1.QUOTED}>.*?)` + `\\k<${MatchGroup$1.QUOTE}>`;
function parseBoolean(stream) {
  return stream.current.kind === TOKEN_TRUE ? TRUE : FALSE;
}
function parseNil() {
  return NIL;
}
function parseEmpty() {
  return EMPTY;
}
function parseBlank() {
  return BLANK;
}
function parseStringLiteral(stream) {
  return new StringLiteral(stream.current.value);
}
function parseIntegerLiteral(stream) {
  return new IntegerLiteral(new Integer(Number(stream.current.value)));
}
function parseFloatLiteral(stream) {
  return new FloatLiteral(new Float(Number(stream.current.value)));
}
const IDENT_TOKENS = new Set([TOKEN_IDENT, TOKEN_IDENT_INDEX, TOKEN_LBRACKET, TOKEN_DOT]);
function parseIdentifier$1(stream) {
  const path = [];
  const kind = stream.current.kind;
  let root;
  if (kind === TOKEN_LBRACKET) {
    root = null;
  } else if (kind === TOKEN_IDENT) {
    root = stream.current.value;
    stream.next();
  } else {
    throw new LiquidSyntaxError(`expected an identifier, found '${stream.current.value}'`, stream.current);
  }
  for (;;) {
    switch (stream.current.kind) {
      case TOKEN_IDENT:
        path.push(new IdentifierPathElement(stream.current.value));
        break;
      case TOKEN_IDENT_INDEX:
        path.push(new IdentifierPathElement(Number(stream.current.value)));
        break;
      case TOKEN_LBRACKET:
        stream.next();
        path.push(parseIdentifier$1(stream));
        // Eat close bracket
        stream.next();
        stream.expect(TOKEN_RBRACKET);
        break;
      case TOKEN_FLOAT:
        throw new LiquidSyntaxError(`expected an identifier, found ${stream.current.value}`, stream.current);
      case TOKEN_DOT:
        break;
      default:
        stream.push(stream.current);
        return new Identifier(root, path);
    }
    stream.next();
  }
}

/**
 *
 * @param stream -
 * @returns
 */
function parseStringOrIdentifier(stream) {
  let expression;
  switch (stream.current.kind) {
    case TOKEN_IDENT:
    case TOKEN_LBRACKET:
      expression = parseIdentifier$1(stream);
      break;
    case TOKEN_STRING:
      expression = parseStringLiteral(stream);
      break;
    default:
      throw new LiquidSyntaxError(`expected identifier or string, found '${String(stream.current.kind)}'`, stream.current);
  }
  return expression;
}
const RANGE_OBJ_TOKENS = new Set([TOKEN_IDENT, TOKEN_INTEGER, TOKEN_FLOAT]);

/**
 *
 * @param stream -
 * @returns
 */
function parseUnchainedIdentifier(stream) {
  const token = stream.current;
  const identifier = parseIdentifier$1(stream);
  if (identifier.path.length) throw new LiquidSyntaxError(`invalid identifier '${identifier}'`, token);
  return identifier;
}

/**
 *
 * @param parseObj -
 * @returns
 */
function makeParseRange(parseObj) {
  let expectToken = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : TOKEN_LPAREN;
  function _parseRangeLiteral(stream) {
    // Eat open parenthesis
    stream.expect(expectToken);
    stream.next();

    // Parse start
    if (!RANGE_OBJ_TOKENS.has(stream.current.kind)) throw new LiquidSyntaxError(`unexpected '${stream.current.value}' in range expression`, stream.current);
    const start = parseObj(stream);
    stream.next();

    // Eat range token
    stream.expect(TOKEN_RANGE);
    stream.next();

    // Parse stop
    if (!RANGE_OBJ_TOKENS.has(stream.current.kind)) throw new LiquidSyntaxError(`unexpected '${stream.current.value}' in range expression`, stream.current);
    const stop = parseObj(stream);

    // Eat close parenthesis
    stream.next();
    stream.expect(TOKEN_RPAREN);
    return new RangeLiteral(start, stop);
  }
  return _parseRangeLiteral;
}

const RULES$8 = [[TOKEN_IDENT_INDEX, IDENT_INDEX_PATTERN], [TOKEN_IDENT_STRING, IDENT_STRING_PATTERN], [TOKEN_STRING, STRING_PATTERN], [TOKEN_RANGE, "\\.\\."], [TOKEN_FLOAT, "-?\\d+\\.(?!\\.)\\d*"], [TOKEN_INTEGER, "-?\\d+\\b"], [TOKEN_DOT, "\\."], [TOKEN_IDENT, IDENTIFIER_PATTERN], [TOKEN_LPAREN, "\\("], [TOKEN_RPAREN, "\\)"], [TOKEN_LBRACKET, "\\["], [TOKEN_RBRACKET, "]"], [TOKEN_COMMA, ","], [TOKEN_COLON, ":"], [TOKEN_PIPE, "\\|"], [TOKEN_NEWLINE, "\\n"], [TOKEN_SKIP, "[ \\t\\r]+"], [TOKEN_ILLEGAL, "."]];
const KEYWORDS$7 = new Set([TOKEN_TRUE, TOKEN_FALSE, TOKEN_NIL, TOKEN_NULL, TOKEN_EMPTY, TOKEN_BLANK]);
const RE$8 = new RegExp(RULES$8.map(_ref => {
  let [n, p] = _ref;
  return `(?<${n}>${p})`;
}).join("|"), "gs");
function isIdentIndexMatch$7(match) {
  return match.TOKEN_IDENT_INDEX === undefined ? false : true;
}
function isIdentStringMatch$7(match) {
  return match.TOKEN_IDENT_STRING === undefined ? false : true;
}
function isStringMatch$7(match) {
  return match.TOKEN_STRING === undefined ? false : true;
}
function isRangeMatch$7(match) {
  return match.TOKEN_RANGE === undefined ? false : true;
}
function isFloatMatch$7(match) {
  return match.TOKEN_FLOAT === undefined ? false : true;
}
function isIntegerMatch$7(match) {
  return match.TOKEN_INTEGER === undefined ? false : true;
}
function isDotMatch$7(match) {
  return match.TOKEN_DOT === undefined ? false : true;
}
function isIdentifierMatch$7(match) {
  return match.TOKEN_IDENT === undefined ? false : true;
}
function isLParenMatch$7(match) {
  return match.TOKEN_LPAREN === undefined ? false : true;
}
function isRParenMatch$7(match) {
  return match.TOKEN_RPAREN === undefined ? false : true;
}
function isLBracketMatch$7(match) {
  return match.TOKEN_LBRACKET === undefined ? false : true;
}
function isRBracketMatch$7(match) {
  return match.TOKEN_RBRACKET === undefined ? false : true;
}
function isCommaMatch$5(match) {
  return match.TOKEN_COMMA === undefined ? false : true;
}
function isColonMatch$4(match) {
  return match.TOKEN_COLON === undefined ? false : true;
}
function isPipeMatch$2(match) {
  return match.TOKEN_PIPE === undefined ? false : true;
}
function isNewlineMatch$7(match) {
  return match.TOKEN_NEWLINE === undefined ? false : true;
}
function isSkipMatch$8(match) {
  return match.TOKEN_SKIP === undefined ? false : true;
}
function isIllegalMatch$8(match) {
  return match.TOKEN_ILLEGAL === undefined ? false : true;
}
function makeTokenizer$7(re, keywords) {
  // eslint-disable-next-line sonarjs/cognitive-complexity
  return function tokenize(source) {
    let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    return function* () {
      for (const match of source.matchAll(re)) {
        const groups = match.groups;
        if (isIdentifierMatch$7(groups)) {
          if (keywords.has(groups.TOKEN_IDENT)) yield new Token(match[0], match[0], match.index + startIndex, source);else yield new Token(TOKEN_IDENT, groups.TOKEN_IDENT, match.index + startIndex, source);
        } else if (isIdentIndexMatch$7(groups)) yield new Token(TOKEN_IDENT_INDEX, groups.identIndex, match.index + startIndex, source);else if (isIdentStringMatch$7(groups)) yield new Token(TOKEN_IDENT, groups.identQuoted, match.index + startIndex, source);else if (isStringMatch$7(groups)) yield new Token(TOKEN_STRING, groups.quoted, match.index + startIndex, source);else if (isNewlineMatch$7(groups) || isSkipMatch$8(groups)) continue;else if (isRangeMatch$7(groups)) yield new Token(TOKEN_RANGE, groups.TOKEN_RANGE, match.index + startIndex, source);else if (isFloatMatch$7(groups)) yield new Token(TOKEN_FLOAT, groups.TOKEN_FLOAT, match.index + startIndex, source);else if (isIntegerMatch$7(groups)) yield new Token(TOKEN_INTEGER, groups.TOKEN_INTEGER, match.index + startIndex, source);else if (isDotMatch$7(groups)) yield new Token(TOKEN_DOT, groups.TOKEN_DOT, match.index + startIndex, source);else if (isLParenMatch$7(groups)) yield new Token(TOKEN_LPAREN, groups.TOKEN_LPAREN, match.index + startIndex, source);else if (isRParenMatch$7(groups)) yield new Token(TOKEN_RPAREN, groups.TOKEN_RPAREN, match.index + startIndex, source);else if (isLBracketMatch$7(groups)) yield new Token(TOKEN_LBRACKET, groups.TOKEN_LBRACKET, match.index + startIndex, source);else if (isRBracketMatch$7(groups)) yield new Token(TOKEN_RBRACKET, groups.TOKEN_RBRACKET, match.index + startIndex, source);else if (isCommaMatch$5(groups)) yield new Token(TOKEN_COMMA, groups.TOKEN_COMMA, match.index + startIndex, source);else if (isColonMatch$4(groups)) yield new Token(TOKEN_COLON, groups.TOKEN_COLON, match.index + startIndex, source);else if (isPipeMatch$2(groups)) yield new Token(TOKEN_PIPE, groups.TOKEN_PIPE, match.index + startIndex, source);else if (isIllegalMatch$8(groups)) throw new LiquidSyntaxError(`unexpected token '${groups.TOKEN_ILLEGAL}'`, new Token(TOKEN_ILLEGAL, groups.TOKEN_ILLEGAL, match.index + startIndex, source));
      }
    }();
  };
}
const tokenize$9 = makeTokenizer$7(RE$8, KEYWORDS$7);

const TOKEN_MAP$3 = new Map([[TOKEN_FALSE, parseBoolean], [TOKEN_TRUE, parseBoolean], [TOKEN_NIL, parseNil], [TOKEN_NULL, parseNil], [TOKEN_EMPTY, parseEmpty], [TOKEN_BLANK, parseBlank], [TOKEN_STRING, parseStringLiteral], [TOKEN_INTEGER, parseIntegerLiteral], [TOKEN_FLOAT, parseFloatLiteral], [TOKEN_IDENT, parseIdentifier$1], [TOKEN_LBRACKET, parseIdentifier$1]]);
function parseObject$2(stream) {
  const func = TOKEN_MAP$3.get(stream.current.kind);
  if (func) return func(stream);
  throw new LiquidSyntaxError(`unexpected '${stream.current.value}'`, stream.current);
}
TOKEN_MAP$3.set(TOKEN_LPAREN, makeParseRange(parseObject$2));
function* splitAtFirstPipe(tokens) {
  const buf = [];
  for (const token of tokens) {
    if (token.kind === TOKEN_PIPE) {
      yield buf;
      yield Array.from(tokens);
      return;
    }
    buf.push(token);
  }
  yield buf;
}
function* splitAtPipe$1(tokens) {
  let buf = [];
  for (const token of tokens) {
    if (token.kind === TOKEN_PIPE) {
      yield buf;
      buf = [];
    } else {
      buf.push(token);
    }
  }
  yield buf;
}
function parseFilter(tokens) {
  const stream = new ExpressionTokenStream(tokens.values());
  stream.expect(TOKEN_IDENT);
  const name = stream.next().value;

  // Shortcut for filters with no arguments.
  if (stream.current.kind === TOKEN_EOF) return new ExpressionFilter(name);

  // Eat colon
  stream.expect(TOKEN_COLON);
  stream.next();
  const args = [];
  const kwargs = new Map();
  while (stream.current.kind !== TOKEN_EOF) {
    if (stream.peek.kind === TOKEN_COLON) {
      // A keyword argument
      const kw = stream.next().value;
      // Eat colon
      stream.expect(TOKEN_COLON);
      stream.next();
      kwargs.set(kw, parseObject$2(stream));
    } else {
      // A positional argument
      args.push(parseObject$2(stream));
    }

    // Eat comma
    stream.next();
    if (stream.current.kind !== TOKEN_EOF) {
      stream.expect(TOKEN_COMMA);
      stream.next();
    }
  }
  return new ExpressionFilter(name, args, kwargs);
}
function parseFromTokens(tokens) {
  const parts = Array.from(splitAtFirstPipe(tokens));
  if (parts.length === 1) {
    return new FilteredExpression(parseObject$2(new ExpressionTokenStream(parts[0].values())));
  }
  return new FilteredExpression(parseObject$2(new ExpressionTokenStream(parts[0].values())), Array.from(splitAtPipe$1(parts[1].values())).map(parseFilter));
}
function parse$6(expr) {
  let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  return parseFromTokens(tokenize$9(expr, startIndex));
}

class AssignTag {
  static RE_ASSIGN = new RegExp(`^(${ASSIGN_IDENTIFIER_PATTERN})\\s*=\\s*(.+)$`, "s");
  block = false;
  name = "assign";
  nodeClass = AssignNode;
  parseExpression(value, startIndex) {
    return parse$6(value, startIndex);
  }
  parse(stream) {
    const token = stream.next();
    stream.expect(TOKEN_EXPRESSION);
    const match = stream.current.value.match(AssignTag.RE_ASSIGN);
    if (!match) throw new LiquidSyntaxError(`invalid assignment expression '${stream.current.value}'`, token);
    const [, name, expr] = match;
    return new this.nodeClass(token, name, this.parseExpression(expr, stream.current.index));
  }
}
class AssignNode {
  constructor(token, name, expression) {
    this.token = token;
    this.name = name;
    this.expression = expression;
  }
  async render(context) {
    context.assign(this.name, this.expression instanceof Literal ? this.expression.evaluateSync(context) : await this.expression.evaluate(context));
  }
  renderSync(context) {
    context.assign(this.name, this.expression.evaluateSync(context));
  }
  children() {
    return [{
      token: this.token,
      expression: this.expression,
      templateScope: [this.name]
    }];
  }
}

class CaptureTag {
  static END_CAPTURE_BLOCK = new Set(["endcapture", TOKEN_EOF$1]);
  static RE_CAPTURE = new RegExp("^\\w[a-zA-Z0-9_\\-]*$");
  block = true;
  name = "capture";
  end = "endcapture";
  nodeClass = CaptureNode;
  parse(stream, environment) {
    const token = stream.next();
    stream.expect(TOKEN_EXPRESSION);
    if (!CaptureTag.RE_CAPTURE.test(stream.current.value)) {
      throw new LiquidSyntaxError(`invalid capture identifier '${stream.current.value}'`, token);
    }
    const name = stream.next().value;
    return new this.nodeClass(token, name, environment.parser.parseBlock(stream, CaptureTag.END_CAPTURE_BLOCK, token));
  }
}
class CaptureNode {
  captureOutput = true;
  constructor(token, name, block) {
    this.token = token;
    this.name = name;
    this.block = block;
  }
  assign(context, buffer) {
    if (context.environment.autoEscape) context.assign(this.name, new Markup(buffer.toString()));else context.assign(this.name, buffer.toString());
  }
  async render(context, out) {
    const buf = context.environment.renderStreamFactory(out);
    await this.block.render(context, buf);
    this.assign(context, buf);
  }
  renderSync(context, out) {
    const buf = context.environment.renderStreamFactory(out);
    this.block.renderSync(context, buf);
    this.assign(context, buf);
  }
  children() {
    return [{
      token: this.token,
      node: this.block,
      templateScope: [this.name]
    }];
  }
}

class TemplateLiteral {
  block = false;
  name = TOKEN_LITERAL;
  nodeClass = LiteralNode;
  parse(stream) {
    return new this.nodeClass(stream.current);
  }
}
class LiteralNode {
  constructor(token) {
    this.token = token;
  }
  async render(context, out) {
    out.write(this.token.value);
  }
  renderSync(context, out) {
    out.write(this.token.value);
  }
  children() {
    return [];
  }
}

/**
 * The root of an abstract syntax tree.
 */
class Root {
  nodes = [];
}

/**
 * A block of abstract syntax tree nodes.
 */
let BlockNode$1 = class BlockNode {
  constructor(token) {
    let nodes = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
    this.token = token;
    this.nodes = nodes;
  }
  async render(context, out) {
    for (const node of this.nodes) {
      throwForDisabledTag(node, context);
      try {
        if (node instanceof LiteralNode) {
          node.renderSync(context, out);
        } else {
          await node.render(context, out);
        }
      } catch (error) {
        if (error instanceof InternalLiquidError) {
          throw error.withToken(node.token, context.templateName);
        }
        throw error;
      }
    }
  }
  renderSync(context, out) {
    for (const node of this.nodes) {
      throwForDisabledTag(node, context);
      try {
        node.renderSync(context, out);
      } catch (error) {
        if (error instanceof InternalLiquidError) {
          throw error.withToken(node.token, context.templateName);
        }
        throw error;
      }
    }
  }
  children() {
    return this.nodes.map(n => ({
      token: this.token,
      node: n
    }));
  }
};

/**
 * An AST node and optional expression guarding that node.
 */

/**
 * Traverse the syntax tree rooted at `root` in depth-first pre-order.
 *
 * @param root - The syntax tree node to start from.
 * @returns A generator producing nodes that are decedents of the `root` node.
 */
function* walk(root) {
  if (root.children) {
    for (const node of root.children()) {
      yield node;
      if (node.node) yield* walk(node.node);
    }
  }
}

/**
 * Return `true` if the syntax tree rooted at `root` contains
 * output statements (or equivalent nodes). `false` otherwise.
 */
function forcedOutput(root) {
  for (const child of walk(root)) {
    if (child.node?.captureOutput) return false;
    if (child.node?.forceOutput) return true;
  }
  return false;
}

/**
 * Throw an error if the given tag is disallowed in the given context.
 */
function throwForDisabledTag(node, context, templateName) {
  if (!!context.disabledTags.size && node.token.kind === TOKEN_TAG && context.disabledTags.has(node.token.value)) throw new DisabledTagError(`'${node.token.value}' is not allowed in this context`, node.token, templateName);
}

const RULES$7 = [[TOKEN_IDENT_INDEX, IDENT_INDEX_PATTERN], [TOKEN_IDENT_STRING, IDENT_STRING_PATTERN], [TOKEN_STRING, STRING_PATTERN], [TOKEN_RANGE, "\\.\\."], [TOKEN_FLOAT, "-?\\d+\\.(?!\\.)\\d*"], [TOKEN_INTEGER, "-?\\d+\\b"], [TOKEN_DOT, "\\."], [TOKEN_IDENT, IDENTIFIER_PATTERN], [TOKEN_LPAREN, "\\("], [TOKEN_RPAREN, "\\)"], [TOKEN_LBRACKET, "\\["], [TOKEN_RBRACKET, "]"], [TOKEN_NEWLINE, "\\n"], [TOKEN_OP, "[!=<>]{1,2}"], [TOKEN_SKIP, "[ \\t\\r]+"], [TOKEN_ILLEGAL, "."]];
const KEYWORDS$6 = new Set([TOKEN_TRUE, TOKEN_FALSE, TOKEN_NIL, TOKEN_NULL, TOKEN_EMPTY, TOKEN_BLANK, TOKEN_AND, TOKEN_OR, TOKEN_CONTAINS]);
const RE$7 = new RegExp(RULES$7.map(_ref => {
  let [n, p] = _ref;
  return `(?<${n}>${p})`;
}).join("|"), "gs");
function isIdentIndexMatch$6(match) {
  return match.TOKEN_IDENT_INDEX === undefined ? false : true;
}
function isIdentStringMatch$6(match) {
  return match.TOKEN_IDENT_STRING === undefined ? false : true;
}
function isStringMatch$6(match) {
  return match.TOKEN_STRING === undefined ? false : true;
}
function isRangeMatch$6(match) {
  return match.TOKEN_RANGE === undefined ? false : true;
}
function isFloatMatch$6(match) {
  return match.TOKEN_FLOAT === undefined ? false : true;
}
function isIntegerMatch$6(match) {
  return match.TOKEN_INTEGER === undefined ? false : true;
}
function isDotMatch$6(match) {
  return match.TOKEN_DOT === undefined ? false : true;
}
function isIdentifierMatch$6(match) {
  return match.TOKEN_IDENT === undefined ? false : true;
}
function isLParenMatch$6(match) {
  return match.TOKEN_LPAREN === undefined ? false : true;
}
function isRParenMatch$6(match) {
  return match.TOKEN_RPAREN === undefined ? false : true;
}
function isLBracketMatch$6(match) {
  return match.TOKEN_LBRACKET === undefined ? false : true;
}
function isRBracketMatch$6(match) {
  return match.TOKEN_RBRACKET === undefined ? false : true;
}
function isNewlineMatch$6(match) {
  return match.TOKEN_NEWLINE === undefined ? false : true;
}
function isOpMatch$2(match) {
  return match.TOKEN_OP === undefined ? false : true;
}
function isSkipMatch$7(match) {
  return match.TOKEN_SKIP === undefined ? false : true;
}
function isIllegalMatch$7(match) {
  return match.TOKEN_ILLEGAL === undefined ? false : true;
}
function makeTokenizer$6(re, keywords) {
  // eslint-disable-next-line sonarjs/cognitive-complexity
  return function tokenize(source) {
    let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    return function* () {
      for (const match of source.matchAll(re)) {
        const groups = match.groups;
        if (isIdentifierMatch$6(groups)) {
          if (keywords.has(groups.TOKEN_IDENT)) yield new Token(groups.TOKEN_IDENT, match[0], match.index + startIndex, source);else yield new Token(TOKEN_IDENT, groups.TOKEN_IDENT, match.index + startIndex, source);
        } else if (isIdentIndexMatch$6(groups)) yield new Token(TOKEN_IDENT_INDEX, groups.identIndex, match.index + startIndex, source);else if (isIdentStringMatch$6(groups)) yield new Token(TOKEN_IDENT, groups.identQuoted, match.index + startIndex, source);else if (isStringMatch$6(groups)) yield new Token(TOKEN_STRING, groups.quoted, match.index + startIndex, source);else if (isNewlineMatch$6(groups) || isSkipMatch$7(groups)) continue;else if (isRangeMatch$6(groups)) yield new Token(TOKEN_RANGE, groups.TOKEN_RANGE, match.index + startIndex, source);else if (isFloatMatch$6(groups)) yield new Token(TOKEN_FLOAT, groups.TOKEN_FLOAT, match.index + startIndex, source);else if (isIntegerMatch$6(groups)) yield new Token(TOKEN_INTEGER, groups.TOKEN_INTEGER, match.index + startIndex, source);else if (isDotMatch$6(groups)) yield new Token(TOKEN_DOT, groups.TOKEN_DOT, match.index + startIndex, source);else if (isLParenMatch$6(groups)) yield new Token(TOKEN_LPAREN, groups.TOKEN_LPAREN, match.index + startIndex, source);else if (isRParenMatch$6(groups)) yield new Token(TOKEN_RPAREN, groups.TOKEN_RPAREN, match.index + startIndex, source);else if (isLBracketMatch$6(groups)) yield new Token(TOKEN_LBRACKET, groups.TOKEN_LBRACKET, match.index + startIndex, source);else if (isRBracketMatch$6(groups)) yield new Token(TOKEN_RBRACKET, groups.TOKEN_RBRACKET, match.index + startIndex, source);else if (isOpMatch$2(groups)) {
          const op = OPERATORS.get(groups.TOKEN_OP);
          if (op === undefined) throw new LiquidSyntaxError(`unknown operator '${groups.TOKEN_OP}'`, new Token(TOKEN_ILLEGAL, groups.TOKEN_OP, match.index + startIndex, source));
          yield new Token(op, groups.TOKEN_OP, match.index + startIndex, source);
        } else if (isIllegalMatch$7(groups)) throw new LiquidSyntaxError(`unexpected token '${groups.TOKEN_ILLEGAL}'`, new Token(TOKEN_ILLEGAL, groups.TOKEN_ILLEGAL, match.index + startIndex, source));
      }
    }();
  };
}
const tokenize$8 = makeTokenizer$6(RE$7, KEYWORDS$6);

const PRECEDENCE_LOWEST$1 = 1;
const PRECEDENCE_LOGICAL_RIGHT$1 = 3;
const PRECEDENCE_RELATIONAL$1 = 5;
const PRECEDENCE_MEMBERSHIP$1 = 6;
const PRECEDENCES$1 = new Map([[TOKEN_IDENT, PRECEDENCE_LOWEST$1], [TOKEN_EQ, PRECEDENCE_RELATIONAL$1], [TOKEN_LT, PRECEDENCE_RELATIONAL$1], [TOKEN_GT, PRECEDENCE_RELATIONAL$1], [TOKEN_NE, PRECEDENCE_RELATIONAL$1], [TOKEN_LG, PRECEDENCE_RELATIONAL$1], [TOKEN_LE, PRECEDENCE_RELATIONAL$1], [TOKEN_GE, PRECEDENCE_RELATIONAL$1], [TOKEN_CONTAINS, PRECEDENCE_MEMBERSHIP$1], [TOKEN_AND, PRECEDENCE_LOGICAL_RIGHT$1], [TOKEN_OR, PRECEDENCE_LOGICAL_RIGHT$1]]);
const TOKEN_MAP$2 = new Map([[TOKEN_FALSE, parseBoolean], [TOKEN_TRUE, parseBoolean], [TOKEN_NIL, parseNil], [TOKEN_NULL, parseNil], [TOKEN_EMPTY, parseEmpty], [TOKEN_BLANK, parseBlank], [TOKEN_STRING, parseStringLiteral], [TOKEN_INTEGER, parseIntegerLiteral], [TOKEN_FLOAT, parseFloatLiteral], [TOKEN_IDENT, parseIdentifier$1], [TOKEN_LBRACKET, parseIdentifier$1], [TOKEN_LPAREN, makeParseRange(parseObject$1)]]);
const BINARY_OPERATORS$1 = new Set([TOKEN_EQ, TOKEN_OR, TOKEN_AND, TOKEN_LT, TOKEN_GT, TOKEN_NE, TOKEN_LG, TOKEN_LE, TOKEN_GE, TOKEN_CONTAINS]);
function parseInfixExpression$1(stream, left) {
  const token = stream.current;
  const precedence = PRECEDENCES$1.has(token.kind) ? PRECEDENCES$1.get(token.kind) : PRECEDENCE_LOWEST$1;
  stream.next();
  return new InfixExpression(left, token.value, parseObject$1(stream, precedence));
}
function parseObject$1(stream) {
  let precedence = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : PRECEDENCE_LOWEST$1;
  const func = TOKEN_MAP$2.get(stream.current.kind);
  if (!func) throw new LiquidSyntaxError(`unexpected '${stream.current.value}'`, stream.current);
  let left = func(stream);
  for (;;) {
    const pKind = stream.peek.kind;
    const pPrec = PRECEDENCES$1.has(pKind) ? PRECEDENCES$1.get(pKind) : PRECEDENCE_LOWEST$1;
    if (pKind === TOKEN_EOF || pPrec < precedence) break;
    if (!BINARY_OPERATORS$1.has(pKind)) return left;
    stream.next();
    left = parseInfixExpression$1(stream, left);
  }
  return left;
}
function parse$5(expr) {
  let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
  return new BooleanExpression(parseObject$1(new ExpressionTokenStream(tokenize$8(expr, startIndex))));
}

var index$c = /*#__PURE__*/Object.freeze({
  __proto__: null,
  TOKEN_MAP: TOKEN_MAP$2,
  makeTokenizer: makeTokenizer$6,
  parse: parse$5,
  parseInfixExpression: parseInfixExpression$1,
  parseObject: parseObject$1,
  tokenize: tokenize$8
});

var index$b = /*#__PURE__*/Object.freeze({
  __proto__: null,
  RE: RE$8,
  RULES: RULES$8,
  TOKEN_MAP: TOKEN_MAP$3,
  makeTokenizer: makeTokenizer$7,
  parse: parse$6,
  parseFilter: parseFilter,
  parseFromTokens: parseFromTokens,
  parseObject: parseObject$2,
  tokenize: tokenize$9
});

const RULES$6 = [[TOKEN_IDENT_INDEX, IDENT_INDEX_PATTERN], [TOKEN_IDENT_STRING, IDENT_STRING_PATTERN], [TOKEN_STRING, STRING_PATTERN], [TOKEN_RANGE, "\\.\\."], [TOKEN_FLOAT, "-?\\d+\\.(?!\\.)\\d*"], [TOKEN_INTEGER, "-?\\d+\\b"], [TOKEN_DOT, "\\."], [TOKEN_IDENT, IDENTIFIER_PATTERN], [TOKEN_LPAREN, "\\("], [TOKEN_RPAREN, "\\)"], [TOKEN_LBRACKET, "\\["], [TOKEN_RBRACKET, "]"], [TOKEN_COMMA, ","], [TOKEN_COLON, ":"], [TOKEN_NEWLINE, "\\n"], [TOKEN_SKIP, "[ \\t\\r]+"], [TOKEN_ILLEGAL, "."]];
const KEYWORDS$5 = new Set([TOKEN_TRUE, TOKEN_FALSE, TOKEN_NIL, TOKEN_NULL, TOKEN_EMPTY, TOKEN_BLANK, TOKEN_WITH, TOKEN_FOR, TOKEN_AS]);
const RE$6 = new RegExp(RULES$6.map(_ref => {
  let [n, p] = _ref;
  return `(?<${n}>${p})`;
}).join("|"), "gs");
function isIdentIndexMatch$5(match) {
  return match.TOKEN_IDENT_INDEX === undefined ? false : true;
}
function isIdentStringMatch$5(match) {
  return match.TOKEN_IDENT_STRING === undefined ? false : true;
}
function isStringMatch$5(match) {
  return match.TOKEN_STRING === undefined ? false : true;
}
function isRangeMatch$5(match) {
  return match.TOKEN_RANGE === undefined ? false : true;
}
function isFloatMatch$5(match) {
  return match.TOKEN_FLOAT === undefined ? false : true;
}
function isIntegerMatch$5(match) {
  return match.TOKEN_INTEGER === undefined ? false : true;
}
function isDotMatch$5(match) {
  return match.TOKEN_DOT === undefined ? false : true;
}
function isIdentifierMatch$5(match) {
  return match.TOKEN_IDENT === undefined ? false : true;
}
function isLParenMatch$5(match) {
  return match.TOKEN_LPAREN === undefined ? false : true;
}
function isRParenMatch$5(match) {
  return match.TOKEN_RPAREN === undefined ? false : true;
}
function isLBracketMatch$5(match) {
  return match.TOKEN_LBRACKET === undefined ? false : true;
}
function isRBracketMatch$5(match) {
  return match.TOKEN_RBRACKET === undefined ? false : true;
}
function isCommaMatch$4(match) {
  return match.TOKEN_COMMA === undefined ? false : true;
}
function isColonMatch$3(match) {
  return match.TOKEN_COLON === undefined ? false : true;
}
function isNewlineMatch$5(match) {
  return match.TOKEN_NEWLINE === undefined ? false : true;
}
function isSkipMatch$6(match) {
  return match.TOKEN_SKIP === undefined ? false : true;
}
function isIllegalMatch$6(match) {
  return match.TOKEN_ILLEGAL === undefined ? false : true;
}
function makeTokenizer$5(re, keywords) {
  // eslint-disable-next-line sonarjs/cognitive-complexity
  return function tokenize(source) {
    let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    return function* () {
      for (const match of source.matchAll(re)) {
        const groups = match.groups;
        if (isIdentifierMatch$5(groups)) {
          if (keywords.has(groups.TOKEN_IDENT)) yield new Token(match[0], match[0], match.index + startIndex, source);else yield new Token(TOKEN_IDENT, groups.TOKEN_IDENT, match.index + startIndex, source);
        } else if (isIdentIndexMatch$5(groups)) yield new Token(TOKEN_IDENT_INDEX, groups.identIndex, match.index + startIndex, source);else if (isIdentStringMatch$5(groups)) yield new Token(TOKEN_IDENT, groups.identQuoted, match.index + startIndex, source);else if (isStringMatch$5(groups)) yield new Token(TOKEN_STRING, groups.quoted, match.index + startIndex, source);else if (isNewlineMatch$5(groups) || isSkipMatch$6(groups)) continue;else if (isRangeMatch$5(groups)) yield new Token(TOKEN_RANGE, groups.TOKEN_RANGE, match.index + startIndex, source);else if (isFloatMatch$5(groups)) yield new Token(TOKEN_FLOAT, groups.TOKEN_FLOAT, match.index + startIndex, source);else if (isIntegerMatch$5(groups)) yield new Token(TOKEN_INTEGER, groups.TOKEN_INTEGER, match.index + startIndex, source);else if (isDotMatch$5(groups)) yield new Token(TOKEN_DOT, groups.TOKEN_DOT, match.index + startIndex, source);else if (isLParenMatch$5(groups)) yield new Token(TOKEN_LPAREN, groups.TOKEN_LPAREN, match.index + startIndex, source);else if (isRParenMatch$5(groups)) yield new Token(TOKEN_RPAREN, groups.TOKEN_RPAREN, match.index + startIndex, source);else if (isLBracketMatch$5(groups)) yield new Token(TOKEN_LBRACKET, groups.TOKEN_LBRACKET, match.index + startIndex, source);else if (isRBracketMatch$5(groups)) yield new Token(TOKEN_RBRACKET, groups.TOKEN_RBRACKET, match.index + startIndex, source);else if (isCommaMatch$4(groups)) yield new Token(TOKEN_COMMA, groups.TOKEN_COMMA, match.index + startIndex, source);else if (isColonMatch$3(groups)) yield new Token(TOKEN_COLON, groups.TOKEN_COLON, match.index + startIndex, source);else if (isIllegalMatch$6(groups)) throw new LiquidSyntaxError(`unexpected token '${groups.TOKEN_ILLEGAL}'`, new Token(TOKEN_ILLEGAL, groups.TOKEN_ILLEGAL, match.index + startIndex, source));
      }
    }();
  };
}
const tokenize$7 = makeTokenizer$5(RE$6, KEYWORDS$5);

var index$a = /*#__PURE__*/Object.freeze({
  __proto__: null,
  RE: RE$6,
  RULES: RULES$6,
  makeTokenizer: makeTokenizer$5,
  tokenize: tokenize$7
});

const RULES$5 = [[TOKEN_IDENT_INDEX, IDENT_INDEX_PATTERN], [TOKEN_IDENT_STRING, IDENT_STRING_PATTERN], [TOKEN_STRING, STRING_PATTERN], [TOKEN_RANGE, "\\.\\."], [TOKEN_FLOAT, "-?\\d+\\.(?!\\.)\\d*"], [TOKEN_INTEGER, "-?\\d+\\b"], [TOKEN_DOT, "\\."], [TOKEN_IDENT, IDENTIFIER_PATTERN], [TOKEN_LPAREN, "\\("], [TOKEN_RPAREN, "\\)"], [TOKEN_LBRACKET, "\\["], [TOKEN_RBRACKET, "]"], [TOKEN_COLON, ":"], [TOKEN_COMMA, ","], [TOKEN_PIPE, "\\|"], [TOKEN_NEWLINE, "\\n"], [TOKEN_SKIP, "[ \\t\\r]+"], [TOKEN_ILLEGAL, "."]];
const KEYWORDS$4 = new Set([TOKEN_IN, TOKEN_OFFSET, TOKEN_LIMIT, TOKEN_REVERSED, TOKEN_COLS, TOKEN_CONTINUE]);
const RE$5 = new RegExp(RULES$5.map(_ref => {
  let [n, p] = _ref;
  return `(?<${n}>${p})`;
}).join("|"), "gs");
function isIdentIndexMatch$4(match) {
  return match.TOKEN_IDENT_INDEX === undefined ? false : true;
}
function isIdentStringMatch$4(match) {
  return match.TOKEN_IDENT_STRING === undefined ? false : true;
}
function isStringMatch$4(match) {
  return match.TOKEN_STRING === undefined ? false : true;
}
function isRangeMatch$4(match) {
  return match.TOKEN_RANGE === undefined ? false : true;
}
function isFloatMatch$4(match) {
  return match.TOKEN_FLOAT === undefined ? false : true;
}
function isIntegerMatch$4(match) {
  return match.TOKEN_INTEGER === undefined ? false : true;
}
function isDotMatch$4(match) {
  return match.TOKEN_DOT === undefined ? false : true;
}
function isIdentifierMatch$4(match) {
  return match.TOKEN_IDENT === undefined ? false : true;
}
function isLParenMatch$4(match) {
  return match.TOKEN_LPAREN === undefined ? false : true;
}
function isRParenMatch$4(match) {
  return match.TOKEN_RPAREN === undefined ? false : true;
}
function isLBracketMatch$4(match) {
  return match.TOKEN_LBRACKET === undefined ? false : true;
}
function isRBracketMatch$4(match) {
  return match.TOKEN_RBRACKET === undefined ? false : true;
}
function isColonMatch$2(match) {
  return match.TOKEN_COLON === undefined ? false : true;
}
function isCommaMatch$3(match) {
  return match.TOKEN_COMMA === undefined ? false : true;
}
function isPipeMatch$1(match) {
  return match.TOKEN_PIPE === undefined ? false : true;
}
function isNewlineMatch$4(match) {
  return match.TOKEN_NEWLINE === undefined ? false : true;
}
function isSkipMatch$5(match) {
  return match.TOKEN_SKIP === undefined ? false : true;
}
function isIllegalMatch$5(match) {
  return match.TOKEN_ILLEGAL === undefined ? false : true;
}
function makeTokenizer$4(re, keywords) {
  // eslint-disable-next-line sonarjs/cognitive-complexity
  return function tokenize(source) {
    let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    return function* () {
      for (const match of source.matchAll(re)) {
        const groups = match.groups;
        if (isIdentifierMatch$4(groups)) {
          if (keywords.has(groups.TOKEN_IDENT)) yield new Token(groups.TOKEN_IDENT, match[0], match.index + startIndex, source);else yield new Token(TOKEN_IDENT, groups.TOKEN_IDENT, match.index + startIndex, source);
        } else if (isIdentIndexMatch$4(groups)) yield new Token(TOKEN_IDENT_INDEX, groups.identIndex, match.index + startIndex, source);else if (isIdentStringMatch$4(groups)) yield new Token(TOKEN_IDENT, groups.identQuoted, match.index + startIndex, source);else if (isStringMatch$4(groups)) yield new Token(TOKEN_STRING, groups.quoted, match.index + startIndex, source);else if (isNewlineMatch$4(groups) || isSkipMatch$5(groups)) continue;else if (isRangeMatch$4(groups)) yield new Token(TOKEN_RANGE, groups.TOKEN_RANGE, match.index + startIndex, source);else if (isFloatMatch$4(groups)) yield new Token(TOKEN_FLOAT, groups.TOKEN_FLOAT, match.index + startIndex, source);else if (isIntegerMatch$4(groups)) yield new Token(TOKEN_INTEGER, groups.TOKEN_INTEGER, match.index + startIndex, source);else if (isDotMatch$4(groups)) yield new Token(TOKEN_DOT, groups.TOKEN_DOT, match.index + startIndex, source);else if (isLParenMatch$4(groups)) yield new Token(TOKEN_LPAREN, groups.TOKEN_LPAREN, match.index + startIndex, source);else if (isRParenMatch$4(groups)) yield new Token(TOKEN_RPAREN, groups.TOKEN_RPAREN, match.index + startIndex, source);else if (isLBracketMatch$4(groups)) yield new Token(TOKEN_LBRACKET, groups.TOKEN_LBRACKET, match.index + startIndex, source);else if (isRBracketMatch$4(groups)) yield new Token(TOKEN_RBRACKET, groups.TOKEN_RBRACKET, match.index + startIndex, source);else if (isColonMatch$2(groups)) yield new Token(TOKEN_COLON, groups.TOKEN_COLON, match.index + startIndex, source);else if (isCommaMatch$3(groups)) yield new Token(TOKEN_COMMA, groups.TOKEN_COMMA, match.index + startIndex, source);else if (isPipeMatch$1(groups)) yield new Token(TOKEN_PIPE, groups.TOKEN_PIPE, match.index + startIndex, source);else if (isIllegalMatch$5(groups)) throw new LiquidSyntaxError(`unexpected token '${groups.TOKEN_ILLEGAL}'`, new Token(TOKEN_ILLEGAL, groups.TOKEN_ILLEGAL, match.index + startIndex, source));
      }
    }();
  };
}
const tokenize$6 = makeTokenizer$4(RE$5, KEYWORDS$4);

const LOOP_ARGS = new Set([TOKEN_LIMIT, TOKEN_OFFSET, TOKEN_COLS]);
const parseRange = makeParseRange(parseObject$2);
function parseContinue() {
  return CONTINUE;
}
function parseStringArgument(stream) {
  try {
    return new IntegerLiteral(new Integer(Number(stream.current.value)));
  } catch (error) {
    throw new LiquidSyntaxError(`invalid integer argument '${stream.current.value}'`, stream.current);
  }
}
const TOKEN_MAP$1 = new Map([[TOKEN_IDENT, parseIdentifier$1], [TOKEN_LBRACKET, parseIdentifier$1], [TOKEN_INTEGER, parseIntegerLiteral], [TOKEN_FLOAT, parseFloatLiteral], [TOKEN_CONTINUE, parseContinue], [TOKEN_STRING, parseStringArgument]]);
function parseLoopArgument(stream) {
  const pFunc = TOKEN_MAP$1.get(stream.current.kind);
  if (pFunc !== undefined) return pFunc(stream);
  throw new LiquidSyntaxError(`unexpected '${stream.current.value}'`, stream.current);
}
function parseLoopArguments(stream) {
  const args = new Map();
  let reversed = false;
  for (;;) {
    const tok = stream.current;
    if (tok.kind === TOKEN_EOF) break;
    if (tok.kind === TOKEN_COMMA) {
      stream.next();
    } else if (LOOP_ARGS.has(tok.kind)) {
      stream.next();
      stream.expect(TOKEN_COLON);
      stream.next();
      args.set(tok.value, parseLoopArgument(stream));
      stream.next();
    } else if (tok.kind === TOKEN_REVERSED) {
      stream.next();
      reversed = true;
    } else {
      throw new LiquidSyntaxError(`unexpected '${tok.value}'`, tok);
    }
  }
  return [args, reversed];
}
function parse$4(expr) {
  let lineNumber = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  const stream = new ExpressionTokenStream(tokenize$6(expr, lineNumber));
  stream.expect(TOKEN_IDENT);
  const name = stream.next().value;

  // Eat TOKEN_IN
  stream.expect(TOKEN_IN);
  stream.next();
  let expression;
  switch (stream.current.kind) {
    case TOKEN_IDENT:
    case TOKEN_LBRACKET:
      expression = parseIdentifier$1(stream);
      break;
    case TOKEN_LPAREN:
      expression = parseRange(stream);
      break;
    case TOKEN_STRING:
      expression = parseStringLiteral(stream);
      break;
    default:
      throw new LiquidSyntaxError(`invalid loop expression`, stream.current);
  }
  stream.next();
  const [args, reversed] = parseLoopArguments(stream);
  return new LoopExpression(name, expression, args.get("limit"), args.get("offset"), args.get("cols"), reversed);
}

var index$9 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  TOKEN_MAP: TOKEN_MAP$1,
  makeTokenizer: makeTokenizer$4,
  parse: parse$4,
  tokenize: tokenize$6
});

const RULES$4 = [[TOKEN_IDENT_INDEX, IDENT_INDEX_PATTERN], [TOKEN_IDENT_STRING, IDENT_STRING_PATTERN], [TOKEN_STRING, STRING_PATTERN], [TOKEN_RANGE_LPAREN, "\\((?=.+?\\.\\.)"], [TOKEN_RANGE, "\\.\\."], [TOKEN_FLOAT, "-?\\d+\\.(?!\\.)\\d*"], [TOKEN_INTEGER, "-?\\d+\\b"], [TOKEN_DOT, "\\."], [TOKEN_IDENT, IDENTIFIER_PATTERN], [TOKEN_LPAREN, "\\("], [TOKEN_RPAREN, "\\)"], [TOKEN_LBRACKET, "\\["], [TOKEN_RBRACKET, "]"], [TOKEN_NEWLINE, "\\n"], [TOKEN_OP, "[!=<>]{1,2}"], [TOKEN_SKIP, "[ \\t\\r]+"], [TOKEN_ILLEGAL, "."]];
const KEYWORDS$3 = new Set([TOKEN_AND, TOKEN_BLANK, TOKEN_CONTAINS, TOKEN_EMPTY, TOKEN_FALSE, TOKEN_NIL, TOKEN_NOT, TOKEN_NULL, TOKEN_OR, TOKEN_TRUE]);
const RE$4 = new RegExp(RULES$4.map(_ref => {
  let [n, p] = _ref;
  return `(?<${n}>${p})`;
}).join("|"), "gs");
function isIdentIndexMatch$3(match) {
  return match.TOKEN_IDENT_INDEX === undefined ? false : true;
}
function isIdentStringMatch$3(match) {
  return match.TOKEN_IDENT_STRING === undefined ? false : true;
}
function isStringMatch$3(match) {
  return match.TOKEN_STRING === undefined ? false : true;
}
function isRangeLParenMatch$1(match) {
  return match.TOKEN_RANGE_LPAREN === undefined ? false : true;
}
function isRangeMatch$3(match) {
  return match.TOKEN_RANGE === undefined ? false : true;
}
function isFloatMatch$3(match) {
  return match.TOKEN_FLOAT === undefined ? false : true;
}
function isIntegerMatch$3(match) {
  return match.TOKEN_INTEGER === undefined ? false : true;
}
function isDotMatch$3(match) {
  return match.TOKEN_DOT === undefined ? false : true;
}
function isIdentifierMatch$3(match) {
  return match.TOKEN_IDENT === undefined ? false : true;
}
function isLParenMatch$3(match) {
  return match.TOKEN_LPAREN === undefined ? false : true;
}
function isRParenMatch$3(match) {
  return match.TOKEN_RPAREN === undefined ? false : true;
}
function isLBracketMatch$3(match) {
  return match.TOKEN_LBRACKET === undefined ? false : true;
}
function isRBracketMatch$3(match) {
  return match.TOKEN_RBRACKET === undefined ? false : true;
}
function isNewlineMatch$3(match) {
  return match.TOKEN_NEWLINE === undefined ? false : true;
}
function isOpMatch$1(match) {
  return match.TOKEN_OP === undefined ? false : true;
}
function isSkipMatch$4(match) {
  return match.TOKEN_SKIP === undefined ? false : true;
}
function isIllegalMatch$4(match) {
  return match.TOKEN_ILLEGAL === undefined ? false : true;
}
function makeTokenizer$3(re, keywords) {
  // eslint-disable-next-line sonarjs/cognitive-complexity
  return function tokenize(source) {
    let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    return function* () {
      for (const match of source.matchAll(re)) {
        const groups = match.groups;
        if (isIdentifierMatch$3(groups)) {
          if (keywords.has(groups.TOKEN_IDENT)) yield new Token(groups.TOKEN_IDENT, match[0], match.index + startIndex, source);else yield new Token(TOKEN_IDENT, groups.TOKEN_IDENT, match.index + startIndex, source);
        } else if (isIdentIndexMatch$3(groups)) yield new Token(TOKEN_IDENT_INDEX, groups.identIndex, match.index + startIndex, source);else if (isIdentStringMatch$3(groups)) yield new Token(TOKEN_IDENT, groups.identQuoted, match.index + startIndex, source);else if (isStringMatch$3(groups)) yield new Token(TOKEN_STRING, groups.quoted, match.index + startIndex, source);else if (isNewlineMatch$3(groups) || isSkipMatch$4(groups)) continue;else if (isRangeLParenMatch$1(groups)) yield new Token(TOKEN_RANGE_LPAREN, groups.TOKEN_RANGE_LPAREN, match.index + startIndex, source);else if (isRangeMatch$3(groups)) yield new Token(TOKEN_RANGE, groups.TOKEN_RANGE, match.index + startIndex, source);else if (isFloatMatch$3(groups)) yield new Token(TOKEN_FLOAT, groups.TOKEN_FLOAT, match.index + startIndex, source);else if (isIntegerMatch$3(groups)) yield new Token(TOKEN_INTEGER, groups.TOKEN_INTEGER, match.index + startIndex, source);else if (isDotMatch$3(groups)) yield new Token(TOKEN_DOT, groups.TOKEN_DOT, match.index + startIndex, source);else if (isLParenMatch$3(groups)) yield new Token(TOKEN_LPAREN, groups.TOKEN_LPAREN, match.index + startIndex, source);else if (isRParenMatch$3(groups)) yield new Token(TOKEN_RPAREN, groups.TOKEN_RPAREN, match.index + startIndex, source);else if (isLBracketMatch$3(groups)) yield new Token(TOKEN_LBRACKET, groups.TOKEN_LBRACKET, match.index + startIndex, source);else if (isRBracketMatch$3(groups)) yield new Token(TOKEN_RBRACKET, groups.TOKEN_RBRACKET, match.index + startIndex, source);else if (isOpMatch$1(groups)) {
          const op = OPERATORS.get(groups.TOKEN_OP);
          if (op === undefined) throw new LiquidSyntaxError(`unknown operator '${groups.TOKEN_OP}'`, new Token(TOKEN_ILLEGAL, groups.TOKEN_OP, match.index + startIndex, source));
          yield new Token(op, groups.TOKEN_OP, match.index + startIndex, source);
        } else if (isIllegalMatch$4(groups)) throw new LiquidSyntaxError(`unexpected token '${groups.TOKEN_ILLEGAL}'`, new Token(TOKEN_ILLEGAL, groups.TOKEN_ILLEGAL, match.index + startIndex, source));
      }
    }();
  };
}
const tokenize$5 = makeTokenizer$3(RE$4, KEYWORDS$3);

const PRECEDENCE_LOWEST = 1;
const PRECEDENCE_LOGICAL_RIGHT = 3;
const PRECEDENCE_RELATIONAL = 5;
const PRECEDENCE_MEMBERSHIP = 6;
const PRECEDENCES = new Map([[TOKEN_RPAREN, PRECEDENCE_LOWEST], [TOKEN_IDENT, PRECEDENCE_LOWEST], [TOKEN_EQ, PRECEDENCE_RELATIONAL], [TOKEN_LT, PRECEDENCE_RELATIONAL], [TOKEN_GT, PRECEDENCE_RELATIONAL], [TOKEN_NE, PRECEDENCE_RELATIONAL], [TOKEN_LG, PRECEDENCE_RELATIONAL], [TOKEN_LE, PRECEDENCE_RELATIONAL], [TOKEN_GE, PRECEDENCE_RELATIONAL], [TOKEN_CONTAINS, PRECEDENCE_MEMBERSHIP], [TOKEN_AND, PRECEDENCE_LOGICAL_RIGHT], [TOKEN_OR, PRECEDENCE_LOGICAL_RIGHT]]);
const TOKEN_MAP = new Map([[TOKEN_FALSE, parseBoolean], [TOKEN_TRUE, parseBoolean], [TOKEN_NIL, parseNil], [TOKEN_NULL, parseNil], [TOKEN_EMPTY, parseEmpty], [TOKEN_BLANK, parseBlank], [TOKEN_STRING, parseStringLiteral], [TOKEN_INTEGER, parseIntegerLiteral], [TOKEN_FLOAT, parseFloatLiteral], [TOKEN_IDENT, parseIdentifier$1], [TOKEN_LBRACKET, parseIdentifier$1], [TOKEN_RANGE_LPAREN, makeParseRange(parseObject, TOKEN_RANGE_LPAREN)]]);
const BINARY_OPERATORS = new Set([TOKEN_EQ, TOKEN_OR, TOKEN_AND, TOKEN_LT, TOKEN_GT, TOKEN_NE, TOKEN_LG, TOKEN_LE, TOKEN_GE, TOKEN_CONTAINS]);
function parsePrefixExpression(stream) {
  const token = stream.next();
  return new PrefixExpression(token.value, parseObject(stream, PRECEDENCE_LOGICAL_RIGHT));
}
TOKEN_MAP.set(TOKEN_NOT, parsePrefixExpression);
function parseInfixExpression(stream, left) {
  const token = stream.current;
  const precedence = PRECEDENCES.has(token.kind) ? PRECEDENCES.get(token.kind) : PRECEDENCE_LOWEST;
  stream.next();
  return new InfixExpression(left, token.value, parseObject(stream, precedence));
}
function parseObject(stream) {
  let precedence = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : PRECEDENCE_LOWEST;
  const func = TOKEN_MAP.get(stream.current.kind);
  if (!func) throw new LiquidSyntaxError(`unexpected '${stream.current.value}'`, stream.current);
  let left = func(stream);
  for (;;) {
    const pKind = stream.peek.kind;
    const pPrec = PRECEDENCES.has(pKind) ? PRECEDENCES.get(pKind) : PRECEDENCE_LOWEST;
    if (pKind === TOKEN_EOF || pPrec < precedence) break;
    if (!BINARY_OPERATORS.has(pKind)) return left;
    stream.next();
    left = parseInfixExpression(stream, left);
  }
  return left;
}
function parse_grouped_expression(stream) {
  stream.next();
  let expr = parseObject(stream);
  stream.next();
  while (stream.current.kind !== TOKEN_RPAREN) {
    if (stream.current.kind === TOKEN_EOF) {
      throw new LiquidSyntaxError("unbalanced parentheses", stream.current);
    }
    expr = parseInfixExpression(stream, expr);
  }
  stream.expect(TOKEN_RPAREN);
  return expr;
}
TOKEN_MAP.set(TOKEN_LPAREN, parse_grouped_expression);

/**
 * Parse an expression that follows Liquid `if` tag semantics plus a
 * logical `not` operator and grouping with parentheses.
 */
function parse$3(expr) {
  let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  const stream = new ExpressionTokenStream(tokenize$5(expr, startIndex));
  const booleanExpression = new BooleanExpression(parseObject(stream));
  if (stream.peek.kind === TOKEN_RPAREN) {
    throw new LiquidSyntaxError("unmatched ')'", stream.peek);
  }
  if (stream.peek.kind !== TOKEN_EOF) {
    throw new LiquidSyntaxError(`unexpected '${stream.peek.value}'`, stream.peek);
  }
  return booleanExpression;
}

var index$8 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  TOKEN_MAP: TOKEN_MAP,
  makeTokenizer: makeTokenizer$3,
  parse: parse$3,
  parseInfixExpression: parseInfixExpression,
  parseObject: parseObject,
  parsePrefixExpression: parsePrefixExpression,
  tokenize: tokenize$5
});

/**
 * Regular expression patterns for tokens in a Liquid argument list.
 */
const RULES$3 = [[TOKEN_IDENT_INDEX, IDENT_INDEX_PATTERN], [TOKEN_IDENT_STRING, IDENT_STRING_PATTERN], [TOKEN_STRING, STRING_PATTERN], [TOKEN_RANGE, "\\.\\."], [TOKEN_FLOAT, "-?\\d+\\.(?!\\.)\\d*"], [TOKEN_INTEGER, "-?\\d+\\b"], [TOKEN_DOT, "\\."], [TOKEN_IDENT, IDENTIFIER_PATTERN], [TOKEN_LPAREN, "\\("], [TOKEN_RPAREN, "\\)"], [TOKEN_LBRACKET, "\\["], [TOKEN_RBRACKET, "]"], [TOKEN_COMMA, ","], [TOKEN_COLON, ":"], [TOKEN_ASSIGN, "="], [TOKEN_NEWLINE, "\\n"], [TOKEN_SKIP, "[ \\t\\r]+"], [TOKEN_ILLEGAL, "."]];
const KEYWORDS$2 = new Set([TOKEN_TRUE, TOKEN_FALSE, TOKEN_NIL, TOKEN_NULL]);

/**
 * The compiled regular expression, built using {@link RULES}.
 */
const RE$3 = new RegExp(RULES$3.map(_ref => {
  let [n, p] = _ref;
  return `(?<${n}>${p})`;
}).join("|"), "gs");
function isIdentIndexMatch$2(match) {
  return match.TOKEN_IDENT_INDEX === undefined ? false : true;
}
function isIdentStringMatch$2(match) {
  return match.TOKEN_IDENT_STRING === undefined ? false : true;
}
function isStringMatch$2(match) {
  return match.TOKEN_STRING === undefined ? false : true;
}
function isRangeMatch$2(match) {
  return match.TOKEN_RANGE === undefined ? false : true;
}
function isFloatMatch$2(match) {
  return match.TOKEN_FLOAT === undefined ? false : true;
}
function isIntegerMatch$2(match) {
  return match.TOKEN_INTEGER === undefined ? false : true;
}
function isDotMatch$2(match) {
  return match.TOKEN_DOT === undefined ? false : true;
}
function isIdentifierMatch$2(match) {
  return match.TOKEN_IDENT === undefined ? false : true;
}
function isLParenMatch$2(match) {
  return match.TOKEN_LPAREN === undefined ? false : true;
}
function isRParenMatch$2(match) {
  return match.TOKEN_RPAREN === undefined ? false : true;
}
function isLBracketMatch$2(match) {
  return match.TOKEN_LBRACKET === undefined ? false : true;
}
function isRBracketMatch$2(match) {
  return match.TOKEN_RBRACKET === undefined ? false : true;
}
function isCommaMatch$2(match) {
  return match.TOKEN_COMMA === undefined ? false : true;
}
function isColonMatch$1(match) {
  return match.TOKEN_COLON === undefined ? false : true;
}
function isAssignMatch(match) {
  return match.TOKEN_ASSIGN === undefined ? false : true;
}
function isNewlineMatch$2(match) {
  return match.TOKEN_NEWLINE === undefined ? false : true;
}
function isSkipMatch$3(match) {
  return match.TOKEN_SKIP === undefined ? false : true;
}
function isIllegalMatch$3(match) {
  return match.TOKEN_ILLEGAL === undefined ? false : true;
}

/***
 * Returns a generator function for tokenizing argument list expressions
 * using the given regular expression and keywords.
 */
function makeTokenizer$2(re, keywords) {
  // eslint-disable-next-line sonarjs/cognitive-complexity
  return function tokenize(source) {
    let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    return function* () {
      for (const match of source.matchAll(re)) {
        const groups = match.groups;
        if (isIdentifierMatch$2(groups)) {
          if (keywords.has(groups.TOKEN_IDENT)) yield new Token(match[0], match[0], match.index + startIndex, source);else yield new Token(TOKEN_IDENT, groups.TOKEN_IDENT, match.index + startIndex, source);
        } else if (isIdentIndexMatch$2(groups)) yield new Token(TOKEN_IDENT_INDEX, groups.identIndex, match.index + startIndex, source);else if (isIdentStringMatch$2(groups)) yield new Token(TOKEN_IDENT, groups.identQuoted, match.index + startIndex, source);else if (isStringMatch$2(groups)) yield new Token(TOKEN_STRING, groups.quoted, match.index + startIndex, source);else if (isNewlineMatch$2(groups) || isSkipMatch$3(groups)) continue;else if (isRangeMatch$2(groups)) yield new Token(TOKEN_RANGE, groups.TOKEN_RANGE, match.index + startIndex, source);else if (isFloatMatch$2(groups)) yield new Token(TOKEN_FLOAT, groups.TOKEN_FLOAT, match.index + startIndex, source);else if (isIntegerMatch$2(groups)) yield new Token(TOKEN_INTEGER, groups.TOKEN_INTEGER, match.index + startIndex, source);else if (isDotMatch$2(groups)) yield new Token(TOKEN_DOT, groups.TOKEN_DOT, match.index + startIndex, source);else if (isLParenMatch$2(groups)) yield new Token(TOKEN_LPAREN, groups.TOKEN_LPAREN, match.index + startIndex, source);else if (isRParenMatch$2(groups)) yield new Token(TOKEN_RPAREN, groups.TOKEN_RPAREN, match.index + startIndex, source);else if (isLBracketMatch$2(groups)) yield new Token(TOKEN_LBRACKET, groups.TOKEN_LBRACKET, match.index + startIndex, source);else if (isRBracketMatch$2(groups)) yield new Token(TOKEN_RBRACKET, groups.TOKEN_RBRACKET, match.index + startIndex, source);else if (isCommaMatch$2(groups)) yield new Token(TOKEN_COMMA, groups.TOKEN_COMMA, match.index + startIndex, source);else if (isColonMatch$1(groups)) yield new Token(TOKEN_COLON, groups.TOKEN_COLON, match.index + startIndex, source);else if (isAssignMatch(groups)) yield new Token(TOKEN_ASSIGN, groups.TOKEN_ASSIGN, match.index + startIndex, source);else if (isIllegalMatch$3(groups)) throw new LiquidSyntaxError(`unexpected token '${groups.TOKEN_ILLEGAL}'`, new Token(TOKEN_ILLEGAL, groups.TOKEN_ILLEGAL, match.index + startIndex, source));
      }
    }();
  };
}
const tokenize$4 = makeTokenizer$2(RE$3, KEYWORDS$2);

/** The value returned from an argument parser function. */

/**
 * An object mapping argument names to Liquid expressions.
 */

/**
 * Return a function to parse keyword or named arguments from a stream of
 * expression tokens until the end of the stream.
 *
 * @param argumentParser - A function that will parse a single argument.
 * @param separatorTokenKind - The token kind that separates an argument's
 * key from its value.
 * @returns An object with string keys and `Expression` values.
 */
function makeParseArguments(argumentParser) {
  let separatorTokenKind = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : TOKEN_COLON;
  function _parseArguments(stream) {
    const args = [];
    // The first keyword argument might follow immediately or after a comma.
    if (stream.current.kind === TOKEN_COMMA) stream.next();
    while (stream.current.kind !== TOKEN_EOF) {
      args.push(argumentParser(stream, separatorTokenKind));
      stream.next();
      // Catch missing comma
      if (stream.current.kind !== TOKEN_EOF) stream.expect(TOKEN_COMMA);
      // Eat comma. Trailing commas are OK
      if (stream.current.kind === TOKEN_COMMA) stream.next();
    }
    return args;
  }
  return _parseArguments;
}
function parseArgument(stream, separatorTokenKind) {
  const key = parseUnchainedIdentifier(stream).toString();
  stream.next();
  stream.expect(separatorTokenKind);
  stream.next(); // Eat separator
  const val = parseObject$2(stream);
  stream.next();
  return [key, val];
}

/**
 * Parse keyword or named arguments from a stream of expression tokens
 * until the end of the stream.
 *
 * Each key/value pair is assumed to be separated by a comma. Leading and
 * trailing commas are OK.
 *
 * If the same key/name appears multiple times, the last occurrence in the
 * argument "list" will take priority.
 *
 * Values can be string, integer, float, true, false or nil literals, an
 * identifier or a range expression. An identifier value could be chained
 * using a mixture of dot and bracket notation.
 *
 * @param stream - A stream of expression tokens.
 * @param separatorTokenKind - The token kind that separates an arguments
 * key from its value.
 * @returns An object with string keys and `Expression` values.
 */
function parseArguments(stream) {
  let separatorTokenKind = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : TOKEN_COLON;
  const args = {};
  // The first keyword argument might follow immediately or after a comma.
  if (stream.current.kind === TOKEN_COMMA) stream.next();
  while (stream.current.kind !== TOKEN_EOF) {
    const [key, expr] = parseArgument(stream, separatorTokenKind);
    args[key] = expr;
    // Catch missing comma
    if (stream.peek.kind !== TOKEN_EOF) stream.expect(TOKEN_COMMA);
    // Eat comma. Trailing commas are OK
    if (stream.current.kind === TOKEN_COMMA) stream.next();
  }
  return args;
}
const parseColonSeparatedArguments = makeParseArguments(parseArgument, TOKEN_COLON);
const parseEqualsSeparatedArguments = makeParseArguments(parseArgument, TOKEN_ASSIGN);
function parseMacroArgument(stream, separatorTokenKind) {
  const key = parseUnchainedIdentifier(stream).toString();
  let val;
  if (stream.peek.kind === separatorTokenKind) {
    stream.next();
    // A keyword argument
    stream.next(); // Eat separator
    val = parseObject$2(stream);
  } else {
    // A positional argument
    val = NIL;
  }
  return [key, val];
}
function parseCallArgument(stream, separatorTokenKind) {
  let key;
  if (stream.peek.kind === separatorTokenKind) {
    // A keyword argument
    key = parseUnchainedIdentifier(stream).toString();
    stream.next();
    stream.next(); // Eat separator
  } else {
    // A positional argument
    key = "";
  }
  return [key, parseObject$2(stream)];
}
const _parseMacroArguments = makeParseArguments(parseMacroArgument, TOKEN_COLON);
const _parseCallArguments = makeParseArguments(parseCallArgument, TOKEN_COLON);

/**
 * Parse keyword or named arguments from a Liquid expression string.
 *
 * Each key/value pair is assumed to be separated by a comma. Leading and
 * trailing commas are OK.
 *
 * If the same key/name appears multiple times, the last occurrence in the
 * argument "list" will take priority.
 *
 * Values can be string, integer, float, true, false or nil literals, an
 * identifier or a range expression. An identifier value could be chained
 * using a mixture of dot and bracket notation.
 *
 * @param expr - A Liquid expression containing zero or more keyword
 * arguments.
 * @param separatorTokenKind - The token kind that separates an arguments
 * key from its value.
 * @returns An object with string keys and `Expression` values.
 */
function parse$2(expr) {
  let separatorTokenKind = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : TOKEN_COLON;
  let startIndex = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
  return parseArguments(new ExpressionTokenStream(tokenize$4(expr, startIndex)), separatorTokenKind);
}
function parseMacroName(stream) {
  if (stream.current.kind === TOKEN_IDENT || stream.current.kind === TOKEN_STRING) {
    return stream.current.value;
  }
  throw new LiquidSyntaxError(`invalid macro name '${stream.current.value}'`, stream.current);
}

/**
 * Parse a macro tag argument list.
 * @param expr - A macro tag expression.
 * @param startIndex - Location in the template source text where this
 * expression starts.
 * @returns An array of macro name and its argument list.
 */
function parseMacroArguments(expr) {
  let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
  const stream = new ExpressionTokenStream(tokenize$4(expr, startIndex));
  const name = parseMacroName(stream);
  stream.next();
  return [name, _parseMacroArguments(stream)];
}

/**
 * Parse a call tag argument list.
 * @param expr - A call tag expression.
 * @param startIndex - Location in the template source text where this
 * expression starts.
 * @returns An array of macro name and the arguments it's being called with.
 */
function parseCallArguments(expr) {
  let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
  const stream = new ExpressionTokenStream(tokenize$4(expr, startIndex));
  const name = parseMacroName(stream);
  stream.next();
  return [name, _parseCallArguments(stream)];
}

var index$7 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  RE: RE$3,
  RULES: RULES$3,
  makeParseArguments: makeParseArguments,
  makeTokenizer: makeTokenizer$2,
  parse: parse$2,
  parseArguments: parseArguments,
  parseCallArguments: parseCallArguments,
  parseColonSeparatedArguments: parseColonSeparatedArguments,
  parseEqualsSeparatedArguments: parseEqualsSeparatedArguments,
  parseMacroArguments: parseMacroArguments,
  tokenize: tokenize$4
});

const RULES$2 = [[TOKEN_IDENT_INDEX, IDENT_INDEX_PATTERN], [TOKEN_IDENT_STRING, IDENT_STRING_PATTERN], [TOKEN_STRING, STRING_PATTERN], [TOKEN_RANGE, "\\.\\."], [TOKEN_FLOAT, "-?\\d+\\.(?!\\.)\\d*"], [TOKEN_INTEGER, "-?\\d+\\b"], [TOKEN_DOT, "\\."], [TOKEN_IDENT, IDENTIFIER_PATTERN], [TOKEN_LPAREN, "\\("], [TOKEN_RPAREN, "\\)"], [TOKEN_LBRACKET, "\\["], [TOKEN_RBRACKET, "]"], [TOKEN_COMMA, ","], [TOKEN_NEWLINE, "\\n"], [TOKEN_SKIP, "[ \\t\\r]+"], [TOKEN_ILLEGAL, "."]];
const KEYWORDS$1 = new Set([TOKEN_TRUE, TOKEN_FALSE, TOKEN_NIL, TOKEN_NULL, TOKEN_EMPTY, TOKEN_BLANK, TOKEN_OR]);
const RE$2 = new RegExp(RULES$2.map(_ref => {
  let [n, p] = _ref;
  return `(?<${n}>${p})`;
}).join("|"), "gs");
function isIdentIndexMatch$1(match) {
  return match.TOKEN_IDENT_INDEX === undefined ? false : true;
}
function isIdentStringMatch$1(match) {
  return match.TOKEN_IDENT_STRING === undefined ? false : true;
}
function isStringMatch$1(match) {
  return match.TOKEN_STRING === undefined ? false : true;
}
function isRangeMatch$1(match) {
  return match.TOKEN_RANGE === undefined ? false : true;
}
function isFloatMatch$1(match) {
  return match.TOKEN_FLOAT === undefined ? false : true;
}
function isIntegerMatch$1(match) {
  return match.TOKEN_INTEGER === undefined ? false : true;
}
function isDotMatch$1(match) {
  return match.TOKEN_DOT === undefined ? false : true;
}
function isIdentifierMatch$1(match) {
  return match.TOKEN_IDENT === undefined ? false : true;
}
function isLParenMatch$1(match) {
  return match.TOKEN_LPAREN === undefined ? false : true;
}
function isRParenMatch$1(match) {
  return match.TOKEN_RPAREN === undefined ? false : true;
}
function isLBracketMatch$1(match) {
  return match.TOKEN_LBRACKET === undefined ? false : true;
}
function isRBracketMatch$1(match) {
  return match.TOKEN_RBRACKET === undefined ? false : true;
}
function isCommaMatch$1(match) {
  return match.TOKEN_COMMA === undefined ? false : true;
}
function isNewlineMatch$1(match) {
  return match.TOKEN_NEWLINE === undefined ? false : true;
}
function isSkipMatch$2(match) {
  return match.TOKEN_SKIP === undefined ? false : true;
}
function isIllegalMatch$2(match) {
  return match.TOKEN_ILLEGAL === undefined ? false : true;
}
function makeTokenizer$1(re, keywords) {
  // eslint-disable-next-line sonarjs/cognitive-complexity
  return function tokenize(source) {
    let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    return function* () {
      for (const match of source.matchAll(re)) {
        const groups = match.groups;
        if (isIdentifierMatch$1(groups)) {
          if (keywords.has(groups.TOKEN_IDENT)) yield new Token(groups.TOKEN_IDENT, match[0], match.index + startIndex, source);else yield new Token(TOKEN_IDENT, groups.TOKEN_IDENT, match.index + startIndex, source);
        } else if (isIdentIndexMatch$1(groups)) yield new Token(TOKEN_IDENT_INDEX, groups.identIndex, match.index + startIndex, source);else if (isIdentStringMatch$1(groups)) yield new Token(TOKEN_IDENT, groups.identQuoted, match.index + startIndex, source);else if (isStringMatch$1(groups)) yield new Token(TOKEN_STRING, groups.quoted, match.index + startIndex, source);else if (isNewlineMatch$1(groups) || isSkipMatch$2(groups)) continue;else if (isRangeMatch$1(groups)) yield new Token(TOKEN_RANGE, groups.TOKEN_RANGE, match.index + startIndex, source);else if (isFloatMatch$1(groups)) yield new Token(TOKEN_FLOAT, groups.TOKEN_FLOAT, match.index + startIndex, source);else if (isIntegerMatch$1(groups)) yield new Token(TOKEN_INTEGER, groups.TOKEN_INTEGER, match.index + startIndex, source);else if (isDotMatch$1(groups)) yield new Token(TOKEN_DOT, groups.TOKEN_DOT, match.index + startIndex, source);else if (isLParenMatch$1(groups)) yield new Token(TOKEN_LPAREN, groups.TOKEN_LPAREN, match.index + startIndex, source);else if (isRParenMatch$1(groups)) yield new Token(TOKEN_RPAREN, groups.TOKEN_RPAREN, match.index + startIndex, source);else if (isLBracketMatch$1(groups)) yield new Token(TOKEN_LBRACKET, groups.TOKEN_LBRACKET, match.index + startIndex, source);else if (isRBracketMatch$1(groups)) yield new Token(TOKEN_RBRACKET, groups.TOKEN_RBRACKET, match.index + startIndex, source);else if (isCommaMatch$1(groups)) yield new Token(TOKEN_COMMA, groups.TOKEN_COMMA, match.index + startIndex, source);else if (isIllegalMatch$2(groups)) throw new LiquidSyntaxError(`unexpected token '${groups.TOKEN_ILLEGAL}'`, new Token(TOKEN_ILLEGAL, groups.TOKEN_ILLEGAL, match.index + startIndex, source));
      }
    }();
  };
}
const tokenize$3 = makeTokenizer$1(RE$2, KEYWORDS$1);

function parseIdentifier(stream) {
  if (!IDENT_TOKENS.has(stream.peek.kind)) {
    return new Identifier(stream.current.value, []);
  }
  const path = [];
  const kind = stream.current.kind;
  let root;
  if (kind === TOKEN_LBRACKET) {
    root = null;
  } else if (kind === TOKEN_IDENT) {
    root = stream.current.value;
    stream.next();
  } else {
    throw new LiquidSyntaxError(`expected an identifier, found '${stream.current.value}'`, stream.current);
  }
  for (;;) {
    switch (stream.current.kind) {
      case TOKEN_IDENT:
        path.push(new IdentifierPathElement(stream.current.value));
        break;
      case TOKEN_IDENT_INDEX:
        path.push(new IdentifierPathElement(Number(stream.current.value)));
        break;
      case TOKEN_LBRACKET:
        stream.next();
        path.push(parseIdentifier(stream));
        stream.next();
        stream.expect(TOKEN_RBRACKET);
        break;
    }
    if (IDENT_TOKENS.has(stream.peek.kind)) {
      stream.next();
    } else {
      break;
    }
  }
  return new Identifier(root, path);
}
const LITERAL_OR_IDENT_MAP = new Map([[TOKEN_IDENT, parseIdentifier], [TOKEN_LBRACKET, parseIdentifier], [TOKEN_STRING, parseStringLiteral], [TOKEN_INTEGER, parseIntegerLiteral], [TOKEN_FLOAT, parseFloatLiteral], [TOKEN_NIL, parseNil], [TOKEN_TRUE, parseBoolean], [TOKEN_FALSE, parseBoolean], [TOKEN_BLANK, parseBlank], [TOKEN_EMPTY, parseEmpty], [TOKEN_LPAREN, makeParseRange(parse$1)]]);
function parse$1(stream) {
  const func = LITERAL_OR_IDENT_MAP.get(stream.current.kind);
  if (!func) throw new LiquidSyntaxError(`unexpected '${stream.current.value}'`, stream.current);
  return func(stream);
}

var index$6 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  RE: RE$2,
  makeTokenizer: makeTokenizer$1,
  parse: parse$1,
  tokenize: tokenize$3
});

const RULES$1 = [[TOKEN_IDENT_INDEX, IDENT_INDEX_PATTERN], [TOKEN_IDENT_STRING, IDENT_STRING_PATTERN], [TOKEN_STRING, STRING_PATTERN], [TOKEN_RANGE, "\\.\\."], [TOKEN_FLOAT, "-?\\d+\\.(?!\\.)\\d*"], [TOKEN_INTEGER, "-?\\d+\\b"], [TOKEN_DOT, "\\."], [TOKEN_IDENT, IDENTIFIER_PATTERN], [TOKEN_LPAREN, "\\("], [TOKEN_RPAREN, "\\)"], [TOKEN_LBRACKET, "\\["], [TOKEN_RBRACKET, "]"], [TOKEN_COMMA, ","], [TOKEN_COLON, ":"], [TOKEN_DPIPE, "\\|\\|"], [TOKEN_PIPE, "\\|"], [TOKEN_NEWLINE, "\\n"], [TOKEN_OP, "[!=<>]{1,2}"], [TOKEN_SKIP, "[ \\t\\r]+"], [TOKEN_ILLEGAL, "."]];
const KEYWORDS = new Set([TOKEN_AND, TOKEN_BLANK, TOKEN_CONTAINS, TOKEN_ELSE, TOKEN_EMPTY, TOKEN_FALSE, TOKEN_IF, TOKEN_NIL, TOKEN_NULL, TOKEN_OR, TOKEN_TRUE]);
const EXTENDED_RULES = [[TOKEN_RANGE_LPAREN, "\\((?=.+?\\.\\.)"], ...RULES$1];
const EXTENDED_KEYWORDS = new Set([...KEYWORDS, TOKEN_NOT]);
const RE$1 = new RegExp(RULES$1.map(_ref => {
  let [n, p] = _ref;
  return `(?<${n}>${p})`;
}).join("|"), "gs");
const EXTENDED_RE = new RegExp(EXTENDED_RULES.map(_ref2 => {
  let [n, p] = _ref2;
  return `(?<${n}>${p})`;
}).join("|"), "gs");
function isIdentIndexMatch(match) {
  return match.TOKEN_IDENT_INDEX === undefined ? false : true;
}
function isIdentStringMatch(match) {
  return match.TOKEN_IDENT_STRING === undefined ? false : true;
}
function isStringMatch(match) {
  return match.TOKEN_STRING === undefined ? false : true;
}
function isRangeLParenMatch(match) {
  return match.TOKEN_RANGE_LPAREN === undefined ? false : true;
}
function isRangeMatch(match) {
  return match.TOKEN_RANGE === undefined ? false : true;
}
function isFloatMatch(match) {
  return match.TOKEN_FLOAT === undefined ? false : true;
}
function isIntegerMatch(match) {
  return match.TOKEN_INTEGER === undefined ? false : true;
}
function isDotMatch(match) {
  return match.TOKEN_DOT === undefined ? false : true;
}
function isIdentifierMatch(match) {
  return match.TOKEN_IDENT === undefined ? false : true;
}
function isLParenMatch(match) {
  return match.TOKEN_LPAREN === undefined ? false : true;
}
function isRParenMatch(match) {
  return match.TOKEN_RPAREN === undefined ? false : true;
}
function isLBracketMatch(match) {
  return match.TOKEN_LBRACKET === undefined ? false : true;
}
function isRBracketMatch(match) {
  return match.TOKEN_RBRACKET === undefined ? false : true;
}
function isCommaMatch(match) {
  return match.TOKEN_COMMA === undefined ? false : true;
}
function isColonMatch(match) {
  return match.TOKEN_COLON === undefined ? false : true;
}
function isPipeMatch(match) {
  return match.TOKEN_PIPE === undefined ? false : true;
}
function isDoublePipeMatch(match) {
  return match.TOKEN_DPIPE === undefined ? false : true;
}
function isNewlineMatch(match) {
  return match.TOKEN_NEWLINE === undefined ? false : true;
}
function isOpMatch(match) {
  return match.TOKEN_OP === undefined ? false : true;
}
function isSkipMatch$1(match) {
  return match.TOKEN_SKIP === undefined ? false : true;
}
function isIllegalMatch$1(match) {
  return match.TOKEN_ILLEGAL === undefined ? false : true;
}
function makeTokenizer(re, keywords) {
  // eslint-disable-next-line sonarjs/cognitive-complexity
  return function tokenize(source) {
    let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    return function* () {
      for (const match of source.matchAll(re)) {
        const groups = match.groups;
        if (isIdentifierMatch(groups)) {
          if (keywords.has(groups.TOKEN_IDENT)) yield new Token(groups.TOKEN_IDENT, match[0], match.index + startIndex, source);else yield new Token(TOKEN_IDENT, groups.TOKEN_IDENT, match.index + startIndex, source);
        } else if (isIdentIndexMatch(groups)) yield new Token(TOKEN_IDENT_INDEX, groups.identIndex, match.index + startIndex, source);else if (isIdentStringMatch(groups)) yield new Token(TOKEN_IDENT, groups.identQuoted, match.index + startIndex, source);else if (isStringMatch(groups)) yield new Token(TOKEN_STRING, groups.quoted, match.index + startIndex, source);else if (isNewlineMatch(groups) || isSkipMatch$1(groups)) continue;else if (isRangeLParenMatch(groups)) yield new Token(TOKEN_RANGE_LPAREN, groups.TOKEN_RANGE_LPAREN, match.index + startIndex, source);else if (isRangeMatch(groups)) yield new Token(TOKEN_RANGE, groups.TOKEN_RANGE, match.index + startIndex, source);else if (isFloatMatch(groups)) yield new Token(TOKEN_FLOAT, groups.TOKEN_FLOAT, match.index + startIndex, source);else if (isIntegerMatch(groups)) yield new Token(TOKEN_INTEGER, groups.TOKEN_INTEGER, match.index + startIndex, source);else if (isDotMatch(groups)) yield new Token(TOKEN_DOT, groups.TOKEN_DOT, match.index + startIndex, source);else if (isLParenMatch(groups)) yield new Token(TOKEN_LPAREN, groups.TOKEN_LPAREN, match.index + startIndex, source);else if (isRParenMatch(groups)) yield new Token(TOKEN_RPAREN, groups.TOKEN_RPAREN, match.index + startIndex, source);else if (isLBracketMatch(groups)) yield new Token(TOKEN_LBRACKET, groups.TOKEN_LBRACKET, match.index + startIndex, source);else if (isRBracketMatch(groups)) yield new Token(TOKEN_RBRACKET, groups.TOKEN_RBRACKET, match.index + startIndex, source);else if (isCommaMatch(groups)) yield new Token(TOKEN_COMMA, groups.TOKEN_COMMA, match.index + startIndex, source);else if (isColonMatch(groups)) yield new Token(TOKEN_COLON, groups.TOKEN_COLON, match.index + startIndex, source);else if (isPipeMatch(groups)) yield new Token(TOKEN_PIPE, groups.TOKEN_PIPE, match.index + startIndex, source);else if (isDoublePipeMatch(groups)) yield new Token(TOKEN_DPIPE, groups.TOKEN_DPIPE, match.index + startIndex, source);else if (isOpMatch(groups)) {
          const op = OPERATORS.get(groups.TOKEN_OP);
          if (op === undefined) throw new LiquidSyntaxError(`unknown operator '${groups.TOKEN_OP}'`, new Token(TOKEN_ILLEGAL, groups.TOKEN_OP, match.index + startIndex, source));
          yield new Token(op, groups.TOKEN_OP, match.index + startIndex, source);
        } else if (isIllegalMatch$1(groups)) throw new LiquidSyntaxError(`unexpected token '${groups.TOKEN_ILLEGAL}'`, new Token(TOKEN_ILLEGAL, groups.TOKEN_ILLEGAL, match.index + startIndex, source));
      }
    }();
  };
}
const tokenize$2 = makeTokenizer(RE$1, KEYWORDS);
const tokenizeWithParens = makeTokenizer(EXTENDED_RE, EXTENDED_KEYWORDS);

function makeSplitAtFirst(tokenKind) {
  function _splitAtFirst(tokens) {
    const index = tokens.findIndex(t => t.kind === tokenKind);
    if (index === -1) {
      return [tokens, undefined];
    }
    return [tokens.slice(0, index), tokens.slice(index + 1)];
  }
  return _splitAtFirst;
}
function* splitAtPipe(tokens) {
  let buf = [];
  for (const token of tokens) {
    if (token.kind === TOKEN_PIPE) {
      yield buf;
      buf = [];
    } else {
      buf.push(token);
    }
  }
  yield buf;
}
const splitAtFirstDoublePipe = makeSplitAtFirst(TOKEN_DPIPE);
const splitAtFirstIf = makeSplitAtFirst(TOKEN_IF);
const splitAtFirstElse = makeSplitAtFirst(TOKEN_ELSE);
function parse(expr) {
  let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  const [standardTokens, extendedTokens] = splitAtFirstIf(Array.from(tokenize$2(expr, startIndex)));
  const _expr = parseFromTokens(standardTokens[Symbol.iterator]());
  if (extendedTokens === undefined) {
    return _expr;
  }
  const [_conditionalTokens, tailFilterTokens] = splitAtFirstDoublePipe(extendedTokens);
  const [conditionalTokens, alternativeTokens] = splitAtFirstElse(_conditionalTokens);
  let condition;
  if (conditionalTokens.length === 0) {
    // An `if` with nothing after it.
    condition = FALSE;
  } else {
    condition = parseObject$1(new ExpressionTokenStream(conditionalTokens[Symbol.iterator]()));
  }
  let alternative;
  if (alternativeTokens === undefined || alternativeTokens.length === 0) {
    alternative = NIL;
  } else {
    alternative = parseFromTokens(alternativeTokens[Symbol.iterator]());
  }
  let tailFilters;
  if (tailFilterTokens === undefined) {
    tailFilters = [];
  } else {
    tailFilters = Array.from(splitAtPipe(tailFilterTokens)).map(parseFilter);
  }
  return new ConditionalExpression(_expr, tailFilters, condition, alternative);
}
function parseWithParens(expr) {
  let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  const [standardTokens, extendedTokens] = splitAtFirstIf(Array.from(tokenizeWithParens(expr, startIndex)));
  const _expr = parseFromTokens(standardTokens[Symbol.iterator]());
  if (extendedTokens === undefined) {
    return _expr;
  }
  const [_conditionalTokens, tailFilterTokens] = splitAtFirstDoublePipe(extendedTokens);
  const [conditionalTokens, alternativeTokens] = splitAtFirstElse(_conditionalTokens);
  let condition;
  if (conditionalTokens.length === 0) {
    // An `if` with nothing after it.
    condition = FALSE;
  } else {
    condition = parseObject(new ExpressionTokenStream(conditionalTokens[Symbol.iterator]()));
  }
  let alternative;
  if (alternativeTokens === undefined || alternativeTokens.length === 0) {
    alternative = NIL;
  } else {
    alternative = parseFromTokens(alternativeTokens[Symbol.iterator]());
  }
  let tailFilters;
  if (tailFilterTokens === undefined) {
    tailFilters = [];
  } else {
    tailFilters = Array.from(splitAtPipe(tailFilterTokens)).map(parseFilter);
  }
  return new ConditionalExpression(_expr, tailFilters, condition, alternative);
}

var index$5 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  makeTokenizer: makeTokenizer,
  parse: parse,
  parseWithParens: parseWithParens,
  tokenize: tokenize$2,
  tokenizeWithParens: tokenizeWithParens
});

var index$4 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  ASSIGN_IDENTIFIER_PATTERN: ASSIGN_IDENTIFIER_PATTERN,
  ExpressionTokenStream: ExpressionTokenStream,
  IDENTIFIER_PATTERN: IDENTIFIER_PATTERN,
  IDENT_INDEX_PATTERN: IDENT_INDEX_PATTERN,
  IDENT_STRING_PATTERN: IDENT_STRING_PATTERN,
  IDENT_TOKENS: IDENT_TOKENS,
  OPERATORS: OPERATORS,
  REVERSE_OPERATORS: REVERSE_OPERATORS,
  STRING_PATTERN: STRING_PATTERN,
  TOKEN_AND: TOKEN_AND,
  TOKEN_AS: TOKEN_AS,
  TOKEN_ASSIGN: TOKEN_ASSIGN,
  TOKEN_BLANK: TOKEN_BLANK,
  TOKEN_BY: TOKEN_BY,
  TOKEN_COLON: TOKEN_COLON,
  TOKEN_COLS: TOKEN_COLS,
  TOKEN_COMMA: TOKEN_COMMA,
  TOKEN_CONTAINS: TOKEN_CONTAINS,
  TOKEN_CONTINUE: TOKEN_CONTINUE,
  TOKEN_DOT: TOKEN_DOT,
  TOKEN_DPIPE: TOKEN_DPIPE,
  TOKEN_ELSE: TOKEN_ELSE,
  TOKEN_EMPTY: TOKEN_EMPTY,
  TOKEN_EOF: TOKEN_EOF,
  TOKEN_EQ: TOKEN_EQ,
  TOKEN_FALSE: TOKEN_FALSE,
  TOKEN_FLOAT: TOKEN_FLOAT,
  TOKEN_FOR: TOKEN_FOR,
  TOKEN_GE: TOKEN_GE,
  TOKEN_GT: TOKEN_GT,
  TOKEN_IDENT: TOKEN_IDENT,
  TOKEN_IDENT_INDEX: TOKEN_IDENT_INDEX,
  TOKEN_IDENT_STRING: TOKEN_IDENT_STRING,
  TOKEN_IF: TOKEN_IF,
  TOKEN_ILLEGAL: TOKEN_ILLEGAL,
  TOKEN_IN: TOKEN_IN,
  TOKEN_INTEGER: TOKEN_INTEGER,
  TOKEN_LBRACKET: TOKEN_LBRACKET,
  TOKEN_LE: TOKEN_LE,
  TOKEN_LG: TOKEN_LG,
  TOKEN_LIMIT: TOKEN_LIMIT,
  TOKEN_LPAREN: TOKEN_LPAREN,
  TOKEN_LT: TOKEN_LT,
  TOKEN_NE: TOKEN_NE,
  TOKEN_NEWLINE: TOKEN_NEWLINE,
  TOKEN_NIL: TOKEN_NIL,
  TOKEN_NOT: TOKEN_NOT,
  TOKEN_NULL: TOKEN_NULL,
  TOKEN_OFFSET: TOKEN_OFFSET,
  TOKEN_OP: TOKEN_OP,
  TOKEN_OR: TOKEN_OR,
  TOKEN_PIPE: TOKEN_PIPE,
  TOKEN_RANGE: TOKEN_RANGE,
  TOKEN_RANGE_LPAREN: TOKEN_RANGE_LPAREN,
  TOKEN_RBRACKET: TOKEN_RBRACKET,
  TOKEN_REVERSED: TOKEN_REVERSED,
  TOKEN_RPAREN: TOKEN_RPAREN,
  TOKEN_SKIP: TOKEN_SKIP,
  TOKEN_STRING: TOKEN_STRING,
  TOKEN_TRUE: TOKEN_TRUE,
  TOKEN_WITH: TOKEN_WITH,
  arguments: index$7,
  boolean: index$c,
  boolean_not: index$8,
  conditional: index$5,
  filtered: index$b,
  include: index$a,
  loop: index$9,
  makeParseRange: makeParseRange,
  parseBlank: parseBlank,
  parseBoolean: parseBoolean,
  parseEmpty: parseEmpty,
  parseFloatLiteral: parseFloatLiteral,
  parseIdentifier: parseIdentifier$1,
  parseIntegerLiteral: parseIntegerLiteral,
  parseNil: parseNil,
  parseStringLiteral: parseStringLiteral,
  parseStringOrIdentifier: parseStringOrIdentifier,
  parseUnchainedIdentifier: parseUnchainedIdentifier,
  reverseOperatorLookup: reverseOperatorLookup,
  standard: index$6
});

const TAG_CASE = "case";
const TAG_ENDCASE = "endcase";
const TAG_WHEN = "when";
const TAG_ELSE$3 = "else";
class CaseTag {
  static END_WHEN_BLOCK = new Set([TAG_ENDCASE, TAG_WHEN, TAG_ELSE$3, TOKEN_EOF$1]);
  static END_CASE_BLOCK = new Set([TAG_ENDCASE]);
  static DELIM_TOKENS = new Set([TOKEN_COMMA, TOKEN_OR]);
  block = true;
  name = TAG_CASE;
  end = TAG_ENDCASE;
  nodeClass = CaseNode;
  parse(stream, environment) {
    const parser = environment.parser;
    const token = stream.next();

    // Parse the case expression
    stream.expect(TOKEN_EXPRESSION);
    const _case = this.parse_case_expression(stream.current.value, stream.current.index);
    stream.next();

    // Eat whitespace or junk between `case` and when/else/endcase
    while (stream.current.kind !== TOKEN_TAG && !CaseTag.END_WHEN_BLOCK.has(stream.current.value)) stream.next();
    const whens = [];
    while (stream.current.kind === TOKEN_TAG && stream.current.value === TAG_WHEN) {
      const whenToken = stream.next();
      stream.expect(TOKEN_EXPRESSION);
      const whenExprs = this.parse_when_expression(stream.current.value, stream.current.index).map(expr => new BooleanExpression(new InfixExpression(_case, "==", expr)));
      const whenBlock = parser.parseBlock(stream, CaseTag.END_WHEN_BLOCK, stream.next());
      whens.push(...whenExprs.map(expr => ({
        token: whenToken,
        condition: expr,
        block: whenBlock
      })));
    }

    // Optional catch-all default block.
    if (stream.current.kind === TOKEN_TAG && stream.current.value === TAG_ELSE$3) {
      return new this.nodeClass(token, whens, parser.parseBlock(stream, CaseTag.END_CASE_BLOCK, stream.next()));
    }
    stream.expectTag(TAG_ENDCASE);
    return new this.nodeClass(token, whens);
  }
  parse_case_expression(expr, startIndex) {
    return parse$1(new ExpressionTokenStream(tokenize$3(expr, startIndex)));
  }
  parse_when_expression(expr, startIndex) {
    const expressions = [];
    const stream = new ExpressionTokenStream(tokenize$3(expr, startIndex));
    for (;;) {
      expressions.push(parse$1(stream));
      stream.next();
      if (CaseTag.DELIM_TOKENS.has(stream.current.kind)) {
        stream.next();
      } else {
        break;
      }
    }
    return expressions;
  }
}
class CaseNode {
  forceOutput = false;
  constructor(token, whens, default_) {
    this.token = token;
    this.whens = whens;
    this.default_ = default_;
    this.forceOutput = forcedOutput(this);
  }
  async render(context, out) {
    const buf = context.environment.renderStreamFactory(out);
    let rendered = false;
    for (const _when of this.whens) {
      if (_when.condition instanceof Literal ? _when.condition.evaluateSync(context) : await _when.condition.evaluate(context)) {
        rendered = true;
        await _when.block.render(context, buf);
      }
    }
    if (!rendered && this.default_ !== undefined) {
      await this.default_.render(context, buf);
    }
    const buffered = buf.toString();
    if (this.forceOutput || /\S/.test(buffered)) out.write(buffered);
  }
  renderSync(context, out) {
    const buf = context.environment.renderStreamFactory(out);
    let rendered = false;
    for (const _when of this.whens) {
      if (_when.condition.evaluateSync(context)) {
        rendered = true;
        _when.block.renderSync(context, buf);
      }
    }
    if (!rendered && this.default_ !== undefined) {
      this.default_.renderSync(context, buf);
    }
    const buffered = buf.toString();
    if (this.forceOutput || /\S/.test(buffered)) out.write(buffered);
  }
  children() {
    const _children = this.whens.map(alt => ({
      token: alt.token,
      node: alt.block,
      expression: alt.condition
    }));
    if (this.default_ !== undefined) _children.push({
      token: this.default_.token,
      node: this.default_
    });
    return _children;
  }
}

class CommentTag {
  block = true;
  name = "comment";
  end = "endcomment";
  nodeClass = CommentNode;
  parse(stream) {
    const token = stream.next();
    const text = [];
    while (stream.current.kind !== TOKEN_EOF$1 && !(stream.current.kind === TOKEN_TAG && stream.current.value === "endcomment")) {
      text.push(stream.current.value);
      stream.next();
    }
    return new this.nodeClass(token, text.join(""));
  }
}
class CommentNode {
  constructor(token, text) {
    this.token = token;
    this.text = text;
  }
  async render() {
    return;
  }
  renderSync() {
    return;
  }
}

const Cycles = Symbol.for("liquid.tags.cycles");
const UndefinedCycleGroup = Symbol.for("liquid.tags.cycles.undefined");
class CycleTag {
  block = false;
  name = "cycle";
  nodeClass = CycleNode;
  parse(stream) {
    const token = stream.next();
    stream.expect(TOKEN_EXPRESSION);
    const tokens = tokenize$9(stream.current.value, token.index);
    let groupName = undefined;
    const parts = Array.from(splitAtFirstColon(tokens));
    if (parts.length === 2) groupName = parseStringOrIdentifier(new ExpressionTokenStream(parts[0].values()));
    return new this.nodeClass(token, Array.from(parseArgs(new ExpressionTokenStream(parts[parts.length - 1].values()))), groupName);
  }
}
class CycleNode {
  constructor(token, args, group) {
    this.token = token;
    this.args = args;
    this.group = group;
  }
  cycle(context, out, groupName, args) {
    const cycles = context.getRegister(Cycles);
    let key;
    if (groupName === undefined) {
      key = args.toString();
    } else if (isUndefined(groupName)) {
      key = UndefinedCycleGroup;
    } else if (groupName === null) {
      key = "";
    } else {
      key = groupName.toString();
    }
    let index = cycles.has(key) ? cycles.get(key) : 0;
    if (index < args.length) {
      out.write(liquidStringify(args[index]));
    }
    index = index + 1;
    if (index >= args.length) {
      index = 0;
    }
    cycles.set(key, index % args.length);
  }
  async render(context, out) {
    const groupName = this.group ? await this.group.evaluate(context) : undefined;
    const args = await Promise.all(this.args.map(arg => arg.evaluate(context)));
    this.cycle(context, out, groupName, args);
  }
  renderSync(context, out) {
    const groupName = this.group ? this.group.evaluateSync(context) : undefined;
    const args = this.args.map(arg => arg.evaluateSync(context));
    this.cycle(context, out, groupName, args);
  }
  children() {
    const _children = [];
    if (this.group) {
      _children.push({
        token: this.token,
        expression: this.group
      });
    }
    for (const arg of this.args) {
      _children.push({
        token: this.token,
        expression: arg
      });
    }
    return _children;
  }
}
function* parseArgs(stream) {
  while (stream.current.kind !== TOKEN_EOF$1) {
    yield parseObject$2(stream);
    stream.next();
    switch (stream.current.kind) {
      case TOKEN_COMMA:
        stream.next();
        break;
      case TOKEN_EOF$1:
        return;
      default:
        throw new LiquidSyntaxError(`expected a comma separated list of arguments, found ${stream.current.kind}`, stream.current);
    }
  }
}

/**
 *
 * @param tokens -
 * @returns
 */
function* splitAtFirstColon(tokens) {
  const buf = [];
  for (const token of tokens) {
    if (token.kind === TOKEN_COLON) {
      yield buf;
      yield Array.from(tokens);
      return;
    }
    buf.push(token);
  }
  yield buf;
}

class DecrementTag {
  block = false;
  name = "decrement";
  nodeClass = DecrementNode;
  parse(stream) {
    const token = stream.next();
    stream.expect(TOKEN_EXPRESSION);
    return new this.nodeClass(token, parseUnchainedIdentifier(new ExpressionTokenStream(tokenize$9(stream.current.value))).toString());
  }
}
class DecrementNode {
  constructor(token, identifier) {
    this.token = token;
    this.identifier = identifier;
  }
  async render(context, out) {
    this.renderSync(context, out);
  }
  renderSync(context, out) {
    let val = context.counters[this.identifier];
    if (val === undefined) val = 0;
    val -= 1;
    context.counters[this.identifier] = val;
    out.write(val.toString());
  }
  children() {
    return [{
      token: this.token,
      templateScope: [this.identifier]
    }];
  }
}

class OutputStatement {
  block = false;
  name = "statement";
  nodeClass = OutputStatementNode;
  parse(stream) {
    return new this.nodeClass(stream.current, parse$6(stream.current.value, stream.current.index));
  }
}
class OutputStatementNode {
  forceOutput = true;
  constructor(token, expression) {
    this.token = token;
    this.expression = expression;
  }
  async render(context, out) {
    const result = await this.expression.evaluate(context);
    if (context.environment.autoEscape) {
      if (isLiquidHTMLable(result)) out.write(result[toLiquidHtml]());else out.write(escape$1(liquidStringify(result)));
    } else out.write(liquidStringify(result));
  }
  renderSync(context, out) {
    const result = this.expression.evaluateSync(context);
    if (context.environment.autoEscape) {
      if (isLiquidHTMLable(result)) {
        out.write(result[toLiquidHtml]());
      } else {
        out.write(escape$1(liquidStringify(result)));
      }
    } else {
      out.write(liquidStringify(result));
    }
  }
  toString() {
    return `\`${this.expression.toString()}\``;
  }
  children() {
    return [{
      token: this.token,
      expression: this.expression
    }];
  }
}

class EchoTag {
  block = false;
  name = "echo";
  nodeClass = EchoNode;
  parseExpression(value, startIndex) {
    return parse$6(value, startIndex);
  }
  parse(stream) {
    const token = stream.next();

    // Empty echo tag at end of file.
    if (stream.current.kind === TOKEN_EOF$1) return new EchoNode(token, NIL);
    stream.expect(TOKEN_EXPRESSION);
    return new this.nodeClass(token, this.parseExpression(stream.current.value, stream.current.index));
  }
}
class EchoNode extends OutputStatementNode {
  toString() {
    return `EchoNode(token=${this.token}, expression=${this.expression})`;
  }
}

class ForLoopDrop {
  static _keys = new Set(["name", "length", "index", "index0", "rindex", "rindex0", "first", "last", "parentloop"]);
  _index = -1;
  constructor(name, it, length, parentloop) {
    this.name = name;
    this.it = it;
    this.length = length;
    this.parentloop = parentloop;
  }
  *[Symbol.iterator]() {
    for (;;) {
      this.step();
      const next = this.it.next();
      if (next.done) break;
      yield next.value;
    }
  }
  [liquidDispatchSync](name) {
    if (ForLoopDrop._keys.has(name)) return Reflect.get(this, name);
    throw new InternalKeyError(`ForLoopDrop[${name}]`);
  }
  toString() {
    return `ForLoop(${this.name})`;
  }
  step() {
    this._index += 1;
  }
  get index() {
    return this._index + 1;
  }
  get index0() {
    return this._index;
  }
  get rindex() {
    return this.length - this._index;
  }
  get rindex0() {
    return this.length - this._index - 1;
  }
  get first() {
    return this._index === 0;
  }
  get last() {
    return this._index === this.length - 1;
  }
}

const TAG_FOR = "for";
const TAG_ENDFOR = "endfor";
const TAG_ELSE$2 = "else";
const TAG_BREAK = "break";
const TAG_CONTINUE = "continue";
class BreakTag {
  name = TAG_BREAK;
  block = false;
  parse(stream) {
    return new BreakNode(stream.current);
  }
}
class ContinueTag {
  name = TAG_CONTINUE;
  block = false;
  parse(stream) {
    return new ContinueNode(stream.current);
  }
}
class ForTag {
  static ENDFORBLOCK = new Set([TAG_ENDFOR, TAG_ELSE$2]);
  static ENDFORELSEBLOCK = new Set([TAG_ENDFOR]);
  name = TAG_FOR;
  block = true;
  end = TAG_ENDFOR;
  nodeClass = ForNode;
  parse(stream, environment) {
    const token = stream.next();
    stream.expect(TOKEN_EXPRESSION);
    const expr = parse$4(stream.current.value);
    stream.next();
    const block = environment.parser.parseBlock(stream, ForTag.ENDFORBLOCK, token);
    let _default = undefined;
    if (stream.current.kind === TOKEN_TAG && stream.current.value === TAG_ELSE$2) {
      _default = environment.parser.parseBlock(stream, ForTag.ENDFORELSEBLOCK, stream.next());
    }
    stream.expect(TOKEN_TAG);
    return new this.nodeClass(token, expr, block, _default);
  }
}
class BreakNode {
  constructor(token) {
    this.token = token;
  }
  toString() {
    return "[break]";
  }
  async render() {
    throw new BreakIteration("break");
  }
  renderSync() {
    throw new BreakIteration("break");
  }
  children() {
    return [];
  }
}
class ContinueNode {
  constructor(token) {
    this.token = token;
  }
  toString() {
    return "[continue]";
  }
  async render() {
    throw new ContinueIteration("continue");
  }
  renderSync() {
    throw new ContinueIteration("continue");
  }
  children() {
    return [];
  }
}
class ForNode {
  forceOutput = false;
  constructor(token, expression, block, default_) {
    this.token = token;
    this.expression = expression;
    this.block = block;
    this.default_ = default_;
    this.forceOutput = forcedOutput(this);
  }

  // eslint-disable-next-line sonarjs/cognitive-complexity
  async render(context, out) {
    const [it, length] = await this.expression.evaluate(context);
    // This intermediate buffer is used to detect and possibly
    // suppress blocks that, when rendered, contain only whitespace
    // Don't buffer the output stream if this.forceOutput is true.
    const buf = this.forceOutput ? out : context.environment.renderStreamFactory(out);
    if (length > 0) {
      const name = this.expression.name;
      const forloop = new ForLoopDrop(`${name}-${this.expression.iterable}`, it, length, context.forLoops.length ? context.forLoops[context.forLoops.length - 1] : context.environment.undefinedFactory("parentloop"));
      context.raiseForLoopLimit(forloop.length);
      const namespace = {
        forloop
      };
      context.forLoops.push(forloop);
      try {
        await context.extend(namespace, async () => {
          for (const item of forloop) {
            namespace[name] = item;
            try {
              await this.block.render(context, buf);
            } catch (error) {
              if (error instanceof BreakIteration) {
                break;
              } else if (error instanceof ContinueIteration) {
                continue;
              } else {
                throw error;
              }
            }
          }
        });
      } finally {
        context.forLoops.pop();
      }
    } else if (this.default_ !== undefined) {
      await this.default_.render(context, buf);
    }
    if (!this.forceOutput) {
      const buffered = buf.toString();
      if (/\S/.test(buffered)) out.write(buffered);
    }
  }

  // eslint-disable-next-line sonarjs/cognitive-complexity
  renderSync(context, out) {
    const [it, length] = this.expression.evaluateSync(context);
    const buf = this.forceOutput ? out : context.environment.renderStreamFactory(out);
    if (length > 0) {
      const name = this.expression.name;
      const forloop = new ForLoopDrop(`${name}-${this.expression.iterable}`, it, length, context.forLoops.length ? context.forLoops[context.forLoops.length - 1] : context.environment.undefinedFactory("parentloop"));
      context.raiseForLoopLimit(forloop.length);
      const namespace = {
        forloop
      };
      context.forLoops.push(forloop);
      try {
        context.extendSync(namespace, () => {
          for (const item of forloop) {
            namespace[name] = item;
            try {
              this.block.renderSync(context, buf);
            } catch (error) {
              if (error instanceof BreakIteration) {
                break;
              } else if (error instanceof ContinueIteration) {
                continue;
              } else {
                throw error;
              }
            }
          }
        });
      } finally {
        context.forLoops.pop();
      }
    } else if (this.default_ !== undefined) {
      this.default_.renderSync(context, buf);
    }
    if (!this.forceOutput) {
      const buffered = buf.toString();
      if (/\S/.test(buffered)) out.write(buffered);
    }
  }
  children() {
    const _children = [{
      token: this.block.token,
      node: this.block,
      expression: this.expression,
      blockScope: [this.expression.name, "forloop"]
    }];
    if (this.default_) _children.push({
      token: this.default_.token,
      node: this.default_
    });
    return _children;
  }
}

const TAG_IF = "if";
const TAG_ENDIF = "endif";
const TAG_ELSIF$1 = "elsif";
const TAG_ELSE$1 = "else";
class IfTag {
  static END_IF_BLOCK = new Set([TAG_ENDIF, TAG_ELSIF$1, TAG_ELSE$1, TOKEN_EOF$1]);
  static END_ELSEIF_BLOCK = new Set([TAG_ENDIF, TAG_ELSIF$1, TAG_ELSE$1]);
  static END_ELSE_BLOCK = new Set([TAG_ENDIF, TAG_ELSIF$1, TAG_ELSE$1]);
  block = true;
  name = TAG_IF;
  end = TAG_ENDIF;
  nodeClass = IfNode;
  parseExpression(stream) {
    stream.expect(TOKEN_EXPRESSION);
    return parse$5(stream.current.value);
  }
  parse(stream, environment) {
    const parser = environment.parser;
    const token = stream.next();
    const condition = this.parseExpression(stream);
    stream.next();
    const consequence = parser.parseBlock(stream, IfTag.END_IF_BLOCK, token);
    const conditionalAlternatives = [];
    while (stream.current.kind === TOKEN_TAG && stream.current.value === TAG_ELSIF$1) {
      // Eat TAG_ELSIF
      const altTok = stream.next();
      const expr = this.parseExpression(stream);
      conditionalAlternatives.push({
        token: altTok,
        condition: expr,
        consequence: parser.parseBlock(stream, IfTag.END_ELSEIF_BLOCK, stream.next())
      });
    }
    let alternative = undefined;
    if (stream.current.kind === TOKEN_TAG && stream.current.value === TAG_ELSE$1) {
      const tok = stream.next();
      // @ts-expect-error: stream.current has changed, so `kind` will have changed too.
      if (stream.current.kind === TOKEN_EXPRESSION) {
        // Superfluous expressions inside an `else` tag are ignored.
        stream.next();
      }
      alternative = parser.parseBlock(stream, IfTag.END_ELSE_BLOCK, tok);
    }

    // Extraneous `else` and `elsif` blocks are ignored.
    if (!(stream.current.kind === TOKEN_TAG && stream.current.value === TAG_ENDIF)) {
      while (stream.current.kind !== TOKEN_EOF$1) {
        if (stream.current.kind === TOKEN_TAG && stream.current.value === TAG_ENDIF) {
          break;
        }
        stream.next();
      }
    }
    stream.expectTag(TAG_ENDIF);
    return new this.nodeClass(token, condition, consequence, conditionalAlternatives, alternative);
  }
}
class IfNode {
  forceOutput = false;
  constructor(token, condition, consequence, conditionalAlternatives, alternative) {
    this.token = token;
    this.condition = condition;
    this.consequence = consequence;
    this.conditionalAlternatives = conditionalAlternatives;
    this.alternative = alternative;
    this.forceOutput = forcedOutput(this);
  }
  async render(context, out) {
    // This intermediate buffer is used to detect and possibly
    // suppress blocks that, when rendered, contain only whitespace.
    // Don't buffer the output stream if this.forceOutput is true.
    const buf = this.forceOutput ? out : context.environment.renderStreamFactory(out);
    let rendered = false;
    if (await this.condition.evaluate(context)) {
      await this.consequence.render(context, buf);
      rendered = true;
    } else {
      for (const alt of this.conditionalAlternatives) {
        if (await alt.condition.evaluate(context)) {
          await alt.consequence.render(context, buf);
          rendered = true;
          break;
        }
      }
    }
    if (!rendered && this.alternative !== undefined) {
      await this.alternative.render(context, buf);
    }
    if (!this.forceOutput) {
      const buffered = buf.toString();
      if (/\S/.test(buffered)) out.write(buffered);
    }
  }
  renderSync(context, out) {
    const buf = this.forceOutput ? out : context.environment.renderStreamFactory(out);
    let rendered = false;
    if (this.condition.evaluateSync(context)) {
      this.consequence.renderSync(context, buf);
      rendered = true;
    } else {
      for (const alt of this.conditionalAlternatives) {
        if (alt.condition.evaluateSync(context)) {
          alt.consequence.renderSync(context, buf);
          rendered = true;
          break;
        }
      }
    }
    if (!rendered && this.alternative !== undefined) {
      this.alternative.renderSync(context, buf);
    }
    if (!this.forceOutput) {
      const buffered = buf.toString();
      if (/\S/.test(buffered)) out.write(buffered);
    }
  }
  children() {
    const _children = [{
      token: this.token,
      node: this.consequence,
      expression: this.condition
    }, ...this.conditionalAlternatives.map(alt => ({
      token: alt.token,
      node: alt.consequence,
      expression: alt.condition
    }))];
    if (this.alternative !== undefined) _children.push({
      token: this.alternative.token,
      node: this.alternative
    });
    return _children;
  }
}

class IncrementTag {
  block = false;
  name = "increment";
  nodeClass = IncrementNode;
  parse(stream) {
    const token = stream.next();
    stream.expect(TOKEN_EXPRESSION);
    return new this.nodeClass(token, parseUnchainedIdentifier(new ExpressionTokenStream(tokenize$9(stream.current.value))).toString());
  }
}
class IncrementNode {
  constructor(token, identifier) {
    this.token = token;
    this.identifier = identifier;
  }
  async render(context, out) {
    return this.renderSync(context, out);
  }
  renderSync(context, out) {
    let val = context.counters[this.identifier];
    if (val === undefined) val = 0;
    context.counters[this.identifier] = val + 1;
    out.write(val.toString());
  }
  children() {
    return [{
      token: this.token,
      templateScope: [this.identifier]
    }];
  }
}

class IncludeTag {
  block = false;
  name = "include";
  nodeClass = IncludeNode;
  parseArgument(stream) {
    const key = parseUnchainedIdentifier(stream).toString();
    stream.next();
    stream.expect(TOKEN_COLON);
    stream.next(); // Eat colon
    const val = parseObject$2(stream);
    stream.next();
    return [key, val];
  }
  parse(stream) {
    const token = stream.next();
    stream.expect(TOKEN_EXPRESSION);
    const exprStream = new ExpressionTokenStream(tokenize$7(stream.current.value, stream.current.index));

    // The name of a template to include.
    // This should be a string literal or an identifier that resolve to a string.
    const templateName = parseStringOrIdentifier(exprStream);
    exprStream.next();

    // Optionally bind an object to a name while rendering the included template, possibly with an alias.
    let bindName = undefined;
    let alias = undefined;
    if (exprStream.current.kind === TOKEN_WITH || exprStream.current.kind === TOKEN_FOR || exprStream.current.kind === TOKEN_AS // working around dodgy ts
    ) {
      // Eat 'with' or 'for'
      exprStream.next();
      exprStream.expect(TOKEN_IDENT);
      bindName = parseIdentifier$1(exprStream);
      exprStream.next();

      // Optional alias for the bind name.
      if (exprStream.current.kind === TOKEN_AS) {
        // Eat 'with' or 'for'
        exprStream.next();
        exprStream.expect(TOKEN_IDENT);
        alias = parseUnchainedIdentifier(exprStream).toString();
        exprStream.next();
      }
    }
    const args = {};

    // The first keyword argument might follow immediately or after a comma.
    if (exprStream.current.kind === TOKEN_IDENT) {
      const [k, v] = this.parseArgument(exprStream);
      args[k] = v;
    }
    while (exprStream.current.kind !== TOKEN_EOF$1) {
      if (exprStream.current.kind === TOKEN_COMMA) {
        exprStream.next();
        const [k, v] = this.parseArgument(exprStream);
        args[k] = v;
      } else {
        throw new LiquidSyntaxError("expected a comma separated list of arguments, " + `found ${exprStream.current.kind}`, token);
      }
    }
    return new this.nodeClass(token, templateName, bindName, alias, args);
  }
}
class IncludeNode {
  tag = "include";
  constructor(token, templateName, bindName, alias) {
    let args = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : {};
    this.token = token;
    this.templateName = templateName;
    this.bindName = bindName;
    this.alias = alias;
    this.args = args;
  }
  async render(context, out) {
    const templateName = `${await this.templateName.evaluate(context)}`;
    const template = await context.getTemplate(templateName, {
      tag: this.tag
    });
    const scope = {};
    for (const [key, value] of Object.entries(this.args)) {
      scope[key] = await value.evaluate(context);
    }
    await context.extend(scope, async () => {
      if (this.bindName) {
        const bindValue = await this.bindName.evaluate(context);
        const bindKey = this.alias || template.name.split(".", 1)[0];
        if (isLiquidArrayLike(bindValue)) {
          // Render the template once for each item in an array.
          for (const item of bindValue) {
            scope[bindKey] = item;
            await template.renderWithContext(context, out, false, true);
          }
        } else {
          scope[bindKey] = bindValue;
          await template.renderWithContext(context, out, false, true);
        }
      } else {
        await template.renderWithContext(context, out, false, true);
      }
    }, template);
  }
  renderSync(context, out) {
    const templateName = `${this.templateName.evaluateSync(context)}`;
    const template = context.getTemplateSync(templateName, {
      tag: this.tag
    });
    const scope = Object.fromEntries(Object.entries(this.args).map(_ref => {
      let [key, value] = _ref;
      return [key, value.evaluateSync(context)];
    }));
    context.extendSync(scope, () => {
      if (this.bindName) {
        const bindValue = this.bindName.evaluateSync(context);
        const bindKey = this.alias || template.name.split(".", 1)[0];
        if (isLiquidArrayLike(bindValue)) {
          // Render the template once for each item in an array.
          for (const item of bindValue) {
            scope[bindKey] = item;
            template.renderWithContextSync(context, out, false, true);
          }
        } else {
          scope[bindKey] = bindValue;
          template.renderWithContextSync(context, out, false, true);
        }
      } else {
        template.renderWithContextSync(context, out, false, true);
      }
    }, template);
  }
  children() {
    const blockScope = Object.keys(this.args);
    const _children = [{
      token: this.token,
      expression: this.templateName,
      blockScope,
      loadMode: "include",
      loadContext: {
        tag: "include"
      }
    }];
    if (this.bindName) {
      if (this.alias) {
        blockScope.push(this.alias);
      } else if (this.templateName instanceof Literal) {
        blockScope.push(this.templateName.toString().split(".", 1)[0]);
      }
      _children.push({
        token: this.token,
        expression: this.bindName
      });
    }
    for (const expr of Object.values(this.args)) {
      _children.push({
        token: this.token,
        expression: expr
      });
    }
    return _children;
  }
}

class InlineCommentTag {
  block = true;
  name = "comment";
  nodeClass = CommentNode;
  static RE_INVALID_INLINE_COMMENT = /\n\s*[^#\s]/m;
  parse(stream) {
    const tok = stream.current;
    if (stream.peek.kind === TOKEN_EXPRESSION) {
      stream.next();
      if (stream.current.value.search(InlineCommentTag.RE_INVALID_INLINE_COMMENT) !== -1) {
        throw new LiquidSyntaxError("every line of an inline comment must start with a '#' character", stream.current);
      }
    }
    return new this.nodeClass(tok, stream.current.value);
  }
}

const RULES = [["LIQUID_EXPR", "[ \\t]*(?<preamble>(?<name>#|\\w+)[ \\t]*)(?<expr>.*?)[ \\t\\r]*?(\\n+|$)"], [TOKEN_SKIP, "[\\r\\n]+"], [TOKEN_ILLEGAL, "."]];
const RE = new RegExp(RULES.map(_ref => {
  let [n, p] = _ref;
  return `(?<${n}>${p})`;
}).join("|"), "gs");
function isLiquidExpressionMatch(match) {
  return match.LIQUID_EXPR === undefined ? false : true;
}
function isSkipMatch(match) {
  return match.TOKEN_SKIP === undefined ? false : true;
}
function isIllegalMatch(match) {
  return match.TOKEN_ILLEGAL === undefined ? false : true;
}
function tokenize$1(expr) {
  let startIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
  let input = arguments.length > 2 ? arguments[2] : undefined;
  return function* () {
    for (const match of expr.matchAll(RE)) {
      const groups = match.groups;
      if (isLiquidExpressionMatch(groups)) {
        yield new Token(TOKEN_TAG, groups.name, match.index + startIndex, input);
        if (groups.expr) yield new Token(TOKEN_EXPRESSION, groups.expr, match.index + startIndex + groups.preamble.length, input);
      } else if (isSkipMatch(groups)) {
        continue;
      } else if (isIllegalMatch(groups)) throw new LiquidSyntaxError(`unexpected token '${groups.TOKEN_ILLEGAL}'`, new Token(TOKEN_ILLEGAL, groups.TOKEN_ILLEGAL, match.index + startIndex, input));
    }
  }();
}
class LiquidTag {
  block = false;
  name = "liquid";
  nodeClass = LiquidNode;
  parse(stream, environment) {
    const token = stream.next();
    let block;
    if (stream.current.kind === TOKEN_EOF$1) {
      // Empty liquid tag at end of file.
      block = new BlockNode$1(stream.current, []);
    } else if (stream.current.kind === TOKEN_TAG) {
      block = environment.parser.parseLiquid(stream);
    } else {
      stream.expect(TOKEN_EXPRESSION);
      const exprStream = new TemplateTokenStream(tokenize$1(stream.current.value, stream.current.index, stream.current.input));
      block = environment.parser.parseLiquid(exprStream);
    }
    return new this.nodeClass(token, block);
  }
}
class LiquidNode {
  constructor(token, block) {
    this.token = token;
    this.block = block;
  }
  async render(context, out) {
    await this.block.render(context, out);
  }
  renderSync(context, out) {
    this.block.renderSync(context, out);
  }
  children() {
    return this.block.children();
  }
}

class RenderTag {
  block = false;
  name = "render";
  nodeClass = RenderNode;
  parseArgument(stream) {
    const key = parseUnchainedIdentifier(stream).toString();
    stream.next();
    stream.expect(TOKEN_COLON);
    stream.next(); // Eat colon
    const val = parseObject$2(stream);
    stream.next();
    return [key, val];
  }
  parse(stream) {
    const token = stream.next();
    stream.expect(TOKEN_EXPRESSION);
    const exprStream = new ExpressionTokenStream(tokenize$7(stream.current.value, stream.current.index));

    // The name of a template to include.
    // This should to a string literal.
    exprStream.expect(TOKEN_STRING);
    const templateName = parseStringLiteral(exprStream);
    exprStream.next();

    // Optionally bind an object to a name while rendering
    // the included template, possibly with an alias.
    let bindName = undefined;
    let alias = undefined;
    let bindLoop = false;
    if (exprStream.current.kind === TOKEN_WITH || exprStream.current.kind === TOKEN_FOR || exprStream.current.kind === TOKEN_AS // working around dodgy ts
    ) {
      // Remember if this was a 'for' or 'with' binding.
      // Note that the 'include' tag does not make this distinction.
      bindLoop = exprStream.current.kind === TOKEN_FOR;
      // Eat 'with' or 'for'
      exprStream.next();
      exprStream.expect(TOKEN_IDENT);
      bindName = parseIdentifier$1(exprStream);
      exprStream.next();

      // Optional alias for the bind name.
      if (exprStream.current.kind === TOKEN_AS) {
        // Eat 'with' or 'for'
        exprStream.next();
        exprStream.expect(TOKEN_IDENT);
        alias = parseUnchainedIdentifier(exprStream).toString();
        exprStream.next();
      }
    }
    const args = {};

    // The first keyword argument might follow immediately or after a comma.
    if (exprStream.current.kind === TOKEN_IDENT) {
      const [k, v] = this.parseArgument(exprStream);
      args[k] = v;
    }
    while (exprStream.current.kind !== TOKEN_EOF$1) {
      if (exprStream.current.kind === TOKEN_COMMA) {
        exprStream.next();
        const [k, v] = this.parseArgument(exprStream);
        args[k] = v;
      } else {
        throw new LiquidSyntaxError("expected a comma separated list of arguments, " + `found ${exprStream.current.kind}`, token);
      }
    }
    return new this.nodeClass(token, templateName, bindLoop, bindName, alias, args);
  }
}
class RenderNode {
  tag = "render";
  constructor(token, templateName, bindLoop, bindName, alias) {
    let args = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : {};
    this.token = token;
    this.templateName = templateName;
    this.bindLoop = bindLoop;
    this.bindName = bindName;
    this.alias = alias;
    this.args = args;
  }
  async render(context, out) {
    const templateName = `${await this.templateName.evaluate(context)}`;
    const template = await context.getTemplate(templateName, {
      tag: this.tag
    });
    const scope = {};
    for (const [key, value] of Object.entries(this.args)) {
      scope[key] = await value.evaluate(context);
    }

    // Disable include tags in this context.
    const ctx = context.copy(scope, ["include"], true, false, template);
    if (this.bindName) {
      const bindValue = await this.bindName.evaluate(context);
      const bindKey = this.alias || template.name.split(".", 1)[0];
      if (this.bindLoop && isLiquidArrayLike(bindValue)) {
        // Render the template once for each item in an array.
        const forloop = new ForLoopDrop(bindKey, bindValue.values(), bindValue.length, context.environment.undefinedFactory("parentloop"));
        scope.forloop = forloop;
        for (const item of forloop) {
          scope[bindKey] = item;
          await template.renderWithContext(ctx, out, true, true);
        }
      } else {
        scope[bindKey] = bindValue;
        await template.renderWithContext(ctx, out, true, true);
      }
    } else {
      await template.renderWithContext(ctx, out, true, true);
    }
  }
  renderSync(context, out) {
    const templateName = `${this.templateName.evaluateSync(context)}`;
    const template = context.getTemplateSync(templateName, {
      tag: this.tag
    });
    const scope = Object.fromEntries(Object.entries(this.args).map(_ref => {
      let [key, value] = _ref;
      return [key, value.evaluateSync(context)];
    }));

    // Disable include tags in this context.
    const ctx = context.copy(scope, ["include"], true, false, template);
    if (this.bindName) {
      const bindValue = this.bindName.evaluateSync(context);
      const bindKey = this.alias || template.name.split(".", 1)[0];
      if (this.bindLoop && isLiquidArrayLike(bindValue)) {
        // Render the template once for each item in an array.
        const forloop = new ForLoopDrop(bindKey, bindValue.values(), bindValue.length, context.environment.undefinedFactory("parentloop"));
        scope.forloop = forloop;
        for (const item of forloop) {
          scope[bindKey] = item;
          template.renderWithContextSync(ctx, out, true, true);
        }
      } else {
        scope[bindKey] = bindValue;
        template.renderWithContextSync(ctx, out, true, true);
      }
    } else {
      template.renderWithContextSync(ctx, out, true, true);
    }
  }
  children() {
    const blockScope = Object.keys(this.args);
    const _children = [{
      token: this.token,
      expression: this.templateName,
      blockScope,
      loadMode: "render",
      loadContext: {
        tag: "render"
      }
    }];
    if (this.bindName) {
      if (this.alias) {
        blockScope.push(this.alias);
      } else if (this.templateName instanceof Literal) {
        blockScope.push(this.templateName.toString().split(".", 1)[0]);
      }
      _children.push({
        token: this.token,
        expression: this.bindName
      });
    }
    for (const expr of Object.values(this.args)) {
      _children.push({
        token: this.token,
        expression: expr
      });
    }
    return _children;
  }
}

class TableRowLoopDrop {
  static _keys = new Set(["length", "index", "index0", "rindex", "rindex0", "first", "last", "col", "col0", "col_first", "col_last", "row"]);
  _index = -1;
  _row = 1;
  _col = 0;
  constructor(name, it, length, ncols) {
    this.name = name;
    this.it = it;
    this.length = length;
    this.ncols = ncols;
  }
  *[Symbol.iterator]() {
    for (;;) {
      this.step();
      const next = this.it.next();
      if (next.done) break;
      yield next.value;
    }
  }
  [liquidDispatchSync](name) {
    if (TableRowLoopDrop._keys.has(name)) return Reflect.get(this, name);
    throw new InternalKeyError(`TableRowLoopDrop[${name}]`);
  }
  toString() {
    return `ForLoop(${this.name})`;
  }
  step() {
    this._index += 1;
    if (this._col === this.ncols) {
      this._col = 1;
      this._row += 1;
    } else {
      this._col += 1;
    }
  }
  get index() {
    return this._index + 1;
  }
  get index0() {
    return this._index;
  }
  get rindex() {
    return this.length - this._index;
  }
  get rindex0() {
    return this.length - this._index - 1;
  }
  get first() {
    return this._index === 0;
  }
  get last() {
    return this._index === this.length - 1;
  }
  get col() {
    return this._col;
  }
  get col0() {
    return this._col - 1;
  }
  get col_first() {
    return this._col === 1;
  }
  get col_last() {
    return this._col === this.ncols;
  }
  get row() {
    return this._row;
  }
}

const TAG_TABLEROW = "tablerow";
const TAG_ENDTABLEROW = "endtablerow";
class TableRowTag {
  static END_TAGBLOCK = new Set([TAG_ENDTABLEROW]);
  block = true;
  name = TAG_TABLEROW;
  end = TAG_ENDTABLEROW;
  nodeClass = TableRowNode;
  parse(stream, environment) {
    const token = stream.next();
    stream.expect(TOKEN_EXPRESSION);
    const expr = parse$4(stream.current.value);
    stream.next();
    return new this.nodeClass(token, expr, environment.parser.parseBlock(stream, TableRowTag.END_TAGBLOCK, token));
  }
}
class TableRowNode {
  constructor(token, expression, block) {
    this.token = token;
    this.expression = expression;
    this.block = block;
  }
  async render(context, out) {
    const name = this.expression.name;
    const [it, length] = await this.expression.evaluate(context);
    let cols = this.expression.cols === undefined ? length : await this.expression.cols.evaluate(context);
    if (isN(cols)) {
      cols = Math.trunc(parseNumberT(cols).valueOf());
    } else {
      throw new InternalTypeError(`tablerow cols must be an integer, found '${cols}'`);
    }
    const tablerowloop = new TableRowLoopDrop(name, it, length, cols);
    const namespace = {
      tablerowloop
    };
    context.raiseForLoopLimit(tablerowloop.length);
    await context.extend(namespace, async () => {
      out.write('<tr class="row1">\n');
      for (const item of tablerowloop) {
        namespace[name] = item;
        out.write(`<td class="col${tablerowloop.col}">`);
        await this.block.render(context, out);
        out.write("</td>");
        if (tablerowloop.col_last && !tablerowloop.last) {
          out.write(`</tr>\n<tr class="row${tablerowloop.row + 1}">`);
        }
      }
      out.write("</tr>\n");
    });
  }
  renderSync(context, out) {
    const name = this.expression.name;
    const [it, length] = this.expression.evaluateSync(context);
    let cols = this.expression.cols === undefined ? length : this.expression.cols.evaluateSync(context);
    if (isN(cols)) {
      cols = Math.trunc(parseNumberT(cols).valueOf());
    } else {
      throw new InternalTypeError(`tablerow cols must be an integer, found '${cols}'`);
    }
    const tablerowloop = new TableRowLoopDrop(name, it, length, cols);
    const namespace = {
      tablerowloop
    };
    context.raiseForLoopLimit(tablerowloop.length);
    context.extendSync(namespace, () => {
      out.write('<tr class="row1">\n');
      for (const item of tablerowloop) {
        namespace[name] = item;
        out.write(`<td class="col${tablerowloop.col}">`);
        this.block.renderSync(context, out);
        out.write("</td>");
        if (tablerowloop.col_last && !tablerowloop.last) {
          out.write(`</tr>\n<tr class="row${tablerowloop.row + 1}">`);
        }
      }
      out.write("</tr>\n");
    });
  }
  children() {
    return [{
      token: this.block.token,
      node: this.block,
      expression: this.expression,
      blockScope: ["tablerowloop", this.expression.name]
    }];
  }
}

const TAG_UNLESS = "unless";
const TAG_ENDUNLESS = "endunless";
const TAG_ELSIF = "elsif";
const TAG_ELSE = "else";
class UnlessTag {
  static END_IF_BLOCK = new Set([TAG_ENDUNLESS, TAG_ELSIF, TAG_ELSE, TOKEN_EOF$1]);
  static END_ELSEIF_BLOCK = new Set([TAG_ENDUNLESS, TAG_ELSIF, TAG_ELSE]);
  static END_ELSE_BLOCK = new Set([TAG_ENDUNLESS, TAG_ELSIF, TAG_ELSE]);
  block = true;
  name = TAG_UNLESS;
  end = TAG_ENDUNLESS;
  nodeClass = UnlessNode;
  parseExpression(stream) {
    stream.expect(TOKEN_EXPRESSION);
    return parse$5(stream.current.value);
  }
  parse(stream, environment) {
    const parser = environment.parser;
    const token = stream.next();
    const condition = this.parseExpression(stream);
    stream.next();
    const consequence = parser.parseBlock(stream, UnlessTag.END_IF_BLOCK, token);
    const conditionalAlternatives = [];
    while (stream.current.kind === TOKEN_TAG && stream.current.value === TAG_ELSIF) {
      // Eat TAG_ELSIF
      const altToken = stream.next();
      const expr = this.parseExpression(stream);
      conditionalAlternatives.push({
        token: altToken,
        condition: expr,
        consequence: parser.parseBlock(stream, UnlessTag.END_ELSEIF_BLOCK, stream.next())
      });
    }
    let alternative = undefined;
    if (stream.current.kind === TOKEN_TAG && stream.current.value === TAG_ELSE) {
      const tok = stream.next();
      // @ts-expect-error: stream.current has changed, so `kind` will have changed too.
      if (stream.current.kind === TOKEN_EXPRESSION) {
        // Superfluous expressions inside an `else` tag are ignored.
        stream.next();
      }
      alternative = parser.parseBlock(stream, UnlessTag.END_ELSE_BLOCK, tok);
    }

    // Extraneous `else` and `elsif` blocks are ignored.
    if (!(stream.current.kind === TOKEN_TAG && stream.current.value === TAG_ENDUNLESS)) {
      while (stream.current.kind !== TOKEN_EOF$1) {
        if (stream.current.kind === TOKEN_TAG && stream.current.value === TAG_ENDUNLESS) {
          break;
        }
        stream.next();
      }
    }
    return new this.nodeClass(token, condition, consequence, conditionalAlternatives, alternative);
  }
}
class UnlessNode {
  forceOutput = false;
  constructor(token, condition, consequence, conditionalAlternatives, alternative) {
    this.token = token;
    this.condition = condition;
    this.consequence = consequence;
    this.conditionalAlternatives = conditionalAlternatives;
    this.alternative = alternative;
    this.forceOutput = forcedOutput(this);
  }
  async render(context, out) {
    const buf = this.forceOutput ? out : context.environment.renderStreamFactory(out);
    let rendered = false;
    if (!(await this.condition.evaluate(context))) {
      await this.consequence.render(context, buf);
      rendered = true;
    } else {
      for (const alt of this.conditionalAlternatives) {
        if (await alt.condition.evaluate(context)) {
          await alt.consequence.render(context, buf);
          rendered = true;
          break;
        }
      }
    }
    if (!rendered && this.alternative !== undefined) {
      await this.alternative.render(context, buf);
    }
    if (!this.forceOutput) {
      const buffered = buf.toString();
      if (/\S/.test(buffered)) out.write(buffered);
    }
  }
  renderSync(context, out) {
    const buf = this.forceOutput ? out : context.environment.renderStreamFactory(out);
    let rendered = false;
    if (!this.condition.evaluateSync(context)) {
      this.consequence.renderSync(context, buf);
      rendered = true;
    } else {
      for (const alt of this.conditionalAlternatives) {
        if (alt.condition.evaluateSync(context)) {
          alt.consequence.renderSync(context, buf);
          rendered = true;
          break;
        }
      }
    }
    if (!rendered && this.alternative !== undefined) {
      this.alternative.renderSync(context, buf);
    }
    if (!this.forceOutput) {
      const buffered = buf.toString();
      if (/\S/.test(buffered)) out.write(buffered);
    }
  }
  children() {
    const _children = [{
      token: this.consequence.token,
      node: this.consequence,
      expression: this.condition
    }, ...this.conditionalAlternatives.map(alt => ({
      token: alt.token,
      node: alt.consequence,
      expression: alt.condition
    }))];
    if (this.alternative !== undefined) _children.push({
      token: this.alternative.token,
      node: this.alternative
    });
    return _children;
  }
}

class IfChangedTag {
  static END_IFCHANGED_BLOCK = new Set(["endifchanged"]);
  name = "ifchanged";
  block = true;
  nodeClass = IfChangedNode;
  parse(stream, environment) {
    const token = stream.next();
    return new this.nodeClass(token, environment.parser.parseBlock(stream, IfChangedTag.END_IFCHANGED_BLOCK, token));
  }
}
class IfChangedNode {
  constructor(token, block) {
    this.token = token;
    this.block = block;
  }
  async render(context, out) {
    const buf = context.environment.renderStreamFactory(out);
    await this.block.render(context, buf);
    const buffered = buf.toString();
    const ifchanged = context.getRegister("ifchanged");
    const last = ifchanged.get("last");
    if (buffered !== last) {
      ifchanged.set("last", buffered);
      out.write(buffered);
    }
  }
  renderSync(context, out) {
    const buf = context.environment.renderStreamFactory(out);
    this.block.renderSync(context, buf);
    const buffered = buf.toString();
    const ifchanged = context.getRegister("ifchanged");
    const last = ifchanged.get("last");
    if (buffered !== last) {
      ifchanged.set("last", buffered);
      out.write(buffered);
    }
  }
  children() {
    return this.block.children();
  }
}

/**
 *
 * @param env -
 */
function registerBuiltin(env) {
  env.tags["assign"] = new AssignTag();
  env.tags["capture"] = new CaptureTag();
  env.tags["case"] = new CaseTag();
  env.tags["comment"] = new CommentTag();
  env.tags["cycle"] = new CycleTag();
  env.tags["decrement"] = new DecrementTag();
  env.tags["echo"] = new EchoTag();
  env.tags["for"] = new ForTag();
  env.tags["continue"] = new ContinueTag();
  env.tags["break"] = new BreakTag();
  env.tags["if"] = new IfTag();
  env.tags["ifchanged"] = new IfChangedTag();
  env.tags["include"] = new IncludeTag();
  env.tags["increment"] = new IncrementTag();
  env.tags["#"] = new InlineCommentTag();
  env.tags["literal"] = new TemplateLiteral();
  env.tags["liquid"] = new LiquidTag();
  env.tags["render"] = new RenderTag();
  env.tags["statement"] = new OutputStatement();
  env.tags["tablerow"] = new TableRowTag();
  env.tags["unless"] = new UnlessTag();
  env.filters["abs"] = abs;
  env.filters["at_most"] = atMost;
  env.filters["at_least"] = atLeast;
  env.filters["ceil"] = ceil;
  env.filters["divided_by"] = dividedBy;
  env.filters["floor"] = floor;
  env.filters["minus"] = minus;
  env.filters["plus"] = plus;
  env.filters["round"] = round;
  env.filters["times"] = times;
  env.filters["modulo"] = modulo;
  env.filters["capitalize"] = capitalize;
  env.filters["append"] = append;
  env.filters["downcase"] = downcase;
  env.filters["escape"] = escape;
  env.filters["escape_once"] = escapeOnce;
  env.filters["lstrip"] = lstrip;
  env.filters["newline_to_br"] = newlineToBr;
  env.filters["prepend"] = prepend;
  env.filters["remove"] = remove;
  env.filters["remove_first"] = removeFirst;
  env.filters["remove_last"] = removeLast;
  env.filters["replace"] = replace;
  env.filters["replace_first"] = replaceFirst;
  env.filters["replace_last"] = replaceLast;
  env.filters["slice"] = slice;
  env.filters["split"] = split;
  env.filters["upcase"] = upcase;
  env.filters["strip"] = strip;
  env.filters["rstrip"] = rstrip;
  env.filters["strip_html"] = stripHtml;
  env.filters["strip_newlines"] = stripNewlines;
  env.filters["truncate"] = truncate;
  env.filters["truncatewords"] = truncateWords;
  env.filters["url_encode"] = urlEncode;
  env.filters["url_decode"] = urlDecode;
  env.filters["base64_encode"] = base64Encode;
  env.filters["base64_decode"] = base64Decode;
  env.filters["base64_url_safe_encode"] = base64UrlSafeEncode;
  env.filters["base64_url_safe_decode"] = base64UrlSafeDecode;
  env.filters["join"] = join;
  env.filters["first"] = first;
  env.filters["last"] = last;
  env.filters["concat"] = concat;
  env.filters["map"] = map;
  env.filters["reverse"] = reverse;
  env.filters["sort"] = sort;
  env.filters["sort_natural"] = sortNatural;
  env.filters["where"] = where;
  env.filters["uniq"] = uniq;
  env.filters["compact"] = compact;
  env.filters["size"] = size;
  env.filters["default"] = default_;
  env.filters["date"] = date;
  env.filters["sum"] = sum;
}

/**
 * A Least Recently Used cache, implemented as an extended Map.
 */
class LRUCache extends Map {
  constructor() {
    let maxSize = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 128;
    let entries = arguments.length > 1 ? arguments[1] : undefined;
    if (entries !== undefined) {
      super(entries);
    } else {
      super();
    }
    this.maxSize = maxSize;
  }
  get(key) {
    const val = super.get(key);
    if (this.has(key)) {
      this.delete(key);
      this.set(key, val);
    }
    return val;
  }
  set(key, value) {
    if (this.has(key)) {
      this.delete(key);
    } else if (this.size >= this.maxSize) {
      this.delete(this.first());
    }
    return super.set(key, value);
  }
  first() {
    return this.keys().next().value;
  }
}

var MatchGroup = /*#__PURE__*/function (MatchGroup) {
  MatchGroup["RAW"] = "raw";
  MatchGroup["STA"] = "statement";
  MatchGroup["RSS"] = "rightStripStatement";
  MatchGroup["RST"] = "rightStripTag";
  MatchGroup["RSL"] = "rightStripLiteral";
  MatchGroup["RSR"] = "rightStripRaw";
  MatchGroup["RSE"] = "rightStripEndRaw";
  MatchGroup["TAG"] = "tagName";
  MatchGroup["EXP"] = "tagExpression";
  MatchGroup["PRE"] = "tagPreamble";
  MatchGroup["LIT"] = "literal";
  return MatchGroup;
}(MatchGroup || {});
function escapeRegExp(s) {
  return s.replace(/[.*+?^${}()|[\]\\]/g, "\\$&");
}
function compileRules() {
  let statementStart = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "{{";
  let statementEnd = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "}}";
  let tagStart = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : "{%";
  let tagEnd = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : "%}";
  const ts = escapeRegExp(tagStart);
  const te = escapeRegExp(tagEnd);
  const ss = escapeRegExp(statementStart);
  const se = escapeRegExp(statementEnd);
  const rules = [`${ts}-?\\s*raw\\s*(?<${MatchGroup.RSR}>-?)${te}(?<${MatchGroup.RAW}>.*?)` + `${ts}-?\\s*endraw\\s*(?<${MatchGroup.RSE}>-?)${te}`, `${ss}-?\\s*(?<${MatchGroup.STA}>.*?)\\s*(?<${MatchGroup.RSS}>-?)${se}`, `(?<${MatchGroup.PRE}>${ts}-?\\s*(?<${MatchGroup.TAG}>#|\\w*)\\s*)` + `(?<${MatchGroup.EXP}>.*?)\\s*(?<${MatchGroup.RST}>-?)${te}`, `(?<${MatchGroup.LIT}>.+?(?=(?:(?:${ts}|${ss})(?<${MatchGroup.RSL}>-?))|$))`];
  return new RegExp(rules.join("|"), "gs");
}
function isStatement(match) {
  return match.statement === undefined ? false : true;
}
function isTag(match) {
  return match.tagName === undefined ? false : true;
}
function isLiteral(match) {
  return match.literal === undefined ? false : true;
}
function isRaw(match) {
  return match.raw === undefined ? false : true;
}

/**
 * Return a generator function for tokenizing liquid templates.
 */
function tokenizerFor(rules) {
  let statementStart = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "{{";
  let statementEnd = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : "}}";
  let tagStart = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : "{%";
  let tagEnd = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : "%}";
  // eslint-disable-next-line sonarjs/cognitive-complexity
  function* _tokenize(source) {
    let leftStrip = false;
    for (const match of source.matchAll(rules)) {
      const groups = match.groups;
      if (isStatement(groups)) {
        leftStrip = !!groups.rightStripStatement;
        yield new Token(TOKEN_STATEMENT, groups.statement, match.index, source);
      } else if (isTag(groups)) {
        leftStrip = !!groups.rightStripTag;
        yield new Token(TOKEN_TAG, groups.tagName, match.index, source);
        if (groups.tagExpression.length) yield new Token(TOKEN_EXPRESSION, groups.tagExpression, match.index + groups.tagPreamble.length, source);
      } else if (isLiteral(groups)) {
        let value = groups.literal;
        // Whitespace control
        const rightStrip = !!groups.rightStripLiteral;
        if (leftStrip && rightStrip) value = value.trim();else if (leftStrip) value = value.trimStart();else if (rightStrip) value = value.trimEnd();
        // Reset for next literal
        leftStrip = false;

        // Assume a template literal that starts with "{{" or "{%" is an error.
        // As per the reference implementation.
        if (value.startsWith(statementStart)) throw new LiquidSyntaxError(`expected '${statementEnd}', found 'eof'`, new Token(TOKEN_LITERAL, value, match.index, source));
        if (value.startsWith(tagStart)) throw new LiquidSyntaxError(`expected '${tagEnd}', found 'eof'`, new Token(TOKEN_LITERAL, value, match.index, source));
        yield new Token(TOKEN_LITERAL, value, match.index, source);
      } else if (isRaw(groups)) {
        leftStrip = !!groups.rightStripEndRaw;
        yield new Token(TOKEN_LITERAL, groups.raw, match.index, source);
      } else {
        throw Error(`unexpected token kind: ${match}`);
      }
    }
  }
  return _tokenize;
}

/**
 * Represents a Liquid template's source code and additional meta data.
 */
class TemplateSource {
  constructor(
  /**
   * The template's source code.
   */
  source,
  /**
   * A name or identifier for the template.
   */
  name,
  /**
   * Additional template globals.
   */
  matter,
  /**
   * A function that returns `true` if the template is up to date, or
   * `false` if it needs to be loaded again.
   */
  upToDate,
  /**
   * A function that returns `true` if the template is up to date, or
   * `false` if it needs to be loaded again.
   */
  upToDateSync) {
    this.source = source;
    this.name = name;
    this.matter = matter;
    this.upToDate = upToDate;
    this.upToDateSync = upToDateSync;
  }
}

/**
 * The base class for all template loaders.
 */
class Loader {
  /**
   * Override `getSource` to implement a custom loader.
   * @param name - The name or identifier of a template.
   * @param renderContext - The active render context, if there is one.
   * @param loaderContext - Additional context. By convention, tags that load
   * templates should add a `tag` property to the loader context containing
   * the tag's name.
   * @returns The source, with any meta data, for the template identified by
   * the given name
   * @throws {@link TemplateNotFoundError}
   * Thrown if the template can not be found.
   */

  /**
   * A synchronous version of `getSource`.
   * @see {@link getSource}
   */

  /**
   * Used internally by `Environment.getTemplate()`. Delegates to `getSource`.
   * @see {@link getSource}. Override `load` to implement a caching loader.
   */
  async load(name, environment, context, globals, loaderContext) {
    const source = await this.getSource(name, context, loaderContext);
    return environment.fromString(source.source, globals, {
      name,
      matter: source.matter,
      loaderContext,
      upToDate: source.upToDate,
      upToDateSync: source.upToDateSync
    });
  }

  /**
   * A synchronous version of `load`.
   * @see {@link load}
   */
  loadSync(name, environment, context, globals, loaderContext) {
    const source = this.getSourceSync(name, context, loaderContext);
    return environment.fromString(source.source, globals, {
      name,
      matter: source.matter,
      loaderContext,
      upToDate: source.upToDate,
      upToDateSync: source.upToDateSync
    });
  }
}

/**
 * A template loader that will try each of an array of loaders until
 * a template is found, or throw a `TemplateNotFoundError` if none of
 * the loaders could find the template.
 */
class ChoiceLoader extends Loader {
  /**
   *
   * @param loaders -
   */
  constructor(loaders) {
    super();
    this.loaders = loaders;
  }
  getSource() {
    // We're overriding `Loader.load` and delegating to a sub-loader
    // implementation of `getSource`.
    throw new Error("Method not implemented.");
  }
  getSourceSync() {
    // We're overriding `Loader.loadSync` and delegating to a sub-loader
    // implementation of `getSourceSync`.
    throw new Error("Method not implemented.");
  }
  async load(name, environment, context, globals, loaderContext) {
    for (const loader of this.loaders) {
      try {
        return await loader.load(name, environment, context, globals, loaderContext);
      } catch (err) {
        if (err instanceof TemplateNotFoundError) {
          continue;
        }
      }
    }
    throw new TemplateNotFoundError(name);
  }
  loadSync(name, environment, context, globals, loaderContext) {
    for (const loader of this.loaders) {
      try {
        return loader.loadSync(name, environment, context, globals, loaderContext);
      } catch (err) {
        if (err instanceof TemplateNotFoundError) {
          continue;
        }
      }
    }
    throw new TemplateNotFoundError(name);
  }
}

/**
 * Options for a file system template loader in the NodeJS runtime.
 */

/**
 * Options for a caching file system template loader in the NodeJS runtime.
 */

/**
 * A template loader that reads templates from a file system when deployed
 * to the NodeJS runtime.
 */
class NodeFileSystemLoader extends Loader {
  /**
   * The `NodeFileSystemLoader` constructor. Create a new `NodeFileSystemLoader`.
   *
   * @param searchPath - A path, or array of paths, to search for templates.
   * @param options - Loader options.
   */
  constructor(searchPath) {
    let {
      encoding = "utf8",
      fileExtension = ""
    } = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    super();
    this.searchPath = isArray(searchPath) ? searchPath : [searchPath];
    this.encoding = encoding;
    this.fileExtension = fileExtension;
  }
  async getSource(name) {
    const templatePath = await this.resolve(this.withFileExtension(name));
    const source = await fs.readFile(templatePath, {
      encoding: this.encoding
    });
    return new TemplateSource(source, templatePath);
  }
  getSourceSync(name) {
    const templatePath = this.resolveSync(this.withFileExtension(name));
    const source = fsCallback.readFileSync(templatePath, {
      encoding: this.encoding
    });
    return new TemplateSource(source, templatePath);
  }

  /**
   * Append the default file extension if the given template name does
   * not have one.
   * @param name - A template file name relative to one of the paths in the
   * current search path.
   * @returns The argument name with the default file extension, if it did
   * not already have one.
   */
  withFileExtension(name) {
    if (this.fileExtension.length) return path.extname(name) ? name : name + this.fileExtension;
    return name;
  }

  /**
   * Find the path to the template file with the given name.
   * @param name - A template file name relative to one of the paths in the
   * current search path.
   * @returns The template file name joined with the first path in the
   * configured search path that is a file.
   * @throws {@link TemplateNotFoundError}
   * If a file with the given name can not be found.
   */
  async resolve(name) {
    const p = path.normalize(name);
    for (const sp of this.searchPath) {
      const templatePath = path.join(sp, p);
      // Is someone trying to escape the search path?
      if (!isSubPath(sp, templatePath)) throw new TemplateNotFoundError(name);
      try {
        const stat = await fs.stat(templatePath);
        if (stat.isFile()) return templatePath;
      } catch {
        continue;
      }
    }
    throw new TemplateNotFoundError(name);
  }

  /**
   * A synchronous version of {@link resolve}.
   */
  resolveSync(name) {
    const p = path.normalize(name);
    for (const sp of this.searchPath) {
      const templatePath = path.join(sp, p);
      // Is someone trying to escape the search path?
      if (!isSubPath(sp, templatePath)) throw new TemplateNotFoundError(name);
      try {
        const stat = fsCallback.statSync(templatePath);
        if (stat.isFile()) return templatePath;
      } catch {
        continue;
      }
    }
    throw new TemplateNotFoundError(name);
  }
}

/**
 * A template loader that caches templates read from a file system.
 */
class CachingNodeFileSystemLoader extends Loader {
  #cache;

  /**
   * The `CachingNodeFileSystemLoader` constructor.
   *
   * @param searchPath - A path, or array of paths, to search for templates.
   * @param options - Loader options.
   */
  constructor(searchPath) {
    let {
      autoReload = true,
      cacheSize = 300,
      encoding = "utf8",
      fileExtension = ""
    } = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    super();
    this.searchPath = isArray(searchPath) ? searchPath : [searchPath];
    this.encoding = encoding;
    this.autoReload = autoReload;
    this.cacheSize = this.autoReload ? Math.max(cacheSize, 0) : 0;
    this.fileExtension = fileExtension;
    this.#cache = new LRUCache(cacheSize);
  }

  /**
   *
   * @param templatePath -
   * @param mtime -
   * @returns
   */
  static async upToDate(templatePath, mtime) {
    try {
      const stat = await fs.stat(templatePath);
      return stat.mtimeMs === mtime;
    } catch {
      return false;
    }
  }

  /**
   *
   * @param templatePath -
   * @param mtime -
   * @returns
   */
  static upToDateSync(templatePath, mtime) {
    try {
      return fsCallback.statSync(templatePath).mtimeMs === mtime;
    } catch {
      return false;
    }
  }
  async getSource(name) {
    const [templatePath, mtime] = await this.resolve(this.withFileExtension(name));
    const source = await fs.readFile(templatePath, {
      encoding: this.encoding
    });
    if (this.autoReload) {
      return new TemplateSource(source, templatePath, undefined, () => {
        return CachingNodeFileSystemLoader.upToDate(templatePath, mtime);
      });
    } else {
      return new TemplateSource(source, templatePath);
    }
  }
  getSourceSync(name) {
    const [templatePath, mtime] = this.resolveSync(this.withFileExtension(name));
    const source = fsCallback.readFileSync(templatePath, {
      encoding: this.encoding
    });
    if (this.autoReload) {
      return new TemplateSource(source, templatePath, undefined, undefined, () => CachingNodeFileSystemLoader.upToDateSync(templatePath, mtime));
    } else {
      return new TemplateSource(source, templatePath);
    }
  }
  async load(name, environment, context, globals, loaderContext) {
    const cached = this.#cache.get(name);
    if (!cached || this.autoReload && !(await cached.isUpToDate())) {
      const source = await this.getSource(name);
      const template = environment.fromString(source.source, globals, {
        name,
        matter: source.matter,
        loaderContext,
        upToDate: source.upToDate,
        upToDateSync: source.upToDateSync
      });
      this.#cache.set(name, template);
      return template;
    }
    return cached.withGlobals(globals);
  }
  loadSync(name, environment, context, globals, loaderContext) {
    const cached = this.#cache.get(name);
    if (!cached || this.autoReload && !cached.isUpToDateSync()) {
      const source = this.getSourceSync(name);
      const template = environment.fromString(source.source, globals, {
        name,
        matter: source.matter,
        loaderContext,
        upToDate: source.upToDate,
        upToDateSync: source.upToDateSync
      });
      this.#cache.set(name, template);
      return template;
    }
    return cached.withGlobals(globals);
  }

  /**
   *
   * @param name -
   * @returns
   */
  // eslint-disable-next-line sonarjs/no-identical-functions
  withFileExtension(name) {
    if (this.fileExtension.length) return path.extname(name) ? name : name + this.fileExtension;
    return name;
  }

  /**
   *
   * @param name -
   * @returns
   */
  async resolve(name) {
    const p = path.normalize(name);
    for (const sp of this.searchPath) {
      const templatePath = path.join(sp, p);
      // Is someone trying to escape the search path?
      if (!isSubPath(sp, templatePath)) throw new TemplateNotFoundError(name);
      try {
        const stat = await fs.stat(templatePath);
        if (stat.isFile()) return [templatePath, stat.mtimeMs];
      } catch {
        continue;
      }
    }
    throw new TemplateNotFoundError(name);
  }

  /**
   *
   * @param name -
   * @returns
   */
  resolveSync(name) {
    const p = path.normalize(name);
    for (const sp of this.searchPath) {
      const templatePath = path.join(sp, p);
      // Is someone trying to escape the search path?
      if (!isSubPath(sp, templatePath)) throw new TemplateNotFoundError(name);
      try {
        const stat = fsCallback.statSync(templatePath);
        if (stat.isFile()) return [templatePath, stat.mtimeMs];
      } catch {
        continue;
      }
    }
    throw new TemplateNotFoundError(name);
  }
}

/** Return `true` if the given path is a sub path of `parent`. */
function isSubPath(parent, dir) {
  const relative = path.relative(parent, dir);
  return !!relative.length && !relative.startsWith(".") && !path.isAbsolute(relative);
}

/**
 * A loader that uses a Map of strings to store template source Text.
 */
class MapLoader extends Loader {
  #templateMap;
  constructor(map) {
    super();
    this.#templateMap = map === undefined ? new Map() : map;
  }
  async getSource(name) {
    return this.getSourceSync(name);
  }
  getSourceSync(name) {
    const source = this.#templateMap.get(name);
    if (source === undefined) throw new TemplateNotFoundError(name);
    return new TemplateSource(source, name);
  }
}

/**
 * A loader that uses an Object of strings to store template template source Text.
 */
class ObjectLoader extends Loader {
  constructor(obj) {
    super();
    this.obj = obj;
    this._obj = obj === undefined ? {} : obj;
  }
  async getSource(name) {
    return this.getSourceSync(name);
  }
  getSourceSync(name) {
    const source = this._obj[name];
    if (source !== undefined) return new TemplateSource(source, name);
    throw new TemplateNotFoundError(name);
  }
}

/**
 * Options for the `FetchLoader` template loader.
 */

/**
 * A template loader that fetches templates using the Fetch API.
 *
 * This is an async only loader. Expect an error when using this
 * loader with `getSourceSync()` and `Environment.getTemplateSync()`.
 *
 * This loader treats the response body as text that is the template
 * source code. You might need to write a custom loader to handle
 * JSON responses, for example.
 */
class FetchLoader extends Loader {
  #init;

  /**
   * The `FetchLoader` constructor. Creates a new `FetchLoader`.
   *
   * @param baseURL - The base URL from which to fetch templates
   * from.
   * @param options - Loader options. Most of which are passed
   * through to the Fetch API's `Request` constructor.
   */
  constructor(baseURL) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    super();
    this.baseURL = baseURL;
    this.#init = {
      cache: options.cache ?? "default",
      credentials: options.credentials ?? "same-origin",
      headers: options.headers ?? new Headers(),
      method: "GET",
      mode: options.mode ?? "cors"
    };
  }
  async getSource(name) {
    const url = `${this.baseURL}/${name}`;
    const request = new Request(url, this.#init);
    const response = await fetch(request);
    if (!response.ok) throw new TemplateNotFoundError(`${url} (${response.status})`);
    return new TemplateSource(await response.text(), name);
  }
  getSourceSync() {
    throw new Error("synchronous loading is not available when using FetchLoader");
  }
}

/**
 * A template loader that uses XMLHttpRequest to fetch templates.
 */
class XMLHttpRequestLoader extends Loader {
  /**
   * The `XMLHttpRequestLoader` constructor.
   *
   * @param baseURL - The base URL from which to fetch templates from.
   * @param options - Loader options.
   */
  constructor(baseURL) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    super();
    this.baseURL = baseURL;
    this.bustBrowserCache = options.bustBrowserCache ?? true;
  }
  async getSource(name) {
    const url = this.url(name);
    const request = await this.fetch(url);
    if (request.status === 0 || request.status === 200) {
      return new TemplateSource(request.responseText, name);
    }
    throw new TemplateNotFoundError(`${url} (${request.status})`);
  }
  getSourceSync(name) {
    const url = this.url(name);
    const request = new XMLHttpRequest();
    request.open("GET", url, false);
    request.send();
    if (request.status === 0 || request.status === 200) {
      return new TemplateSource(request.responseText, name);
    }
    throw new TemplateNotFoundError(`${url} (${request.status})`);
  }
  url(name) {
    const url = `${this.baseURL}/${name}`;
    if (this.bustBrowserCache) {
      return (
        // eslint-disable-next-line prefer-template
        url + (url.indexOf("?") === -1 ? "?" : "&") + "s=" + new Date().getTime()
      );
    }
    return url;
  }
  fetch(url) {
    return new Promise(resolve => {
      const request = new XMLHttpRequest();
      request.open("GET", url, true);
      request.onload = () => resolve(request);
      request.send();
    });
  }
}

class TemplateParser {
  constructor(environment) {
    this.environment = environment;
  }
  parse(stream) {
    const root = new Root();
    while (stream.current.kind !== TOKEN_EOF$1) {
      try {
        root.nodes.push(this.parseStatement(stream));
      } catch (error) {
        if (error instanceof Error) this.environment.error(error);else throw error;
      }
      stream.next();
    }
    return root;
  }
  parseBlock(stream, end, token) {
    const block = new BlockNode$1(token ?? stream.current);
    while (!(stream.current.kind === TOKEN_TAG && end.has(stream.current.value))) {
      if (stream.current.kind === TOKEN_EOF$1) throw new LiquidSyntaxError(`missing end tag, expected ${Array.from(end.values()).join(", ")}`, stream.current);
      block.nodes.push(this.parseStatement(stream));
      stream.next();
    }
    return block;
  }
  parseLiquid(stream) {
    const block = new BlockNode$1(stream.current);
    while (stream.current.kind !== TOKEN_EOF$1) {
      block.nodes.push(this.parseStatement(stream));
      stream.next();
    }
    return block;
  }
  getTag(token) {
    const tag = this.environment.tags[token.value];
    if (!tag) throw new LiquidSyntaxError(`unexpected tag '${token.value}'`, token);
    return tag;
  }
  parseStatement(stream) {
    let node;
    switch (stream.current.kind) {
      case TOKEN_STATEMENT:
        node = this.environment.tags["statement"].parse(stream, this.environment);
        break;
      case TOKEN_TAG:
        node = this.getTag(stream.current).parse(stream, this.environment);
        break;
      case TOKEN_LITERAL:
        node = this.environment.tags["literal"].parse(stream, this.environment);
        break;
      default:
        throw new LiquidSyntaxError(`unexpected token ${stream.current.kind}`, stream.current);
    }
    return node;
  }
}

const TAG_EXTENDS = "extends";
const TAG_BLOCK = "block";
const TAG_END_BLOCK = "endblock";
const END_BLOCK = new Set([TAG_END_BLOCK, TOKEN_EOF]);
const EXTENDS_REGISTER = Symbol.for("liquid.tags.extends");
class BlockDrop {
  constructor(context, out, name, parent) {
    this.context = context;
    this.out = out;
    this.name = name;
    this.parent = parent;
  }
  [liquidDispatchSync](name) {
    if (name !== "super") {
      throw new InternalKeyError(`BlockDrop[${name}]`);
    }
    if (this.parent === undefined) {
      return this.context.environment.undefinedFactory("super");
    }
    const buf = this.context.environment.renderStreamFactory(this.out);
    this.context.extendSync({
      block: new BlockDrop(this.context, buf, this.parent.sourceName, this.parent.parent)
    }, () => this.parent?.block.block.renderSync(this.context, buf));
    return this.context.environment.autoEscape ? new Markup(buf.toString()) : buf.toString();
  }
}
class BlockTag {
  parse(stream, environment) {
    const token = stream.next();
    stream.expect(TOKEN_EXPRESSION);
    let eStream = new ExpressionTokenStream(tokenize$3(stream.current.value, token.index));
    const blockName = this.parseBlockName(eStream);
    eStream.next();
    let required;
    if (eStream.current.value === "required") {
      required = true;
      eStream.next();
    } else {
      required = false;
    }
    eStream.expect(TOKEN_EOF);
    stream.next();
    const block = environment.parser.parseBlock(stream, END_BLOCK);
    stream.expectTag(TAG_END_BLOCK);

    // Named end block?
    if (stream.peek.kind === TOKEN_EXPRESSION) {
      stream.next();
      eStream = new ExpressionTokenStream(tokenize$3(stream.current.value, stream.current.index));
      const endBlockName = this.parseBlockName(eStream);
      eStream.next();
      eStream.expect(TOKEN_EOF);
      if (!endBlockName.equals(blockName)) {
        throw new TemplateInheritanceError(`expected endblock for '${blockName}', found '${endBlockName}'`, stream.current);
      }
    }
    return new BlockNode(token, blockName, block, required);
  }
  parseBlockName(eStream) {
    if (eStream.current.kind === TOKEN_IDENT || eStream.current.kind === TOKEN_STRING) {
      return new StringLiteral(eStream.current.value);
    }
    throw new LiquidSyntaxError(`invalid identifier '${eStream.current.value}' for '${TAG_BLOCK}'`, eStream.current);
  }
}
class ExtendsTag {
  block = false;
  name = TAG_EXTENDS;
  nodeClass = ExtendsNode;
  parse(stream) {
    const token = stream.next();
    stream.expect(TOKEN_EXPRESSION);
    const eStream = new ExpressionTokenStream(tokenize$3(stream.current.value, token.index));
    const parentTemplateName = parseStringLiteral(eStream);
    eStream.next();
    eStream.expect(TOKEN_EOF);
    return new ExtendsNode(token, parentTemplateName);
  }
}
class BlockNode {
  constructor(token, name, block, required) {
    this.token = token;
    this.block = block;
    this.required = required;
    this.expression = name;
    this.name = liquidStringify(name.value);
  }
  async render(context, out) {
    const blockStack = context.getRegister(EXTENDS_REGISTER).get(this.name);
    if (blockStack === undefined || !blockStack.length) {
      // This base template is being rendered directly.
      if (this.required) {
        throw new TemplateInheritanceError(`block '${this.name}' must be overridden`, this.token);
      }
      await context.extend({
        block: new BlockDrop(context, out, this.name)
      }, async () => await this.block.render(context, out));
      return;
    }
    const stackItem = blockStack[0];
    if (stackItem.required) {
      throw new TemplateInheritanceError(`block '${this.name}' must be overridden`, this.token, stackItem.sourceName);
    }
    const ctx = context.copy({
      block: new BlockDrop(context, out, this.name, stackItem.parent)
    }, [], true, true);
    await stackItem.block.block.render(ctx, out);
  }
  renderSync(context, out) {
    const blockStack = context.getRegister(EXTENDS_REGISTER).get(this.name);
    if (blockStack === undefined || !blockStack.length) {
      // This base template is being rendered directly.
      if (this.required) {
        throw new TemplateInheritanceError(`block '${this.name}' must be overridden`, this.token);
      }
      context.extendSync({
        block: new BlockDrop(context, out, this.name)
      }, () => this.block.renderSync(context, out));
      return;
    }
    const stackItem = blockStack[0];
    if (stackItem.required) {
      throw new TemplateInheritanceError(`block '${this.name}' must be overridden`, this.token, stackItem.sourceName);
    }
    const ctx = context.copy({
      block: new BlockDrop(context, out, this.name, stackItem.parent)
    }, [], true, true);
    stackItem.block.block.renderSync(ctx, out);
  }
  children() {
    return [{
      token: this.token,
      expression: this.expression
    }, {
      token: this.token,
      node: this.block,
      blockScope: ["block"]
    }];
  }
}
class ExtendsNode {
  static tag = TAG_EXTENDS;
  constructor(token, name) {
    this.token = token;
    this.name = name;
  }
  async render(context, out) {
    if (context.template === undefined) {
      const msg = "the 'extends' tag requires the current render context to keep a " + "reference to its template as Context.template";
      throw new LiquidEnvironmentError(msg, this.token);
    }
    const baseTemplate = await buildBlockStacks(context, context.template, liquidStringify(this.name.evaluateSync(context)), TAG_EXTENDS);
    await baseTemplate.renderWithContext(context, out);
    context.getRegister(EXTENDS_REGISTER).clear();
    throw new StopRender("stop");
  }
  renderSync(context, out) {
    if (context.template === undefined) {
      const msg = "the 'extends' tag requires the current render context to keep a " + "reference to its template as Context.template";
      throw new LiquidEnvironmentError(msg, this.token);
    }
    const baseTemplate = buildBlockStacksSync(context, context.template, liquidStringify(this.name.evaluateSync(context)), TAG_EXTENDS);
    baseTemplate.renderWithContextSync(context, out);
    context.getRegister(EXTENDS_REGISTER).clear();
    throw new StopRender("stop");
  }
  children() {
    return [{
      token: this.token,
      expression: this.name,
      loadMode: "extends",
      loadContext: {
        tag: ExtendsNode.tag
      }
    }];
  }
}

/**
 * Build a stack for each `{% block %}` in the inheritance chain.
 *
 * @param context - A render context to build the block stacks in.
 * @param template - A leaf template with an _extends_ tag.
 * @param parentName - The name of the immediate parent template.
 * @param tag - The name of the "extends" tag, if it is overridden.
 */
async function buildBlockStacks(context, template, parentName) {
  let tag = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : TAG_EXTENDS;
  context.registers.set(EXTENDS_REGISTER, new DefaultMap(Array));

  // Guard against recursive _extends_.
  const seen = new Set();
  let stacked = stackBlocks(context, template);
  let parent = await context.getTemplate(parentName, {
    tag
  });
  if (stacked.extendsNode === undefined) {
    throw new InternalSyntaxError(`expected an '${tag}' node (${parentName}, ${template.name})`);
  }
  seen.add(liquidStringify(stacked.extendsNode.name.evaluateSync(context)));
  stacked = stackBlocks(context, parent);
  let parentTemplateName = undefined;
  if (stacked.extendsNode) {
    parentTemplateName = liquidStringify(stacked.extendsNode.name.evaluateSync(context));
    if (seen.has(parentTemplateName)) {
      throw new TemplateInheritanceError(`circular extends '${parentTemplateName}'`, stacked.extendsNode.token);
    }
    seen.add(parentTemplateName);
  }
  while (parentTemplateName) {
    parent = await context.getTemplate(parentTemplateName, {
      tag
    });
    stacked = stackBlocks(context, parent);
    if (stacked.extendsNode) {
      parentTemplateName = liquidStringify(stacked.extendsNode.name.evaluateSync(context));
      if (seen.has(parentTemplateName)) {
        throw new TemplateInheritanceError(`circular extends '${parentTemplateName}'`, stacked.extendsNode.token);
      }
      seen.add(parentTemplateName);
    } else {
      parentTemplateName = undefined;
    }
  }
  return parent;
}
function buildBlockStacksSync(context, template, parentName) {
  let tag = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : TAG_EXTENDS;
  context.registers.set(EXTENDS_REGISTER, new DefaultMap(Array));

  // Guard against recursive _extends_.
  const seen = new Set();
  let stacked = stackBlocks(context, template);
  let parent = context.getTemplateSync(parentName, {
    tag
  });
  if (stacked.extendsNode === undefined) {
    throw new InternalSyntaxError(`expected an '${tag}' node`);
  }
  seen.add(liquidStringify(stacked.extendsNode.name.evaluateSync(context)));
  stacked = stackBlocks(context, parent);
  let parentTemplateName = undefined;
  if (stacked.extendsNode) {
    parentTemplateName = liquidStringify(stacked.extendsNode.name.evaluateSync(context));
    if (seen.has(parentTemplateName)) {
      throw new TemplateInheritanceError(`circular extends '${parentTemplateName}'`, stacked.extendsNode.token);
    }
    seen.add(parentTemplateName);
  }
  while (parentTemplateName) {
    parent = context.getTemplateSync(parentTemplateName, {
      tag
    });
    stacked = stackBlocks(context, parent);
    if (stacked.extendsNode) {
      parentTemplateName = liquidStringify(stacked.extendsNode.name.evaluateSync(context));
      if (seen.has(parentTemplateName)) {
        throw new TemplateInheritanceError(`circular extends '${parentTemplateName}'`, stacked.extendsNode.token);
      }
      seen.add(parentTemplateName);
    } else {
      parentTemplateName = undefined;
    }
  }
  return parent;
}
function findInheritanceNodes(template) {
  const extendsNodes = [];
  const blockNodes = [];
  for (const node of template.tree.nodes) {
    visitNode(node, extendsNodes, blockNodes);
  }
  return {
    extendsNodes,
    blockNodes
  };
}
function visitNode(node, extendsNodes, blockNodes) {
  if (node instanceof BlockNode) {
    blockNodes.push(node);
  } else if (node instanceof ExtendsNode) {
    extendsNodes.push(node);
  }
  if (node.children) {
    for (const child of node.children()) {
      if (child.node) {
        visitNode(child.node, extendsNodes, blockNodes);
      }
    }
  }
}
function stackBlocks(context, template) {
  const {
    extendsNodes,
    blockNodes
  } = findInheritanceNodes(template);
  if (extendsNodes.length > 1) {
    throw new TemplateInheritanceError("too many 'extends' tags", extendsNodes[1].token);
  }
  const seenBlockNames = new Set();
  for (const block of blockNodes) {
    if (seenBlockNames.has(block.name)) {
      throw new TemplateInheritanceError(`duplicate block '${block.name}'`, block.token);
    }
    seenBlockNames.add(block.name);
  }
  storeBlocks(context, blockNodes, template.name);
  return extendsNodes.length > 0 ? {
    extendsNode: extendsNodes[0],
    blockNodes
  } : {
    extendsNode: undefined,
    blockNodes
  };
}

/**
 * Push block nodes onto stacks held in the render context register.
 */
function storeBlocks(context, blocks, sourceName) {
  const blockStacks = context.getRegister(EXTENDS_REGISTER);
  let stack;
  for (const block of blocks) {
    stack = blockStacks.get(block.name);
    stack.push({
      block,
      required: stack.length && !block.required ? false : block.required,
      sourceName
    });
    if (stack.length > 1) {
      stack[stack.length - 2].parent = stack[stack.length - 1];
    }
  }
}

/**
 * Options passed to `Template.analyze` and `Template.analyzeSync`.
 */

/**
 * The location of a template variable, as found during static template
 * analysis.
 *
 * A column number might be added later.
 */

/**
 * An array of template variable locations.
 */

/**
 * A mapping of template variable names to their locations.
 */

/**
 * A mapping of template, tag or filter names to their locations.
 */

/**
 * The result of statically analyzing a template's variables.
 *
 * Each of the following properties is an object mapping template variable names
 * to an array of objects. Each object includes the template name and line number
 * of the associated variable. If a name is referenced multiple times, it will
 * appear multiple times in the array. If a name is referenced before it is
 * "assigned", it will appear in `localVariables` and `globalVariables`.
 */

class TemplateVariableCounter {
  static RE_SPLIT_IDENT = /(\.|\[)/;
  constructor(template, _ref2) {
    let {
      followPartials,
      raiseForFailures,
      scope,
      templateLocals,
      partials
    } = _ref2;
    this.template = template;
    this.templateName = this.template.name;
    this.followPartials = followPartials ?? true;
    this.raiseForFailures = raiseForFailures ?? true;
    this.scope = scope ?? chainObjects();
    this.partials = partials ?? new Set();
    this.emptyContext = new RenderContext(this.template.environment);
    this.templateLocals = templateLocals ?? new DefaultMap(Array);
    this.templateGlobals = new DefaultMap(Array);
    this.variables = new DefaultMap(Array);
    this.failedVisits = new DefaultMap(Array);
    this.unloadablePartials = new DefaultMap(Array);
    this.filters = new DefaultMap(Array);
    this.tags = new DefaultMap(Array);
  }
  async analyze() {
    for (const node of this.template.tree.nodes) {
      try {
        await this._analyze(node);
      } catch (error) {
        if (error instanceof StopRender) {
          break;
        }
        throw error;
      }
    }
    this._raiseForFailures();
    return this;
  }
  analyzeSync() {
    for (const node of this.template.tree.nodes) {
      try {
        this._analyzeSync(node);
      } catch (error) {
        if (error instanceof StopRender) {
          break;
        }
        throw error;
      }
    }
    this._raiseForFailures();
    return this;
  }
  async _analyze(root) {
    this.countTag(root);
    if (root.children === undefined) {
      // This node does not define a children method.
      const name = root.constructor.name;
      this.failedVisits.get(name).push({
        templateName: this.templateName,
        lineNumber: root.token.lineNumber()
      });
      return;
    }
    for (const child of root.children()) {
      this.analyzeExpression(child);
      await this.expressionHook(child);
      this.updateTemplateScope(child);
      if (child.blockScope) {
        this.scope[chainPush](Object.fromEntries(child.blockScope.map(val => [val, undefined])));
      }
      if (this.followPartials) {
        switch (child.loadMode) {
          case "include":
            await this.analyzeInclude(child);
            break;
          case "render":
            await this.analyzeRender(child);
            break;
          case "extends":
            await this.analyzeTemplateInheritanceChain(child, this.template);
            throw new StopRender("stop static analysis");
          case undefined:
            break;
          default:
            throw new TemplateTraversalError(`unknown load mode '${child.loadMode}'`);
        }
      }

      // Recurse
      if (child.node) {
        await this._analyze(child.node);
      }
      if (child.blockScope) {
        this.scope[chainPop]();
      }
    }
  }
  _analyzeSync(root) {
    this.countTag(root);
    if (root.children === undefined) {
      // This node does not define a children method.
      const name = root.constructor.name;
      this.failedVisits.get(name).push({
        templateName: this.templateName,
        lineNumber: root.token.lineNumber()
      });
      return;
    }
    for (const child of root.children()) {
      this.analyzeExpression(child);
      this.expressionHookSync(child);
      this.updateTemplateScope(child);
      if (child.blockScope) {
        this.scope[chainPush](Object.fromEntries(child.blockScope.map(val => [val, undefined])));
      }
      if (this.followPartials) {
        switch (child.loadMode) {
          case "include":
            this.analyzeIncludeSync(child);
            break;
          case "render":
            this.analyzeRenderSync(child);
            break;
          case "extends":
            this.analyzeTemplateInheritanceChainSync(child, this.template);
            throw new StopRender("stop static analysis");
          case undefined:
            break;
          default:
            throw new TemplateTraversalError(`unknown load mode '${child.loadMode}'`);
        }
      }

      // Recurse
      if (child.node) {
        this._analyzeSync(child.node);
      }
      if (child.blockScope) {
        this.scope[chainPop]();
      }
    }
  }
  analyzeExpression(child) {
    if (!child.expression) return;
    if (!child.expression.children) {
      // This expression does not define a children method.
      const name = child.expression.constructor.name;
      this.failedVisits.get(name).push({
        templateName: this.templateName,
        lineNumber: child.token.lineNumber()
      });
    }
    const refs = this.updateExpressionRefs(child.expression);
    for (const ref of refs.variables) {
      this.variables.get(ref).push({
        templateName: this.templateName,
        lineNumber: child.token.lineNumber()
      });
    }

    // Check refs that are not in scope or in the local namespace before
    // pushing the next block scope. This should highlight names that are
    // expected to be "global"
    for (const ref of refs.variables) {
      const _ref = ref.split(TemplateVariableCounter.RE_SPLIT_IDENT, 1)[0];
      if (this.scope[_ref] === Missing && !this.templateLocals.has(_ref)) {
        this.templateGlobals.get(ref).push({
          templateName: this.templateName,
          lineNumber: child.token.lineNumber()
        });
      }
    }
    for (const ref of refs.filters) {
      this.filters.get(ref).push({
        templateName: this.templateName,
        lineNumber: child.token.lineNumber()
      });
    }
  }
  updateTemplateScope(child) {
    if (child.templateScope) {
      for (const name of child.templateScope) {
        this.templateLocals.get(name).push({
          templateName: this.templateName,
          lineNumber: child.token.lineNumber()
        });
      }
    }
  }
  updateExpressionRefs(expression) {
    const refs = {
      variables: [],
      filters: []
    };
    if (expression instanceof Identifier) {
      refs.variables.push(expression.toString());
    } else if (expression instanceof FilteredExpression) {
      refs.filters.push(...expression.filters.map(f => f.name));
    }
    if (expression.children) {
      for (const expr of expression.children()) {
        for (const child of this.updateExpressionRefs(expr).variables) {
          refs.variables.push(child);
        }
      }
    }
    return refs;
  }
  async analyzeInclude(child) {
    const {
      templateName,
      loadContext
    } = this.includeContext(child);
    if (templateName === undefined || loadContext === undefined) {
      return;
    }
    let template;
    try {
      template = await this.getTemplate(templateName, loadContext, this.templateName, child);
    } catch (error) {
      if (error instanceof TemplateNotFoundError) return;
      throw error;
    }
    const refs = await new TemplateVariableCounter(template, {
      followPartials: this.followPartials,
      scope: this.scope,
      templateLocals: this.templateLocals,
      partials: this.partials
    }).analyze();
    this.updateReferenceCounters(refs);
  }
  analyzeIncludeSync(child) {
    const {
      templateName,
      loadContext
    } = this.includeContext(child);
    if (templateName === undefined || loadContext === undefined) {
      return;
    }
    let template;
    try {
      template = this.getTemplateSync(templateName, loadContext, this.templateName, child);
    } catch (error) {
      if (error instanceof TemplateNotFoundError) return;
      throw error;
    }
    const refs = new TemplateVariableCounter(template, {
      followPartials: this.followPartials,
      scope: this.scope,
      templateLocals: this.templateLocals,
      partials: this.partials
    }).analyzeSync();
    this.updateReferenceCounters(refs);
  }
  includeContext(child) {
    if (child.expression === undefined) {
      return {};
    }

    // Partial templates rendered in "include" mode might use a variable template
    // name. We can't statically analyze a partial template unless it's name is a
    // literal string (or possibly an integer, but unlikely).
    if (!(child.expression instanceof Literal)) {
      this.unloadablePartials.get(child.expression.toString()).push({
        templateName: this.templateName,
        lineNumber: child.token.lineNumber()
      });
      return {};
    }
    const context = {
      templateName: child.expression.value.toString(),
      loadContext: child.loadContext ?? {}
    };
    const contextKey = JSON.stringify(context);

    // Keep track of partial templates that have already been analyzed. This prevents
    // us from analyzing the same template twice and protects us against recursive
    // includes/renders.
    if (this.partials.has(contextKey)) {
      return {};
    }
    this.partials.add(contextKey);
    return context;
  }
  async analyzeRender(child) {
    const {
      templateName,
      loadContext
    } = this.renderContext(child);
    if (templateName === undefined || loadContext === undefined) {
      return;
    }
    let template;
    try {
      template = await this.getTemplate(templateName, loadContext, this.templateName, child);
    } catch (error) {
      if (error instanceof TemplateNotFoundError) return;
      throw error;
    }

    // Partial templates rendered in "render" mode do not share the parent template
    // local namespace. We do not pass the current block scope stack to "rendered"
    // templates either.
    const scope = chainObjects();
    if (child.blockScope) {
      scope[chainPush](Object.fromEntries(child.blockScope.map(val => [val, undefined])));
    }
    const refs = await new TemplateVariableCounter(template, {
      followPartials: this.followPartials,
      scope,
      partials: this.partials
    }).analyze();
    this.updateReferenceCounters(refs);
  }
  analyzeRenderSync(child) {
    const {
      templateName,
      loadContext
    } = this.renderContext(child);
    if (templateName === undefined || loadContext === undefined) {
      return;
    }
    let template;
    try {
      template = this.getTemplateSync(templateName, loadContext, this.templateName, child);
    } catch (error) {
      if (error instanceof TemplateNotFoundError) return;
      throw error;
    }

    // Partial templates rendered in "render" mode do not share the parent template
    // local namespace. We do not pass the current block scope stack to "rendered"
    // templates either.
    const scope = chainObjects();
    if (child.blockScope) {
      scope[chainPush](Object.fromEntries(child.blockScope.map(val => [val, undefined])));
    }
    const refs = new TemplateVariableCounter(template, {
      followPartials: this.followPartials,
      scope,
      partials: this.partials
    }).analyzeSync();
    this.updateReferenceCounters(refs);
  }
  async analyzeTemplateInheritanceChain(node, template) {
    const {
      templateName,
      loadContext
    } = this.renderContext(node);
    if (templateName === undefined || loadContext === undefined) {
      return;
    }
    const stackContext = this.emptyContext.copy({}, [], false, false, template);
    stackContext.registers.set(EXTENDS_REGISTER$1, new DefaultMap(Array));

    // Guard against recursive `extends`.
    const seen = new Set();

    // Add blocks from the leaf template tot he stack context.
    let stacked = this.stackBlocks(stackContext, template, false);
    if (stacked.extendsNode === undefined) {
      throw new InternalSyntaxError(`expected an 'extends' node`);
    }
    seen.add(liquidStringify(stacked.extendsNode.name));
    let parent;
    try {
      parent = await this.getTemplate(templateName, loadContext, this.templateName, node);
    } catch (error) {
      if (error instanceof TemplateNotFoundError) return;
      throw error;
    }
    stacked = this.stackBlocks(stackContext, parent);
    let parentTemplateName = this.extend(stacked, seen);
    while (parentTemplateName) {
      try {
        parent = await this.getTemplate(parentTemplateName, loadContext, this.templateName, node);
      } catch (error) {
        if (error instanceof TemplateNotFoundError) return;
        throw error;
      }
      stacked = this.stackBlocks(stackContext, parent);
      parentTemplateName = this.extend(stacked, seen);
    }
    const refs = await new InheritanceChainCounter(parent, stackContext, undefined, {
      followPartials: this.followPartials,
      scope: chainObjects({
        block: undefined
      }, this.scope),
      templateLocals: this.templateLocals,
      raiseForFailures: this.raiseForFailures,
      partials: this.partials
    }).analyze();
    this.updateReferenceCounters(refs);
  }
  analyzeTemplateInheritanceChainSync(node, template) {
    const {
      templateName,
      loadContext
    } = this.renderContext(node);
    if (templateName === undefined || loadContext === undefined) {
      return;
    }
    const stackContext = this.emptyContext.copy({}, [], false, false, template);
    stackContext.registers.set(EXTENDS_REGISTER$1, new DefaultMap(Array));

    // Guard against recursive `extends`.
    const seen = new Set();

    // Add blocks from the leaf template tot he stack context.
    let stacked = this.stackBlocks(stackContext, template, false);
    if (stacked.extendsNode === undefined) {
      throw new InternalSyntaxError(`expected an 'extends' node`);
    }
    seen.add(liquidStringify(stacked.extendsNode.name));
    let parent;
    try {
      parent = this.getTemplateSync(templateName, loadContext, this.templateName, node);
    } catch (error) {
      if (error instanceof TemplateNotFoundError) return;
      throw error;
    }
    stacked = this.stackBlocks(stackContext, parent);
    let parentTemplateName = this.extend(stacked, seen);
    while (parentTemplateName) {
      try {
        parent = this.getTemplateSync(parentTemplateName, loadContext, this.templateName, node);
      } catch (error) {
        if (error instanceof TemplateNotFoundError) return;
        throw error;
      }
      stacked = this.stackBlocks(stackContext, parent);
      parentTemplateName = this.extend(stacked, seen);
    }
    const refs = new InheritanceChainCounter(parent, stackContext, undefined, {
      followPartials: this.followPartials,
      scope: chainObjects({
        block: undefined
      }, this.scope),
      templateLocals: this.templateLocals,
      raiseForFailures: this.raiseForFailures,
      partials: this.partials
    }).analyzeSync();
    this.updateReferenceCounters(refs);
  }
  extend(_stacked, seen) {
    if (_stacked.extendsNode !== undefined) {
      const _parentTemplateName = liquidStringify(_stacked.extendsNode.name);
      if (seen.has(_parentTemplateName)) {
        throw new TemplateInheritanceError(`circular extends '${_parentTemplateName}'`, _stacked.extendsNode.token);
      }
      seen.add(_parentTemplateName);
      return _parentTemplateName;
    }
    return undefined;
  }
  stackBlocks(stackContext, template) {
    let countTags = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
    const stacked = stackBlocks(stackContext, template);
    if (countTags && stacked.extendsNode) {
      const token = stacked.extendsNode.token;
      this.tags.get(token.value).push({
        templateName: template.name,
        lineNumber: token.lineNumber()
      });
    }
    for (const node of stacked.blockNodes) {
      const token = node.token;
      this.tags.get(token.value).push({
        templateName: template.name,
        lineNumber: token.lineNumber()
      });
    }
    return stacked;
  }
  async getTemplate(name, loaderContext, parentName, parentNode) {
    try {
      return await this.emptyContext.getTemplate(name, loaderContext);
    } catch (error) {
      if (error instanceof TemplateNotFoundError) {
        this.unloadablePartials.get(name).push({
          templateName: parentName,
          lineNumber: parentNode.token.lineNumber()
        });
      }
      throw error;
    }
  }
  getTemplateSync(name, loaderContext, parentName, parentNode) {
    try {
      return this.emptyContext.getTemplateSync(name, loaderContext);
    } catch (error) {
      if (error instanceof TemplateNotFoundError) {
        this.unloadablePartials.get(name).push({
          templateName: parentName,
          lineNumber: parentNode.token.lineNumber()
        });
      }
      throw error;
    }
  }
  renderContext(child) {
    if (child.expression === undefined) {
      return {};
    }
    if (!(child.expression instanceof StringLiteral)) {
      this.unloadablePartials.get(child.expression.toString()).push({
        templateName: this.templateName,
        lineNumber: child.token.lineNumber()
      });
      return {};
    }
    const context = {
      templateName: child.expression.value.toString(),
      loadContext: child.loadContext ?? {}
    };
    const contextKey = JSON.stringify(context);

    // Keep track of partial templates that have already been analyzed. This prevents
    // us from analyzing the same template twice and protects us against recursive
    // includes/renders.
    if (this.partials.has(contextKey)) {
      return {};
    }
    this.partials.add(contextKey);
    return context;
  }
  countTag(node) {
    if (!(node instanceof BlockNode$1) && node.token.kind === TOKEN_TAG) {
      this.tags.get(node.token.value).push({
        templateName: this.templateName,
        lineNumber: node.token.lineNumber()
      });
    }
  }

  // eslint-disable-next-line sonarjs/cognitive-complexity
  updateReferenceCounters(refs) {
    for (const [_name, _refs] of refs.variables.entries()) {
      for (const location of _refs) {
        this.variables.get(_name).push(location);
      }
    }
    for (const [_name, _refs] of refs.templateGlobals.entries()) {
      for (const location of _refs) {
        this.templateGlobals.get(_name).push(location);
      }
    }
    for (const [_name, _refs] of refs.failedVisits.entries()) {
      for (const location of _refs) {
        this.failedVisits.get(_name).push(location);
      }
    }
    for (const [_name, _refs] of refs.unloadablePartials.entries()) {
      for (const location of _refs) {
        this.unloadablePartials.get(_name).push(location);
      }
    }
    for (const [_name, _refs] of refs.filters.entries()) {
      for (const location of _refs) {
        this.filters.get(_name).push(location);
      }
    }
    for (const [_name, _refs] of refs.tags.entries()) {
      for (const location of _refs) {
        this.tags.get(_name).push(location);
      }
    }
  }
  _raiseForFailures() {
    if (this.raiseForFailures && this.failedVisits.size) {
      const msgTarget = this.failedVisits.entries().next().value[0];
      let msg;
      if (this.failedVisits.size > 1) {
        msg = `${msgTarget} (+${this.failedVisits.size - 1} more) ` + "does not implement a 'children' method";
      } else {
        msg = `${msgTarget} does not implement a 'children' method`;
      }
      throw new TemplateTraversalError(`failed visit: ${msg}`);
    }
    if (this.raiseForFailures && this.unloadablePartials.size) {
      const msgTarget = this.unloadablePartials.entries().next().value[0];
      let msg;
      if (this.unloadablePartials.size > 1) {
        msg = `partial template ${msgTarget} ` + `(+${this.unloadablePartials.size - 1} more) ` + "could not be loaded";
      } else {
        msg = `partial template ${msgTarget} could not be loaded`;
      }
      throw new TemplateTraversalError(`failed visit: ${msg}`);
    }
  }

  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  async expressionHook(child) {}

  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  expressionHookSync(child) {}
}
class InheritanceChainCounter extends TemplateVariableCounter {
  constructor(baseTemplate, stackContext, parentBlockStackItem, _ref3) {
    let {
      followPartials,
      raiseForFailures,
      scope,
      templateLocals,
      partials
    } = _ref3;
    super(baseTemplate, {
      followPartials,
      raiseForFailures,
      scope,
      templateLocals,
      partials
    });
    this.baseTemplate = baseTemplate;
    this.stackContext = stackContext;
    this.parentBlockStackItem = parentBlockStackItem;
  }
  async _analyze(root) {
    if (root instanceof BlockNode) {
      return await this.analyzeBlock(root);
    }
    return await super._analyze(root);
  }
  _analyzeSync(root) {
    if (root instanceof BlockNode) {
      return this.analyzeBlockSync(root);
    }
    return super._analyzeSync(root);
  }
  async expressionHook(child) {
    if (!child.expression || !this.parentBlockStackItem || !this.containsSuper(child.expression)) return;
    const template = this.makeTemplate(this.parentBlockStackItem);
    const scope = Object.fromEntries(Array.from(this.templateLocals.keys()).map(s => [s.split(InheritanceChainCounter.RE_SPLIT_IDENT, 1)[0], undefined]));
    const refs = await new InheritanceChainCounter(template, this.stackContext, undefined, {
      followPartials: this.followPartials,
      scope: chainObjects({
        block: undefined
      }, this.scope, scope),
      raiseForFailures: this.raiseForFailures,
      partials: this.partials
    }).analyze();
    this.updateReferenceCounters(refs);
  }
  expressionHookSync(child) {
    if (!child.expression || !this.parentBlockStackItem || !this.containsSuper(child.expression)) return;
    const template = this.makeTemplate(this.parentBlockStackItem);
    const scope = Object.fromEntries(Array.from(this.templateLocals.keys()).map(s => [s.split(InheritanceChainCounter.RE_SPLIT_IDENT, 1)[0], undefined]));
    const refs = new InheritanceChainCounter(template, this.stackContext, undefined, {
      followPartials: this.followPartials,
      scope: chainObjects({
        block: undefined
      }, this.scope, scope),
      raiseForFailures: this.raiseForFailures,
      partials: this.partials
    }).analyzeSync();
    this.updateReferenceCounters(refs);
  }
  containsSuper(expression) {
    if (expression instanceof Identifier && expression.toString() === "block.super") return true;
    if (expression instanceof FilteredExpression && expression.expression instanceof Identifier && expression.expression.toString() === "block.super") return true;
    if (expression.children) {
      for (const expr of expression.children()) {
        if (this.containsSuper(expr)) return true;
      }
    }
    return false;
  }
  async analyzeBlock(block) {
    const blockStacks = this.stackContext.getRegister(EXTENDS_REGISTER$1);
    const _blockStackItems = blockStacks.get(block.name);
    if (!_blockStackItems) return;
    const blockStackItem = _blockStackItems[0];
    const template = this.makeTemplate(blockStackItem);
    const scope = Object.fromEntries(Array.from(this.templateLocals.keys()).map(s => [s.split(InheritanceChainCounter.RE_SPLIT_IDENT, 1)[0], undefined]));
    const refs = await new InheritanceChainCounter(template, this.stackContext, blockStackItem.parent, {
      followPartials: this.followPartials,
      scope: chainObjects({
        block: undefined
      }, this.scope, scope),
      raiseForFailures: this.raiseForFailures,
      partials: this.partials
    }).analyze();
    this.updateReferenceCounters(refs);
  }
  analyzeBlockSync(block) {
    const blockStacks = this.stackContext.getRegister(EXTENDS_REGISTER$1);
    const _blockStackItems = blockStacks.get(block.name);
    if (!_blockStackItems) return;
    const blockStackItem = _blockStackItems[0];
    const template = this.makeTemplate(blockStackItem);
    const scope = Object.fromEntries(Array.from(this.templateLocals.keys()).map(s => [s.split(InheritanceChainCounter.RE_SPLIT_IDENT, 1)[0], undefined]));
    const refs = new InheritanceChainCounter(template, this.stackContext, blockStackItem.parent, {
      followPartials: this.followPartials,
      scope: chainObjects({
        block: undefined
      }, this.scope, scope),
      raiseForFailures: this.raiseForFailures,
      partials: this.partials
    }).analyzeSync();
    this.updateReferenceCounters(refs);
  }
  makeTemplate(item) {
    const parseTree = new Root();
    parseTree.nodes.push(...item.block.block.nodes);
    return new Template(this.template.environment, parseTree, {}, {
      name: item.sourceName
    });
  }
}

// For backwards compatibility. We've moved these to static_analysis.ts.

/**
 * A Liquid template that has been parsed and is bound to an environment,
 * ready to be rendered. Rather than constructing a template directly, you
 * should use `Template.fromString()`, `Environment.fromString()` or
 * `Environment.getTemplate()`.
 */
class Template {
  renderContextClass = RenderContext;

  /**
   * Parse a Liquid template, automatically creating an environment to
   * bind it to.
   *
   * @param source - The Liquid template source code.
   * @param templateGlobals - Global render context variables that will
   * included every time this template is rendered.
   * @param options - Options to set on the implicit environment. `globals`
   * and `loader` will be ignored when creating an implicit environment.
   * @returns A new template, bound to an implicit environment.
   */
  static fromString(source, templateGlobals) {
    let options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    const {
      loader,
      ...opts
    } = options;
    return Environment.getImplicitEnvironment(opts).fromString(source, templateGlobals, {
      name: "<string>"
    });
  }

  /**
   * Parse a Liquid template, automatically creating an environment to
   * bind it to.
   *
   * Alias of {@link fromString}
   *
   * @param source - The Liquid template source code.
   * @param templateGlobals - Global render context variables that will
   * included every time this template is rendered.
   * @param options - Options to set on the implicit environment.
   * @returns A new template, bound to an implicit environment.
   */
  static from(source, templateGlobals) {
    let options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    return Template.fromString(source, templateGlobals, options);
  }

  /**
   * Template constructor. Rather than constructing a template directly, you
   * should use `Template.fromString()`, `Environment.fromString()` or
   * `Environment.getTemplate()`.
   *
   * @param environment - The environment this template is bound to.
   * @param tree - The root of the abstract syntax tree representing this
   * template.
   * @param globals - An optional object who's properties will be added
   * to the render context every time the resulting template is rendered.
   * @param templateContext - Optional meta data. Mostly for managing loading
   * and reloading of templates.
   */
  constructor(environment, tree, globals) {
    let templateContext = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
    this.environment = environment;
    this.tree = tree;
    this.name = templateContext.name ?? "<string>";
    this.globals = globals === undefined ? {} : globals;
    this.matter = templateContext.matter ?? {};
    this.loaderContext = templateContext.loaderContext ?? {};
    this.isUpToDate = templateContext.upToDate ?? (async () => true);
    this.isUpToDateSync = templateContext.upToDateSync ?? (() => true);
  }

  /**
   * Render the template.
   * @param globals - An optional object who's properties will be added
   * to the render context,
   * @returns The rendered template.
   */
  async render() {
    let globals = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    const context = new this.renderContextClass(this.environment, this.makeGlobals(globals), {
      templateName: this.name,
      loaderContext: this.loaderContext,
      template: this
    });
    const outputStream = this.environment.renderStreamFactory();
    await this.renderWithContext(context, outputStream);
    return outputStream.toString();
  }

  /**
   * A synchronous version of `render`.
   * @see {@link render}
   */
  renderSync() {
    let globals = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    const context = new this.renderContextClass(this.environment, this.makeGlobals(globals), {
      templateName: this.name,
      loaderContext: this.loaderContext,
      template: this
    });
    const outputStream = this.environment.renderStreamFactory();
    this.renderWithContextSync(context, outputStream);
    return outputStream.toString();
  }
  handleError(error, node, blockScope, partial) {
    if (error instanceof LiquidInterrupt) {
      if (!partial || blockScope) {
        this.environment.error(new LiquidSyntaxError(`unexpected '${error.message}'`, node.token, this.name));
      } else {
        throw error;
      }
    } else if (error instanceof InternalLiquidError) {
      this.environment.error(error.withToken(node.token, this.name));
    } else if (error instanceof LiquidError) {
      this.environment.error(error);
    } else {
      throw error;
    }
  }

  /**
   * Render a template given an existing render context and output stream.
   * This is used by the built-in `include` and `render` tags.
   */
  async renderWithContext(context, outputStream) {
    let blockScope = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
    let partial = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
    for (const node of this.tree.nodes) {
      throwForDisabledTag(node, context, this.name);
      try {
        if (node instanceof LiteralNode) {
          node.renderSync(context, outputStream);
        } else {
          await node.render(context, outputStream);
        }
      } catch (error) {
        if (error instanceof StopRender) {
          break;
        }
        this.handleError(error, node, blockScope, partial);
      }
    }
  }

  /**
   * A synchronous version of `renderWithContext`.
   * @see {@link renderWithContext}
   */
  renderWithContextSync(context, outputStream) {
    let blockScope = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
    let partial = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
    for (const node of this.tree.nodes) {
      throwForDisabledTag(node, context, this.name);
      try {
        node.renderSync(context, outputStream);
      } catch (error) {
        if (error instanceof StopRender) {
          break;
        }
        this.handleError(error, node, blockScope, partial);
      }
    }
  }

  /**
   * Copy this template with new render context globals.
   *
   * @param globals - An object who's properties will be added
   * to the render context every time this template is rendered.
   * @returns A copy of this template with new render context globals.
   */
  withGlobals(globals) {
    return new Template(this.environment, this.tree, globals, {
      loaderContext: this.loaderContext,
      matter: this.matter,
      name: this.name,
      upToDate: this.isUpToDate,
      upToDateSync: this.isUpToDateSync
    });
  }

  /**
   * Combine render context global variables from the bound environment,
   * the "matter" object originating from a template loader (if any) and
   * those passed to `render()`.
   *
   * Override this to change global template scope priorities.
   */
  makeGlobals(templateGlobals) {
    return chainObjects(templateGlobals, this.matter, this.globals);
  }

  /**
   * Statically analyze this template and any included/rendered templates.
   * Currently we only analyze references to template variables.
   *
   * @param options - Template analysis options.
   */
  async analyze() {
    let {
      followPartials,
      raiseForFailures
    } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    const counter = new TemplateVariableCounter(this, {
      followPartials,
      raiseForFailures
    });
    const refs = await counter.analyze();
    return {
      variables: Object.fromEntries(refs.variables.entries()),
      localVariables: Object.fromEntries(refs.templateLocals.entries()),
      globalVariables: Object.fromEntries(refs.templateGlobals.entries()),
      failedVisits: Object.fromEntries(refs.failedVisits.entries()),
      unloadablePartials: Object.fromEntries(refs.unloadablePartials.entries()),
      filters: Object.fromEntries(refs.filters.entries()),
      tags: Object.fromEntries(refs.tags.entries())
    };
  }

  /**
   * A synchronous version of `analyze`
   * @see {@link analyze}
   * @param options - Template analysis options.
   */
  analyzeSync() {
    let {
      followPartials,
      raiseForFailures
    } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    const counter = new TemplateVariableCounter(this, {
      followPartials,
      raiseForFailures
    });
    const refs = counter.analyzeSync();
    return {
      variables: Object.fromEntries(refs.variables.entries()),
      localVariables: Object.fromEntries(refs.templateLocals.entries()),
      globalVariables: Object.fromEntries(refs.templateGlobals.entries()),
      failedVisits: Object.fromEntries(refs.failedVisits.entries()),
      unloadablePartials: Object.fromEntries(refs.unloadablePartials.entries()),
      filters: Object.fromEntries(refs.filters.entries()),
      tags: Object.fromEntries(refs.tags.entries())
    };
  }
}

/**
 * An object to which a {@link Tag} can write its rendered content to.
 */

/**
 * A {@link RenderStream} implementation that buffers rendered content
 * in memory.
 */
class BufferedRenderStream {
  constructor() {
    let buffer = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    this.buffer = buffer;
  }
  write(value) {
    this.buffer.push(value);
  }
  toString() {
    return this.buffer.join("");
  }
}

/**
 * A {@link RenderStream} implementation that buffers rendered content in
 * memory and throws an OutputStreamLimitError if bytes written exceed its
 * limit.
 */
class LimitedRenderStream {
  size = 0;
  constructor(limit) {
    let buffer = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
    this.limit = limit;
    this.buffer = buffer;
  }
  write(value) {
    if (value.length) {
      this.size += _byteLength(value);
      if (this.size > this.limit) {
        throw new InternalOutputStreamLimitError("output stream limit reached");
      }
    }
    this.buffer.push(value);
  }
  toString() {
    return this.buffer.join("");
  }
}
function _byteLength(value) {
  // From https://stackoverflow.com/questions/5515869/string-length-in-bytes-in-javascript
  // returns the byte length of an utf8 string
  let length = value.length;
  for (let i = value.length - 1; i >= 0; i--) {
    const code = value.charCodeAt(i);
    if (code > 0x7f && code <= 0x7ff) length++;else if (code > 0x7ff && code <= 0xffff) length += 2;
    if (code >= 0xdc00 && code <= 0xdfff) i--; //trail surrogate
  }
  return length;
}

const implicitEnvironmentCache = new LRUCache(10);

/**
 * Liquid environment options.
 */

/**
 * Optional meta data and utilities for managing liquid templates.
 */

/**
 * Shared configuration from which templates can be loaded and parsed.
 * @see {@link EnvironmentOptions}
 */
class Environment {
  templateClass = Template;
  /**
   * An object mapping filter names to filter functions.
   */
  filters = {};

  /**
   * An object mapping tag names to tag implementations.
   */
  tags = {};
  #tokenRules;
  #tokenize;
  #parser;

  /**
   * Environment constructor.
   *
   * @param options - Environment options.
   */
  constructor() {
    let {
      autoEscape,
      globals,
      loader,
      maxContextDepth,
      localNamespaceLimit,
      loopIterationLimit,
      outputStreamLimit,
      statementStartString,
      statementEndString,
      strictFilters,
      tagStartString,
      tagEndString,
      undefinedFactory,
      renderStreamFactory
    } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    this.autoEscape = autoEscape ?? false;
    this.globals = globals ?? {};
    this.loader = loader ?? new MapLoader();
    this.maxContextDepth = maxContextDepth ?? 30;
    this.localNamespaceLimit = localNamespaceLimit ?? -1;
    this.loopIterationLimit = loopIterationLimit ?? -1;
    this._outputStreamLimit = outputStreamLimit ?? -1;
    this.statementStartString = statementStartString ?? "{{";
    this.statementEndString = statementEndString ?? "}}";
    this.strictFilters = strictFilters ?? true;
    this.tagStartString = tagStartString ?? "{%";
    this.tagEndString = tagEndString ?? "%}";
    this.undefinedFactory = undefinedFactory ?? LaxUndefined.from;
    this.renderStreamFactory = renderStreamFactory ?? _makeRenderStreamFactory(this._outputStreamLimit);
    this.#tokenRules = compileRules(this.statementStartString, this.statementEndString, this.tagStartString, this.tagEndString);
    this.#tokenize = tokenizerFor(this.#tokenRules, this.statementStartString, this.statementEndString, this.tagStartString, this.tagEndString);
    this.#parser = new TemplateParser(this);
    registerBuiltin(this);
  }

  /**
   * Return an environment configured with the given options. The `globals`
   * and `loader` options are ignored when creating implicit environments.
   *
   * @param options - Options for the implicit environment.
   */
  static getImplicitEnvironment() {
    let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    const {
      globals,
      loader,
      ...opts
    } = options;
    const cacheKey = JSON.stringify(opts, Object.keys(opts).sort());
    let env = implicitEnvironmentCache.get(cacheKey);
    if (!env) {
      env = new Environment(opts);
      implicitEnvironmentCache.set(cacheKey, env);
    }
    return env;
  }

  /**
   * Load a template using the configured template loader.
   * @param name - The name or identifier of the template to load.
   * @param globals - An optional object who's properties will be added
   * to the render context every time the resulting template is rendered.
   * @param context - A reference to the active render context, if one is
   * active.
   * @param loaderContext - Additional, arbitrary data that a loader can use
   * to scope or otherwise narrow its search space.
   * @returns A `Template` bound to this environment, ready to be rendered.
   * @throws `NoSuchTemplateError` if a template with the given name can not
   * be found.
   */
  async getTemplate(name, globals, context, loaderContext) {
    return this.loader.load(name, this, context, globals, loaderContext);
  }

  /**
   * A synchronous version of `Environment.getTemplate()`.
   * @see {@link getTemplate}
   */
  getTemplateSync(name, globals, context, loaderContext) {
    return this.loader.loadSync(name, this, context, globals, loaderContext);
  }

  /**
   * Parse the given string as a Liquid template.
   * @param source - The Liquid template source code.
   * @param globals - An optional object who's properties will be added
   * to the render context every time the resulting template is rendered.
   * @param templateContext - Optional meta data. Mostly for managing loading
   * and reloading of templates.
   * @returns A `Template` bound to this environment, ready to be rendered.
   * @throws `NoSuchTemplateError` if a template with the given name can not
   * be found.
   */
  fromString(source, globals) {
    let templateContext = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    return new this.templateClass(this, this.parse(source, templateContext?.name), this.makeGlobals(globals), templateContext);
  }

  /**
   * Add a filter to this environment.
   *
   * @param name - The filter's name, as used by template authors to apply
   * the filter.
   * @param filter - A function implementing the filter.
   */
  addFilter(name, filter) {
    this.filters[name] = filter;
  }

  /**
   * Add a tag to this environment.
   *
   * @param name - The tag's name, as used by template authors to use the
   * tag.
   * @param tag - An object implementing the Tag interface.
   */
  addTag(name, tag) {
    this.tags[name] = tag;
  }

  /**
   * Re-throw an error.
   *
   * Override this method if you want to implement a "lax mode".
   */
  error(err) {
    throw err;
  }
  get parser() {
    return this.#parser;
  }
  parse(source, name) {
    try {
      return this.parser.parse(new TemplateTokenStream(this.#tokenize(source)));
    } catch (error) {
      if (error instanceof LiquidSyntaxError) {
        throw error.withTemplateName(name);
      }
      throw error;
    }
  }
  makeGlobals(templateGlobals) {
    if (templateGlobals === undefined) return this.globals;
    return chainObjects(templateGlobals, this.globals);
  }
  get outputStreamLimit() {
    return this._outputStreamLimit;
  }
  set outputStreamLimit(value) {
    // Update the render stream factory with the new limit.
    this._outputStreamLimit = value;
    this.renderStreamFactory = _makeRenderStreamFactory(this._outputStreamLimit);
  }
}
function _makeRenderStreamFactory(limit) {
  return limit > -1 ? buf => new LimitedRenderStream(limit - (buf?.size ?? 0)) : () => new BufferedRenderStream();
}

var index$3 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  ForLoopDrop: ForLoopDrop,
  TableRowLoopDrop: TableRowLoopDrop
});

var index$2 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  AssignNode: AssignNode,
  AssignTag: AssignTag,
  BreakNode: BreakNode,
  BreakTag: BreakTag,
  CaptureNode: CaptureNode,
  CaptureTag: CaptureTag,
  CaseNode: CaseNode,
  CaseTag: CaseTag,
  CommentNode: CommentNode,
  CommentTag: CommentTag,
  ContinueNode: ContinueNode,
  ContinueTag: ContinueTag,
  CycleNode: CycleNode,
  CycleTag: CycleTag,
  Cycles: Cycles,
  DecrementNode: DecrementNode,
  DecrementTag: DecrementTag,
  EchoNode: EchoNode,
  EchoTag: EchoTag,
  ForNode: ForNode,
  ForTag: ForTag,
  IfChangedNode: IfChangedNode,
  IfChangedTag: IfChangedTag,
  IfNode: IfNode,
  IfTag: IfTag,
  IncludeNode: IncludeNode,
  IncludeTag: IncludeTag,
  IncrementNode: IncrementNode,
  IncrementTag: IncrementTag,
  LiquidNode: LiquidNode,
  LiquidTag: LiquidTag,
  LiteralNode: LiteralNode,
  OutputStatement: OutputStatement,
  OutputStatementNode: OutputStatementNode,
  RenderNode: RenderNode,
  RenderTag: RenderTag,
  TableRowNode: TableRowNode,
  TableRowTag: TableRowTag,
  TemplateLiteral: TemplateLiteral,
  UndefinedCycleGroup: UndefinedCycleGroup,
  UnlessNode: UnlessNode,
  UnlessTag: UnlessTag
});

/**
 * A drop-in replacement for the standard output statement that supports
 * inline `if` expressions.
 */
class ConditionalOutputStatement extends OutputStatement {
  parse(stream) {
    return new this.nodeClass(stream.current, parse(stream.current.value, stream.current.index));
  }
}

/**
 * A drop-in replacement for the standard assign tag that supports
 * inline `if` expressions.
 */
class ConditionalAssignTag extends AssignTag {
  parseExpression(value, startIndex) {
    return parse(value, startIndex);
  }
}

/**
 * A drop-in replacement for the standard echo tag that supports
 * inline `if` expressions.
 */
class ConditionalEchoTag extends EchoTag {
  parseExpression(value, startIndex) {
    return parse(value, startIndex);
  }
}

/**
 * A drop-in replacement for the standard output statement that supports
 * inline `if` expressions with a logical `not` operator and grouping
 * terms with parentheses.
 */
class ConditionalOutputStatementWithParens extends OutputStatement {
  parse(stream) {
    return new this.nodeClass(stream.current, parseWithParens(stream.current.value, stream.current.index));
  }
}

/**
 * A drop-in replacement for the standard assign tag that supports
 * inline `if` expressions with a logical `not` operator and grouping
 * terms with parentheses.
 */
class ConditionalAssignTagWithParens extends AssignTag {
  parseExpression(value, startIndex) {
    return parseWithParens(value, startIndex);
  }
}

/**
 * A drop-in replacement for the standard echo tag that supports
 * inline `if` expressions with a logical `not` operator and grouping
 * terms with parentheses.
 */
class ConditionalEchoTagWithParens extends EchoTag {
  parseExpression(value, startIndex) {
    return parseWithParens(value, startIndex);
  }
}

class IfNotTag extends IfTag {
  parseExpression(stream) {
    stream.expect(TOKEN_EXPRESSION);
    return parse$3(stream.current.value);
  }
}

const TAG_ENDMACRO = "endmacro";
const END_MACRO_BLOCK = new Set([TAG_ENDMACRO]);
const Macros = Symbol.for("liquid.tags.macros");
class MacroTag {
  nodeClass = MacroNode;
  parse(stream, environment) {
    const token = stream.next();
    stream.expect(TOKEN_EXPRESSION);
    const [name, args] = parseMacroArguments(stream.current.value, stream.current.index);
    stream.next();
    const block = environment.parser.parseBlock(stream, END_MACRO_BLOCK, token);
    return new this.nodeClass(token, name, args, block);
  }
}
class CallTag {
  block = false;
  nodeClass = CallNode;
  parse(stream) {
    const token = stream.next();
    stream.expect(TOKEN_EXPRESSION);
    const [name, _args] = parseCallArguments(stream.current.value, stream.current.index);
    const args = [];
    const kwargs = [];
    for (const [k, v] of _args) {
      if (k === "") {
        args.push(v);
      } else {
        kwargs.push([k, v]);
      }
    }
    return new this.nodeClass(token, name, args, kwargs);
  }
}
class MacroNode {
  constructor(token, name, args, block) {
    this.token = token;
    this.name = name;
    this.args = args;
    this.block = block;
  }
  async render(context) {
    this.renderSync(context);
  }
  renderSync(context) {
    const macros = context.getRegister(Macros);
    macros.set(this.name, {
      args: this.args,
      block: this.block
    });
  }
  children() {
    const blockScope = this.args.map(arg => arg[0]);
    const _children = [{
      token: this.token,
      node: this.block,
      blockScope
    }];
    for (const [_, v] of this.args) {
      if (v !== NIL) {
        _children.push({
          token: this.token,
          expression: v
        });
      }
    }
    return _children;
  }
}
class CallNode {
  disabledTags = ["include", "render"];
  constructor(token, name, args, kwargs) {
    this.token = token;
    this.name = name;
    this.args = args;
    this.kwargs = kwargs;
  }
  async render(context, out) {
    const macro = this.getMacro(context);
    if (isUndefined(macro)) {
      macro.poke();
      return;
    }
    macro.block.renderSync(await this.makeContext(context, macro), out);
  }
  renderSync(context, out) {
    const macro = this.getMacro(context);
    if (isUndefined(macro)) {
      macro.poke();
      return;
    }
    macro.block.renderSync(this.makeContextSync(context, macro), out);
  }
  children() {
    const _children = this.kwargs.map(arg => ({
      token: this.token,
      expression: arg[1]
    }));
    for (const expr of this.args) {
      _children.push({
        token: this.token,
        expression: expr
      });
    }
    return _children;
  }
  bindArgs(macro) {
    const args = Object.fromEntries(macro.args);
    const macroKeys = Object.keys(args);
    const keySet = new Set(macroKeys);

    // Bind positional arguments to names.
    const excessArgs = [];
    const keysLength = macroKeys.length;
    const argsLength = this.args.length;
    const nArgs = Math.max(keysLength, argsLength);
    for (let i = 0; i < nArgs; i++) {
      if (i >= keysLength) {
        excessArgs.push(this.args[i]);
        continue;
      }
      if (i >= argsLength) {
        break;
      }
      args[macroKeys[i]] = this.args[i];
    }

    // Update default and/or missing arguments with keyword arguments.
    const excessKeywordArgs = {};
    for (const [key, expr] of this.kwargs) {
      if (keySet.has(key)) {
        args[key] = expr;
      } else {
        excessKeywordArgs[key] = expr;
      }
    }
    return {
      args,
      excessArgs,
      excessKeywordArgs
    };
  }
  async makeContext(context, macro) {
    const {
      args,
      excessArgs,
      excessKeywordArgs
    } = this.bindArgs(macro);

    // Evaluate excess arguments.
    const excess = {
      kwargs: {},
      args: []
    };
    for (const [key, expr] of Object.entries(excessKeywordArgs)) {
      excess["kwargs"][key] = await expr.evaluate(context);
    }
    for (const expr of excessArgs) {
      excess["args"].push(await expr.evaluate(context));
    }

    // Evaluate arguments.
    const boundArgs = {};
    for (const [key, expr] of Object.entries(args)) {
      if (NIL.equals(expr)) {
        boundArgs[key] = context.environment.undefinedFactory(key);
      } else {
        boundArgs[key] = await expr.evaluate(context);
      }
    }
    return context.copy(chainObjects(boundArgs, excess), this.disabledTags, true);
  }
  makeContextSync(context, macro) {
    const {
      args,
      excessArgs,
      excessKeywordArgs
    } = this.bindArgs(macro);

    // Evaluate excess arguments.
    const excess = {
      kwargs: {},
      args: []
    };
    for (const [key, expr] of Object.entries(excessKeywordArgs)) {
      excess["kwargs"][key] = expr.evaluateSync(context);
    }
    for (const expr of excessArgs) {
      excess["args"].push(expr.evaluateSync(context));
    }

    // Evaluate arguments.
    const boundArgs = {};
    for (const [key, expr] of Object.entries(args)) {
      if (NIL.equals(expr)) {
        boundArgs[key] = context.environment.undefinedFactory(key);
      } else {
        boundArgs[key] = expr.evaluateSync(context);
      }
    }
    return context.copy(chainObjects(boundArgs, excess), this.disabledTags, true);
  }
  getMacro(context) {
    const macros = context.getRegister(Macros);
    const macro = macros.get(this.name);
    if (macro === undefined) {
      return context.environment.undefinedFactory(this.name);
    }
    return macro;
  }
}

// Reuse the tokenizer from the built-in `include` tag, but with some different keywords.
const tokenize = makeTokenizer$5(RE$6, new Set([TOKEN_TRUE, TOKEN_FALSE, TOKEN_NIL, TOKEN_NULL]));
const TAG_ENDWITH = "endwith";
const END_WITH_BLOCK = new Set([TAG_ENDWITH]);
/**
 * An implementation of the `with` tag.
 *
 * Extend the current scope for the duration of the `with` block. Useful for
 * aliasing long or nested variable names. Also useful for caching the result
 * of a drop's methods, if the drop does not perform its own caching.
 */
class WithTag {
  parse(stream, environment) {
    const token = stream.next();
    stream.expect(TOKEN_EXPRESSION);
    const args = this.parseExpression(stream.current);
    stream.next();
    const block = environment.parser.parseBlock(stream, END_WITH_BLOCK, token);
    return new WithNode(token, args, block);
  }
  parseExpression(expressionToken) {
    const args = {};
    const eStream = new ExpressionTokenStream(tokenize(expressionToken.value, expressionToken.index));
    while (eStream.current.kind !== TOKEN_EOF$1) {
      const [key, expr] = this.parseArgument(eStream);
      args[key] = expr;
      // Eat comma.
      if (eStream.current.kind === TOKEN_COMMA) eStream.next();
    }
    return args;
  }
  parseArgument(eStream) {
    const key = parseUnchainedIdentifier(eStream).toString();
    eStream.next();
    eStream.expect(TOKEN_COLON);
    eStream.next(); // Eat colon
    const val = parseObject$2(eStream);
    eStream.next();
    return [key, val];
  }
}
class WithNode {
  constructor(token, args, block) {
    this.token = token;
    this.args = args;
    this.block = block;
  }
  async render(context, out) {
    const scope = {};
    for (const [key, value] of Object.entries(this.args)) {
      scope[key] = await value.evaluate(context);
    }
    await context.extend(scope, () => this.block.render(context, out));
  }
  renderSync(context, out) {
    const scope = Object.fromEntries(Object.entries(this.args).map(_ref => {
      let [key, value] = _ref;
      return [key, value.evaluateSync(context)];
    }));
    context.extendSync(scope, () => this.block.renderSync(context, out));
  }
  children() {
    // FIXME: block scoped variables
    return [{
      token: this.token,
      node: this.block
    }];
  }
}

var index$1 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  BlockDrop: BlockDrop,
  BlockNode: BlockNode,
  BlockTag: BlockTag,
  CallNode: CallNode,
  CallTag: CallTag,
  ConditionalAssignTag: ConditionalAssignTag,
  ConditionalAssignTagWithParens: ConditionalAssignTagWithParens,
  ConditionalEchoTag: ConditionalEchoTag,
  ConditionalEchoTagWithParens: ConditionalEchoTagWithParens,
  ConditionalOutputStatement: ConditionalOutputStatement,
  ConditionalOutputStatementWithParens: ConditionalOutputStatementWithParens,
  ExtendsNode: ExtendsNode,
  ExtendsTag: ExtendsTag,
  IfNotTag: IfNotTag,
  MacroNode: MacroNode,
  MacroTag: MacroTag,
  Macros: Macros,
  WithNode: WithNode,
  WithTag: WithTag,
  stackBlocks: stackBlocks
});

function addInheritanceTags(env) {
  env.tags["block"] = new BlockTag();
  env.tags["extends"] = new ExtendsTag();
}
function addAllExtras(env) {
  addInheritanceTags(env);
  env.tags["call"] = new CallTag();
  env.tags["ConditionalOutputStatementWithParens"] = new ConditionalOutputStatementWithParens();
  env.tags["ConditionalAssignTagWithParens"] = new ConditionalAssignTagWithParens();
  env.tags["ConditionalEchoTagWithParens"] = new ConditionalEchoTagWithParens();
  env.tags["IfNotTag"] = new IfNotTag();
  env.tags["MacroTag"] = new MacroTag();
  env.tags["WithTag"] = new WithTag();
}

var index = /*#__PURE__*/Object.freeze({
  __proto__: null,
  addAllExtras: addAllExtras,
  addInheritanceTags: addInheritanceTags,
  tags: index$1
});

const version = "1.8.2";

// TODO: express interface

export { BLANK, Blank, BlockNode$1 as BlockNode, BooleanExpression, BooleanLiteral, BreakIteration, BufferedRenderStream, CONTINUE, CachingNodeFileSystemLoader, ChoiceLoader, ConditionalExpression, ContextDepthError, Continue, ContinueIteration, DisabledTagError, EMPTY, Empty, Environment, ExpressionFilter, FALSE, FalsyStrictUndefined, FetchLoader, FilterArgumentError, FilterNotFoundError, FilterValueError, FilteredExpression, Float, FloatLiteral, For, Identifier, IdentifierPathElement, InfixExpression, Integer, IntegerLiteral, InternalKeyError, InternalLiquidError, InternalOutputStreamLimitError, InternalSyntaxError, InternalTypeError, InternalUndefinedError, LRUCache, LaxUndefined, LiquidEnvironmentError, LiquidError, LiquidFilterArgumentError, LiquidFilterValueError, LiquidInterrupt, LiquidKeyError, LiquidNumber, LiquidSyntaxError, LiquidTypeError, LiquidUndefinedError, Literal, Loader, LocalNamespaceLimitError, LoopExpression, LoopIterationLimitError, MapLoader, Markup, MaxContextDepthError, MaxLocalNamespaceLimitError, MaxLoopIterationLimitError, Missing, NAN, NIL, Nil, NoSuchFilterError, NoSuchTagError, NoSuchTemplateError, NodeFileSystemLoader, ObjectLoader, OrphanedBreakTagError, OrphanedContinueTagError, OutputStreamLimitError, PrefixExpression, PushedTooFarError, Range, RangeLiteral, ReadOnlyObjectChainError, RenderContext, Root, StopRender, StrictUndefined, StringLiteral, TRUE, Template, TemplateInheritanceError, TemplateNotFoundError, TemplateParser, TemplateSource, TemplateTraversalError, Undefined, XMLHttpRequestLoader, ZERO, chainObjects, chainPop, chainPush, chainSize, checkArguments, index$3 as drops, index$4 as expressions, index as extra, index$d as filters, forcedOutput, hasLiquidCallable, isFloat, isInteger, isLiquidCallable, isLiquidDispatchable, isLiquidDispatchableSync, isLiquidHTMLable, isLiquidPrimitive, isLiquidStringable, isLiquidTruthy, isLiquidable, isLiquidableSync, isN, isNumberT, liquidDispatch, liquidDispatchSync, types as object, parseNumberT, range, index$2 as tags, throwForDisabledTag, throwIfOptions, toLiquid, toLiquidHtml, toLiquidPrimitive, toLiquidString, toLiquidSync, token as tokens, version, walk };
